/* Reference Table for Customer Type (Portfolio) */
DROP	TABLE IF EXISTS risk.ref_custtype_P; -- created by zeren
CREATE	TABLE risk.ref_custtype_P()
DISTRIBUTE	BY HASH(portfoy_tip)
AS (
SELECT	portfoy_tip, portfoy_tip_ack
FROM	dw_out.dwd_kon_musteri
GROUP	BY portfoy_tip, portfoy_tip_ack
);
GRANT ALL ON risk.ref_custtype_P to public;

/* Reference Table for Customer Type (Branch) */
DROP	TABLE IF EXISTS risk.ref_custtype_I; -- created by zeren
CREATE	TABLE risk.ref_custtype_I()
DISTRIBUTE	BY HASH(ref_oz_bank_mus)
AS (
SELECT	ref_oz_bank_mus, is_kolu
FROM	dw_out.dwd_kon_musteri
GROUP	BY ref_oz_bank_mus, is_kolu
);
GRANT 	ALL ON risk.ref_custtype_I to public;

/* Deriving salary information */

CREATE	ANALYTIC TABLE risk.maas_tarihler
DISTRIBUTE BY REPLICATION
AS
SELECT	CAST(date_trunc('month', cast(max(tarih) as DATE) - 90) as DATE)  as frst_date, 
		CAST(date_trunc('month', max(tarih)) as DATE) - 1  as last_date
FROM	dw_out.dwf_maas_kesit;
GRANT 	ALL ON risk.maas_tarihler to public;

CREATE	ANALYTIC TABLE risk.maas
DISTRIBUTE BY HASH(cmusno)
AS
SELECT	COALESCE(t1.cmusno, t2.cmusno) as cmusno,
		COALESCE(mm_maas, gelir) as INC
FROM	(
	SELECT	calisan_cmusno as cmusno, 
			ROUND(SUM(tut_tl) / 3, 2) as mm_maas -- salary info from salary accounts.
	FROM	dw_out.dwf_maas_kesit maas
	JOIN	risk.maas_tarihler tarih
		ON	1 = 1
	WHERE	tarih >= frst_date
		AND	tarih <= last_date
	GROUP	BY calisan_cmusno
	) t1
FULL JOIN (
	SELECT	COALESCE(t2.cmusno, t3.cmusno) AS cmusno,
			COALESCE(t2.lks_gelir, t3.deger) AS gelir
	FROM	(
		SELECT	cmusno, CAST(lks_gelir AS NUMERIC(18,2)) as lks_gelir
		FROM	dw_out.basvuru
		WHERE	lks_gelir IS NOT NULL
		) t2 
	FULL JOIN (
		SELECT	cmusno, CAST(deger AS NUMERIC(18,2)) as deger
		FROM	dw_out.ank_cev
		WHERE	anksoruno = '503'
		) t3
		ON 	t2.cmusno = t3.cmusno
	) t2
	ON	t1.cmusno = t2.cmusno;

/* Customer Info Table */
DROP	TABLE IF EXISTS risk.cust_info; -- created by zeren
CREATE	TABLE risk.cust_info()
DISTRIBUTE	BY HASH(CUST_ID)
AS (
SELECT t1.*, t2.INC, t3.CURR_LIMIT
FROM	(
	SELECT	cmusno as CUST_ID,
			-- STD_INC, -- steady income not possible. 
			ref_meslek as OCC_KEY,
			cinsiyet as SEX, -- E as Man, K as Woman
			ref_egitim as EDU_KEY,
			ref_calisma_sekli as EMP_KEY,
			CAST(d_dtar_yil || '-' || d_dtar_ay || '-' || d_dtar_gun AS DATE) as DOB,
			d_ilk_edinim_tar as CUST_ACQ_DT,
			-- HM_ADDR_CITY_KEY, -- one address supplied.
			-- HM_ADDR_DIST_KEY, -- one address supplied.
			d_ilkod_evadr as ADDR_CITY_KEY,
			d_ilcekod_evadr as ADDR_DIST_KEY,
			medeni_drm AS MARITAL_STS, -- FMLY_SZ Not Available. Marital Status Available. E as Married, B as Single, D as Died-Spouse, S as Divorced
			maas_anlasmali_eh as SALARY_CUST_FLG,-- E as Yes, H as No
			ana_sube as MN_BRNCH_KEY,
			portfoy_tip as CUST_TYPE_KEY_P, -- portfolio
			ref_oz_bank_mus as CUST_TYPE_KEY_I -- job branch 		 
	FROM	dw_out.dwd_kon_musteri
	WHERE	(ref_oz_bank_mus IN ('4','8') OR portfoy_tip IN ('4','8')) -- confirms that the customer has an individual account or a star account.
		AND	 mus_tip = 2 -- confirms that the customer has an individual account or a star account.
	) t1
JOIN	risk.maas t2
	ON	t1.CUST_ID = t2.cmusno
JOIN	(SELECT	d_cmusno as cmusno, "LIMIT" as curr_limit FROM dw_out.dwd_kart) t3
	ON	t1.CUST_ID = t3.cmusno
); 
GRANT 	ALL ON risk.cust_info to public;