DROP TABLE IF EXISTS risk.temp_eoc_bs;
CREATE	ANALYTIC TABLE risk.temp_eoc_bs 
DISTRIBUTE	BY HASH(cust_no) 
AS
SELECT	CAST(account_no as INTEGER) as cust_no,
	    min_amnt,
	    currency_code,/*ek*/
	    ref.usd_rate,
	    ref.eur_rate,
	    is_shifted,/*ek*/
	    pymt_due_date_total,/*ek*/
	    pymt_cycle_total,/*ek*/
	    min_amnt_cash,
	    min_amnt_prch,
		min_amnt_others,
	    min_amnt_overlimit_cash,
	    min_amnt_overlimit_prch,
		TO_DATE(CAST(eoc.prev_stmt_date AS CHAR(8)), 'YYYYMMDD') as prev_stmt_date,
		TO_DATE(CAST(eoc.prev_due_date AS CHAR(8)), 'YYYYMMDD') as prev_due_date,
		TO_DATE(CAST(due_date AS CHAR(8)), 'YYYYMMDD') as due_date,/*ek*/
		TO_DATE(CAST(stmt_date AS CHAR(8)), 'YYYYMMDD') as stmt_date,
		total_amnt,
		c_limit,
	    min_payment_ratio
FROM	"dw_out"."eoc_rediscount_summary_all" eoc
left join risk.ref_currency_table ref on CAST(eoc.account_no as INTEGER)=ref.cust_no and 
	 									 TO_DATE(CAST(eoc.prev_stmt_date AS CHAR(8)), 'YYYYMMDD')=ref.prev_stmt_date	 
--where account_no='1115473'
	 ;

GRANT ALL ON risk.temp_eoc_bs TO public;
analyze risk.temp_eoc_bs ;
-------------------------------------------------------------------------

DROP TABLE IF EXISTS risk.temp_eoc;
CREATE	ANALYTIC TABLE risk.temp_eoc 
DISTRIBUTE	BY HASH(cust_no) 
AS
SELECT	cust_no,
		currency_code,
	    usd_rate,
	    eur_rate,
	    sum(min_amnt) as min_amnt,
	    sum(min_amnt_cash) as min_amnt_cash,
	    sum(min_amnt_prch) as min_amnt_prch,
		sum(min_amnt_others) as min_amnt_others,
		sum(min_amnt_overlimit_cash) as min_amnt_overlimit_cash,
		sum(min_amnt_overlimit_prch) as min_amnt_overlimit_prch,
		prev_stmt_date,
		prev_due_date,
		sum(total_amnt) as total_amnt,
		c_limit
FROM	risk.temp_eoc_bs
group by cust_no,
		 currency_code,
	     usd_rate,
	     eur_rate,
	     prev_stmt_date,
		 prev_due_date,
		 c_limit
	 ;

GRANT ALL ON risk.temp_eoc TO public;
analyze risk.temp_eoc ;

------------------------------------------------------------------

DROP TABLE IF EXISTS risk.temp_smy_bs;
CREATE	ANALYTIC TABLE risk.temp_smy_bs 
DISTRIBUTE	BY HASH(cust_no) 
AS
select	as_of_dt,
		stmt_dt,
		due_dt,
		last_txn_amt,
		last_txn_dt,
		lmt,
		prev_stmt_dt,
		prev_due_dt,
		nxt_stmt_dt,
		nxt_due_dt,
		cl_brnd_tp_nm,
		cl_bin_clss_nm,
		CAST(ss_acc_no as INTEGER) as cust_no,
		(CAST(ss_crd_ctr_no as bigint)+9876) as ctr_no,
		cl_crd_st_nm,
		actv_f,
		main_card_f,
		bsn_f,
		nxt_fee_dt,
		cl_cc_fllw_st_tp_nm,
		cl_cc_cst_st_tp_nm,
		cl_worst_xtrt_pymt_st_tp_nm,
		cl_cst_xtrt_pymt_st_tp_nm,
		cl_worst_stmt_val_nm,
		cl_cc_cst_fllw_st_tp_nm,
		dlq_strt_dt,
		dlq_day_cnt,
		cash_lmt,
		sc_lmt_usg_rto,
		sc_cash_lmt_usg_rto,
		cl_dmst_stmt_pymt_tp_nm,
		rsk_lvl, 
		lmt_blc_f
FROM	"dw_out"."crd_ctr_smy_hist"
WHERE	cl_card_tp_nm ='Credit'

;

GRANT ALL ON risk.temp_smy_bs TO public;
analyze risk.temp_smy_bs ;



DROP TABLE IF EXISTS risk.temp_smy;
CREATE	ANALYTIC TABLE risk.temp_smy 
DISTRIBUTE	BY HASH(cust_no) 
AS
select	min(as_of_dt) as as_of_dt,
		stmt_dt,
		due_dt,
		min(last_txn_amt) as last_txn_amt,
		min(last_txn_dt) as last_txn_dt,
		min(lmt) as lmt,
		prev_stmt_dt,
		prev_due_dt,
		min(nxt_stmt_dt) as nxt_stmt_dt,
		min(nxt_due_dt) as nxt_due_dt,
		cl_brnd_tp_nm,
		cl_bin_clss_nm,
		cust_no,
		ctr_no
FROM	risk.temp_smy_bs
group by stmt_dt,
		 due_dt,
		 prev_stmt_dt,
		 prev_due_dt,
		 cl_brnd_tp_nm,
		 cl_bin_clss_nm,
		 cust_no,
		 ctr_no
;

GRANT ALL ON risk.temp_smy TO public;
analyze risk.temp_smy ;

-------------------------------------------------------------------------

DROP TABLE IF EXISTS risk.temp_kredi1;

CREATE fact TABLE risk.temp_kredi1
(
   as_of_dt date,
   stmt_dt date,
   due_dt date,
   last_txn_amt numeric,
   last_txn_dt date,
   lmt numeric,
   prev_stmt_dt date,
   prev_due_dt date,
   nxt_stmt_dt date,
   nxt_due_dt date,
   cl_brnd_tp_nm character varying(150),
   cl_bin_clss_nm character varying(150),
   ctr_no character varying(150),
   cust_no integer,
   currency_code numeric,
   usd_rate numeric(28,6),
   eur_rate numeric(28,6),
   min_amnt numeric,
   min_amnt_cash numeric,
   min_amnt_prch numeric,
   min_amnt_others numeric,
   min_amnt_overlimit_cash numeric,
   min_amnt_overlimit_prch numeric,
   total_amnt numeric,
   c_limit numeric
)
DISTRIBUTE BY HASH (cust_no)
STORAGE ROW
COMPRESS LOW
PARTITION BY list (as_of_dt)
(
   PARTITION p_1( values( '2015-10-31' )),
   PARTITION p_2( values( '2015-11-30' )),
   PARTITION p_3( values( '2015-12-31' )),
   PARTITION p_4( values( '2016-01-31' )),
   PARTITION p_5( values( '2016-02-29' )),
   PARTITION p_6( values( '2016-03-31' )),
   PARTITION p_7( values( '2016-04-30' )),
   PARTITION p_8( values( '2016-05-31' )),
   PARTITION p_9( values( '2016-06-30' )),
   PARTITION p_10( values( '2016-07-31' )),
   PARTITION p_11( values( '2016-08-31' )),
   PARTITION p_12( values( '2016-09-30' )),
   PARTITION p_13( values( '2016-10-31' )),
   PARTITION p_14( values( '2016-11-30' )),
   PARTITION p_15( values( '2016-12-31' )),
   PARTITION p_16( values( '2017-01-31' )),
   PARTITION p_17( values( '2017-02-28' )),
   PARTITION p_18( values( '2017-03-31' )),
   PARTITION p_19( values( '2017-04-30' )),
   PARTITION p_20( values( '2017-05-31' )),
   PARTITION p_21( values( '2017-06-30' )),
   PARTITION p_22( values( '2017-07-31' )),
   PARTITION p_23( values( '2017-08-31' )),
   PARTITION p_24( values( '2017-09-30' )),
   PARTITION p_25( values( '2017-10-31' )),
   PARTITION p_26( values( '2017-11-30' )),
   PARTITION p_27( values( '2017-12-31' )),
   PARTITION p_28( values( '2018-01-31' )),
   PARTITION p_29( values( '2018-02-28' )),
   PARTITION p_30( values( '2018-03-31' )),
   PARTITION p_31( values( '2018-04-30' )),
   PARTITION p_32( values( '2018-05-31' )),
   PARTITION p_33( values( '2018-06-30' )),
   PARTITION p_34( values( '2018-07-31' )),
   PARTITION p_35( values( '2018-08-31' ))
)

;

insert into risk.temp_kredi1 
SELECT	smy.as_of_dt,
		smy.stmt_dt,
		smy.due_dt,
		smy.last_txn_amt, 
		smy.last_txn_dt,
		smy.lmt,
		smy.prev_stmt_dt,
		smy.prev_due_dt,
		smy.nxt_stmt_dt,
		smy.nxt_due_dt,
		smy.cl_brnd_tp_nm,
		smy.cl_bin_clss_nm,
		CAST(ctr_no as varchar(150)) as ctr_no,
		smy.cust_no,
		eoc.currency_code,
	    eoc.usd_rate,
	    eoc.eur_rate,
		eoc.min_amnt,
		eoc.min_amnt_cash,
		eoc.min_amnt_prch,
		eoc.min_amnt_others,
		eoc.min_amnt_overlimit_cash,
   		eoc.min_amnt_overlimit_prch,
		eoc.total_amnt,
		eoc.c_limit
from risk.temp_smy smy 
join risk.temp_eoc eoc 
	on 	smy.cust_no = eoc.cust_no
	and	smy.stmt_dt = eoc.prev_stmt_date
where as_of_dt not in ('2018-01-01','2017-01-01','2016-01-01','2018-07-30')
;

GRANT ALL ON risk.temp_kredi1 TO public;
analyze risk.temp_kredi1 ;

-------------------------------------------------------------------------

DROP TABLE IF EXISTS risk.temp_kart;
CREATE FACT TABLE risk.temp_kart 
(
cust_id numeric(8,0), 
card_id character varying(20),
cust_no integer,
tarih_id  date,
valid_f integer
)
DISTRIBUTE BY HASH (cust_id)
STORAGE ROW
COMPRESS LOW
PARTITION BY list (tarih_id)
(
   PARTITION p_1( values( '2015-10-31' )),
   PARTITION p_2( values( '2015-11-30' )),
   PARTITION p_3( values( '2015-12-31' )),
   PARTITION p_4( values( '2016-01-31' )),
   PARTITION p_5( values( '2016-02-29' )),
   PARTITION p_6( values( '2016-03-31' )),
   PARTITION p_7( values( '2016-04-30' )),
   PARTITION p_8( values( '2016-05-31' )),
   PARTITION p_9( values( '2016-06-30' )),
   PARTITION p_10( values( '2016-07-31' )),
   PARTITION p_11( values( '2016-08-31' )),
   PARTITION p_12( values( '2016-09-30' )),
   PARTITION p_13( values( '2016-10-31' )),
   PARTITION p_14( values( '2016-11-30' )),
   PARTITION p_15( values( '2016-12-31' )),
   PARTITION p_16( values( '2017-01-31' )),
   PARTITION p_17( values( '2017-02-28' )),
   PARTITION p_18( values( '2017-03-31' )),
   PARTITION p_19( values( '2017-04-30' )),
   PARTITION p_20( values( '2017-05-31' )),
   PARTITION p_21( values( '2017-06-30' )),
   PARTITION p_22( values( '2017-07-31' )),
   PARTITION p_23( values( '2017-08-31' )),
   PARTITION p_24( values( '2017-09-30' )),
   PARTITION p_25( values( '2017-10-31' )),
   PARTITION p_26( values( '2017-11-30' )),
   PARTITION p_27( values( '2017-12-31' )),
   PARTITION p_28( values( '2018-01-31' )),
   PARTITION p_29( values( '2018-02-28' )),
   PARTITION p_30( values( '2018-03-31' )),
   PARTITION p_31( values( '2018-04-30' )),
   PARTITION p_32( values( '2018-05-31' )),
   PARTITION p_33( values( '2018-06-30' )),
   PARTITION p_34( values( '2018-07-31' ))
)

;

insert into risk.temp_kart 
select d_cmusno as cust_id,
	   kartno as card_id,
	   COALESCE(ikincilmusterino, musterino) as cust_no,
	   CAST(tarih_id as DATE) as tarih_id,
	   case when d_gecerli_eh = 'E' and kayitgecerli = 'Y' AND 
	   			 KARTSTATUSU='N' AND TAKIPSTATU='N' AND KARTALTSTATU is null then 1
	   			 else 0 end :: integer as valid_f
FROM  dw_out.dwd_kart
WHERE tarih_id not in ('2018-01-01','2017-01-01','2016-01-01','2018-07-30') 
	AND	d_gecerli_eh = 'E'
	AND	kartbastarih IS NOT NULL AND kartbastarih != '1900-01-01'
	AND	is_expired = 'N'
	--AND D_KREDIDEBIT='C' 
    --AND KAYITGECERLI='Y' 
    --AND KARTSTATUSU='N' 
    --AND TAKIPSTATU='N' 
    --AND KARTALTSTATU is null
;
GRANT ALL ON risk.temp_kart to public;

analyze risk.temp_kart ;
-------------------------------------------------------------------------

DROP TABLE IF EXISTS risk.statement_info_cc;

create table risk.statement_info_cc 
DISTRIBUTE BY HASH(cust_id) 
COMPRESS LOW 
AS
select 	kart.cust_id, 
		kart.card_id,
		kart.valid_f,
		stmt.as_of_dt,
		stmt.stmt_dt,
		stmt.due_dt,
		case when stmt.last_txn_dt>stmt_dt then 0 
			  else stmt.last_txn_amt end as last_txn_amt, 
		--stmt.last_txn_amt, 
		stmt.last_txn_dt,
		stmt.lmt,
		stmt.prev_stmt_dt,
		stmt.prev_due_dt,
		stmt.nxt_stmt_dt,
		stmt.nxt_due_dt,
		stmt.cl_brnd_tp_nm,
		stmt.cl_bin_clss_nm,
		stmt.cust_no,
		stmt.currency_code,
	    stmt.usd_rate,
	    stmt.eur_rate,
		stmt.min_amnt,
		stmt.min_amnt_cash,
		stmt.min_amnt_prch,
		stmt.min_amnt_others,
		--stmt.min_amnt_overlimit_cash,
   		--stmt.min_amnt_overlimit_prch,
		stmt.total_amnt,
		stmt.c_limit,
		stmt.total_amnt/stmt.c_limit as CC_LMT_UTL,
		min_amnt/total_amnt as min_paym_ratio
from risk.temp_kart kart
join risk.temp_kredi1 stmt 
	on 	kart.cust_no =  stmt.cust_no and 
		kart.tarih_id = stmt.as_of_dt and
		kart.card_id = stmt.ctr_no
where cust_id is not null
-- order by cust_id asc, card_id asc, stmt_dt asc
--limit 10
;

GRANT ALL ON risk.statement_info_cc TO public;

analyze risk.statement_info_cc ;