/* Filtering Table */
DROP TABLE IF EXISTS risk.prep_statinfo; -- created by zeren
CREATE ANALYTIC TABLE risk.prep_statinfo
DISTRIBUTE BY HASH(cust_id)
AS
SELECT	cmusno as cust_id, hesno, sube, bankaurunid, i2.label 
FROM 	staging.pov_ybs_hesap_ortak_musteri as i1
JOIN	risk.ref_bankaurunid i2 -- should be updated.
	ON	i1.bankaurunid = i2.level0
WHERE	cmusno IN (SELECT cmusno FROM risk.prep_accnt_sts GROUP BY cmusno);

CREATE	INDEX risk_ps_index
	ON	risk.prep_statinfo_index (hesno, sube);

/* Table with Index */
CREATE ANALYTIC TABLE risk.kesit_part1
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih BETWEEN '2015-09-01' AND '2016-02-29';

CREATE 	INDEX risk_kesit_part1
	ON 	risk.kesit_part1 (hesno,sube);

CREATE ANALYTIC TABLE risk.kesit_part2
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih BETWEEN '2016-03-01' AND '2016-08-31';

CREATE 	INDEX risk_kesit_part2
	ON 	risk.kesit_part2 (hesno,sube);

CREATE ANALYTIC TABLE risk.kesit_part3
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih BETWEEN '2016-09-01' AND '2017-02-28';

CREATE 	INDEX risk_kesit_part3
	ON 	risk.kesit_part3 (hesno,sube);
	
CREATE ANALYTIC TABLE risk.kesit_part4
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih BETWEEN '2017-03-01' AND '2017-08-31';

CREATE 	INDEX risk_kesit_part4
	ON 	risk.kesit_part4 (hesno,sube);

CREATE ANALYTIC TABLE risk.kesit_part5
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih BETWEEN '2017-09-01' AND '2018-02-28';

CREATE 	INDEX risk_kesit_part5
	ON 	risk.kesit_part5 (hesno,sube);
	
CREATE ANALYTIC TABLE risk.kesit_part6
DISTRIBUTE BY HASH(hesno)
AS
SELECT	hesno, sube, faiz_orani, drm, tarih, tl_bky, parakod
FROM 	staging.pov_v_hes_kesit_v3
WHERE	tarih > '2018-02-28';

CREATE 	INDEX risk_kesit_part6
	ON 	risk.kesit_part6 (hesno,sube);
	
/* Joins */
CREATE 	TABLE risk.kesit_fil_part1
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part1 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

CREATE 	TABLE risk.kesit_fil_part2
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part2 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

CREATE 	TABLE risk.kesit_fil_part3
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part3 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

CREATE 	TABLE risk.kesit_fil_part4
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part4 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

CREATE 	TABLE risk.kesit_fil_part5
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part5 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

CREATE 	TABLE risk.kesit_fil_part6
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, label as Product_Name, tarih, drm as STATUS, parakod,
		CAST(faiz_orani AS NUMERIC) as INT_RATE, 
		SUM(tl_bky) as SUM_BALANCE
FROM	risk.kesit_part6 k 
JOIN	risk.prep_statinfo j1
	ON	k.hesno = j1.hesno
	AND	k.sube  = j1.sube
GROUP	BY cust_id, label, tarih, drm, faiz_orani, parakod
);

/* Clean Up */
DROP TABLE risk.kesit_part1;
DROP TABLE risk.kesit_part2;
DROP TABLE risk.kesit_part3;
DROP TABLE risk.kesit_part4;
DROP TABLE risk.kesit_part5;
DROP TABLE risk.kesit_part6;