
DROP TABLE IF EXISTS risk.krd_tkst_tah_detay;
create analytic table risk.krd_tkst_tah_detay DISTRIBUTE BY hash (Credit_No) compress as 

select a.*,
	   b.Coll_Principal_Amt,
	   b.Coll_Amt_of_Int,
	   b.Coll_Def_Int_Amt,
	   b.Cancellation_Status,
	   b.Cancellation_Date
	      
from (select tkst.taksitno as Payment_No,
			 tkst.krdno as Credit_No,
			 case when tkst.drm = 1 then 'UnPaid'
			 	  when tkst.drm = 2 then 'Paid'
			 	  when tkst.drm = 3 then 'EarlyClosed'
			 	  when tkst.drm = 4 then 'Cancelled'
			 	  else 'PartialPay' end ::varchar(20) as Payment_Status,
			 tkst.ana_para_tut as Principal_Amt,
			 tkst.faiz_tut as Amt_of_Int,
			 tkst.vade as Due_Date,   
		     tkst.sube as Branch_No,
		     tkst.istar as Trx_Date,
		     tkst.isl_kur as Trxt_Exch_Rate,
		     case when tkst.taksit_tip = 1 then 'Normal_Payment'
		     	  when tkst.taksit_tip = 2 then 'Pstpn_Int_Pay'
		     	  else 'Additional_Payment' end::varchar(50) as Payment_Type
	   
	   from "dw_out"."krd_taksit" tkst
	   --where tkst.krdno=15193820
	   )a
left join (select tah.taksitno,
			      sum(tah.ana_para_tut) as Coll_Principal_Amt,
			      sum(tah.faiz_tut) as Coll_Amt_of_Int,
			      sum(tah.gec_faiz_tut) as Coll_Def_Int_Amt,
			      tah.ipt_drm as Cancellation_Status,
			      tah.ipt_tar as Cancellation_Date
		  from "dw_out"."krd_taksit_tah" tah
		  group by tah.taksitno,
		  		   tah.sube,
		  		   tah.isl_kur,
		  		   tah.istar,
		  		   tah.krddegtlpno,
		  		   tah.ipt_drm,
		  		   tah.ipt_tar,
		  		   tah.ipt_sicilno,
		  		   tah.mas_tut) b on a.Payment_No = b.taksitno
;
GRANT ALL ON risk.krd_tkst_tah_detay TO public;

----------------------------------------------------------------------

DROP TABLE IF EXISTS risk.product_target_loan_base;

CREATE TABLE risk.product_target_loan_base DISTRIBUTE BY HASH(cust_id) compress AS

select tkst.*,
	   ukk.cmusno as Cust_ID,
	   ukk.tarih as DT,
	   ukk.bankaurunid as Bank_Product_Type_ID,
	   ukk.krdno as Product_ID,
	   ukk.hesno as Account_No,
	   ukk.krd_drm as Credit_Status,
	   ukk.toplam_odenen_taksit as Total_Paid_Installment,
	   ukk.toplam_kalan_taksit as Total_Remaining_Installment,
	   ukk.erken_odenen_taksit as Early_Paid_Installment,
	   ukk.son_taksit_vadesi as Final_Installment_Due_Date,
	   ukk.erken_odeme_tarihi as Early_Payment_Date,
	   ukk.en_kotu_odeme_performansi as Worst_Payment_Perfomance,
	   ukk.en_guncel_odeme_performansi as Recent_Payment_Perfomance,
	   ukk.toplam_gecikme_sayisi as Total_Default_Payment,
	   ukk.str_gecikme as Str_Default,
	   ukk.toplam_kalan_anapara as Total_Remaining_Principal_Amt,
	   ukk.odenen_taksit_tutari as Total_Paid_Installment_Amt,
	   ukk.kalan_taksit_tutari as Remaining_Installment_Amt,
	   ukk.toplam_taksit_sayisi as Number_of_Remaining_Installment,
	   ukk.toplam_taksit_tutari as Total_Installment_Amt,
	   ukk.ortalama_taksit_tutari as Average_Installment_Amt,
	   ukk.parakod as Currency_Code,
	   ukk.ac_tar as Openning_Date,
	   ukk.kap_tar as Closing_Date,
	   ukk.takip_drm as Follow_Up_Status,
	   ukk.yeni_musteri as New_Customer_Flag,
	   ukk.tkp_tar as Follow_Up_Date,
	   ukk.tkp_ana_para_tl_tut as Follow_Up_Principal_Amt,
	   ukk.faiz_orani as Interest_Rate,
	   ukk.kul_faiz_oran as Used_Interest_Rate,
	   ukk.cari_faiz_oran as Current_Interest_Rate

from risk.krd_tkst_tah_detay tkst
left join staging.pov_dwf_banka_urun_kesit_kredi ukk on tkst.Credit_No = ukk.krdno and
													   		date_part('month', tkst.Due_Date) = date_part('month', ukk.tarih) and 
												   			date_part('year', tkst.Due_Date) = date_part('year', ukk.tarih)

order by tkst.Credit_No,
		 tkst.Due_Date

;

GRANT ALL ON risk.product_target_loan_base TO public;
analyze risk.product_target_loan_base;

----------------------------------------------------------------------

DROP TABLE IF EXISTS risk.product_target_credit;
CREATE TABLE risk.product_target_credit DISTRIBUTE BY HASH(cust_id) compress AS

select ptlb.cust_id,
	   ptlb.Credit_No,
	   ptlb.bank_product_type_id as prod_key,
	   --bu.product_class,
	   case when ptlb.bank_product_type_id=2900 then 'Foreign Money Individual Financial Loan'
	   		when ptlb.bank_product_type_id=2901 then 'Foreign Money Office Loan'
	   		when ptlb.bank_product_type_id=2902 then 'Foreign Money Personal Loan'
	   		when ptlb.bank_product_type_id=2903 then 'Foreign Money Car Loan' else bu.product_class end as product_class, 
	   ptlb.due_date,
	   ptlb.trx_date,
	   (cast(trx_date as date) - cast(due_date as date)) as days_pst_due,
	   ptlb.payment_status,
	   ptlb.principal_amt,
	   ptlb.amt_of_int,
	   ptlb.coll_principal_amt,
	   ptlb.coll_amt_of_int,
	   ptlb.coll_def_int_amt,
	   ptlb.final_installment_due_date,
	   ptlb.early_payment_date
	   
from risk.product_target_loan_base ptlb
left join risk.ref_bankaurunid_updated_v2 bu on ptlb.bank_product_type_id = bu.level0
where Cust_ID is not null
;

GRANT ALL ON risk.product_target_credit TO public;
analyze risk.product_target_credit;


/*aagidakiler droplandi*/

/*
2900	Nakdi Banka Kaynakl YP Taksitli Bireysel Finansman Kredileri
2901	Nakdi Banka Kaynakl YP Taksitli yeri Kredileri
2902	Nakdi Banka Kaynakl YP Taksitli htiya Kredileri
2903	Nakdi Banka Kaynakl YP Taksitli Tat Kredileri

*/