-- Source of Customer Status

DROP TABLE IF EXISTS risk.full_stat;
CREATE ANALYTIC TABLE risk.full_stat
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	CAST(ACCOUNT_NO AS INTEGER) as cust_no,
		(CAST(card_no as bigint)+9876) as card_number,
		old_value as old_status,
		new_value as status,
		CAST(op_date AS DATE) as str_date,
		LEAD(CAST(op_date AS DATE), 1, NOW()::DATE) OVER (PARTITION BY ACCOUNT_NO ORDER BY op_date) as end_date
FROM	dw_out.mis_statement_history
WHERE	ACCOUNT_NO != '' AND ACCOUNT_NO != ' ' and card_no is not null and card_no != '' and card_no != ' ' 
--where account_no='1014338'/*en sonda bunu kaldir*/
;


/*this code is for check*/
/*
SELECT	CAST(ACCOUNT_NO AS INTEGER) as cust_no,
		(CAST(card_no as bigint)+9876) as card_number,
		old_value as old_status,
		new_value as status,
		CAST(op_date AS DATE) as str_date,
		LEAD(CAST(op_date AS DATE), 1, NOW()::DATE) OVER (PARTITION BY ACCOUNT_NO ORDER BY op_date) as end_date
FROM	dw_out.mis_statement_history
WHERE	ACCOUNT_NO = '2074040' */


----------------------------------------------

DROP TABLE IF EXISTS risk.pt_cc_dpd;
CREATE ANALYTIC TABLE risk.pt_cc_dpd
DISTRIBUTE BY HASH (cust_no) compress
AS
select stmt.cust_id,
	   stmt.card_id,
	   stmt.cust_no,
	   stmt.as_of_dt,
	   stmt.stmt_dt,
	   stmt.due_dt,
	   stmt.nxt_stmt_dt,
	   stmt.nxt_due_dt,
	   st.old_status,
	   st.status,
	   (st.end_date-st.str_date) as dpd,
	   st.str_date,
	   st.end_date

from risk.statement_info_cc stmt
left join risk.full_stat st 
		  on stmt.cust_no=st.cust_no 
		  and cast(stmt.card_id as bigint)=st.card_number and
	 	  --stmt.as_of_dt between st.str_date and st.end_date
	 	  st.str_date between stmt.due_dt and stmt.nxt_due_dt
where st.str_date is not null and st.status != 'N' /*and stmt.cust_no=1014338 en sonda bunu kaldir*/
order by as_of_dt desc,
		 st.str_date desc;

GRANT ALL on risk.pt_cc_dpd to public;

----------------------------------------------

DROP TABLE IF EXISTS risk.product_target_cc;
CREATE TABLE risk.product_target_cc
DISTRIBUTE BY HASH (cust_no) compress
AS
select stmt.cust_id,
	   stmt.card_id,
	   stmt.valid_f,
	   stmt.as_of_dt,
	   LEAD(CAST(stmt.as_of_dt AS DATE), 1, null) OVER (PARTITION BY stmt.card_id ORDER BY stmt.as_of_dt) as next_month,
	   stmt.stmt_dt,
	   stmt.due_dt,
	   stmt.nxt_stmt_dt,
	   stmt.nxt_due_dt,
	   st.old_status,
	   st.status,
	   --case when st.status != 'N' then (st.end_date-st.str_date) else 0 end as dpd,
	   (st.end_date-st.str_date) as dpd,
	   st.str_date,
	   st.end_date,
	   stmt.cust_no,
	   stmt.currency_code,
	   stmt.usd_rate,
	   stmt.eur_rate,
	   stmt.min_amnt,
	   stmt.total_amnt

from risk.statement_info_cc stmt
left join risk.pt_cc_dpd st 
		  on stmt.cust_no=st.cust_no 
		  and stmt.card_id=st.card_id
		  and stmt.as_of_dt = st.as_of_dt
--where stmt.cust_no=1014338 /*en sonda bunu kaldir*/
order by as_of_dt desc,
		 st.str_date desc;

GRANT ALL on risk.product_target_cc to public;

analyze risk.product_target_cc; 

-------------------------------------------------------
