DROP TABLE IF EXISTS RISK.BLM_Employment_Info_VAR;
CREATE FACT TABLE RISK.BLM_Employment_Info_VAR() 
DISTRIBUTE BY HASH(CUST_ID)
COMPRESS LOW
AS
(	select 
	 CUST_ID
	,CARD_ID
	,STMT_DT
	,TARGET
	
	,CASE WHEN salary_amt IS NULL THEN AVG(salary_amt) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE salary_amt END AS salary_amt
	,CASE WHEN credit_sc IS NULL THEN AVG(credit_sc) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE credit_sc END AS credit_sc
	,CASE WHEN salary_acct_cnt IS NULL THEN AVG(salary_acct_cnt) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE salary_acct_cnt END AS salary_acct_cnt
	,CASE WHEN avg_salary IS NULL THEN AVG(avg_salary) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE avg_salary END AS avg_salary
	,CASE WHEN top10pct_avg_salary IS NULL THEN AVG(top10pct_avg_salary) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE top10pct_avg_salary END AS top10pct_avg_salary
	,CASE WHEN top10pct_med_salary IS NULL THEN AVG(top10pct_med_salary) OVER (PARTITION BY (extract(year from STMT_DT)*100)+extract(MONTH from STMT_DT)) ELSE top10pct_med_salary END AS top10pct_med_salary
			
	
	,CASE WHEN salary_amt IS NULL THEN 1 ELSE 0 END AS salary_amt_NF
	,CASE WHEN credit_sc IS NULL THEN 1 ELSE 0 END AS credit_sc_NF
	,CASE WHEN salary_acct_cnt IS NULL THEN 1 ELSE 0 END AS salary_acct_cnt_NF
	,CASE WHEN avg_salary IS NULL THEN 1 ELSE 0 END AS avg_salary_NF
	,CASE WHEN top10pct_avg_salary IS NULL THEN 1 ELSE 0 END AS top10pct_avg_salary_NF
	,CASE WHEN top10pct_med_salary IS NULL THEN 1 ELSE 0 END AS top10pct_med_salary_NF

	
	from 
		(SELECT 
		DT.CUST_ID
		,CARD_ID
		,STMT_DT
		,TARGET
		,MAX(salary_amt) AS salary_amt 
		,MAX(credit_sc) AS credit_sc 
		,MAX(salary_acct_cnt) AS salary_acct_cnt 
		,MAX(avg_salary) AS avg_salary 
		,MAX(top10pct_avg_salary) AS top10pct_avg_salary
		,MAX(top10pct_med_salary) AS top10pct_med_salary
		FROM 
		RISK.CUST_DT_DUMMY AS DT
		LEFT OUTER JOIN
		risk.employer_employee AS EE
		ON
		EE.CUST_ID = DT.CUST_ID
		AND
		(to_date(substring(EE.yearmonth from 1 for 4)||'-'||to_char(to_number(substring(EE.yearmonth from 6 for 2), '99'), '09')||'-01', 'YYYY-MM-DD') + interval '1 month') - interval '1 day' BETWEEN STMT_DT - 30 AND STMT_DT
		LEFT OUTER JOIN
		risk.emp_info AS EI
		ON
		EI.emp_id = EE.employer_id
		GROUP BY 1,2,3,4	) as innerquery 
		
);

grant all on risk.BLM_Employment_Info_VAR to public;
analyze risk.BLM_Employment_Info_VAR;
 