DROP TABLE IF EXISTS RISK.blm_statement_info_vars;
CREATE TABLE RISK.blm_statement_info_vars
DISTRIBUTE BY HASH (CUST_ID)
AS
(SELECT
cust_id
,card_id
,stmt_dt
,target
,SUM(_1M*_VIPR) AS _1M_VIPR
,SUM(_1M*_CLMC) AS _1M_CLMC
,SUM(_1M*_MCGL) AS _1M_MCGL
,SUM(_1M*_VICL) AS _1M_VICL
,SUM(_1M*_MCPL) AS _1M_MCPL
,SUM(_1M*_MCST) AS _1M_MCST

,SUM(_1M*_OVR_LMT) AS _1M_OVR_LMT
,SUM(_3M*_OVR_LMT) AS _3M_OVR_LMT
,SUM(_6M*_OVR_LMT) AS _6M_OVR_LMT

,SUM(_1M*_total_amnt) AS _1M_total_amnt
,SUM(_3M*_total_amnt) AS _3M_total_amnt
,SUM(_6M*_total_amnt) AS _6M_total_amnt

,COUNT(distinct _1M*_currency_code) AS _1M_currency_code
,MAX(_1M*_last_tx_days) AS _1M_last_tx_days
,MAX(_1M*_cc_limit) AS _1M_cc_limit

,MAX(_1M*_cc_lmt_utl) AS _1M_cc_lmt_utl
,MAX(_3M*_cc_lmt_utl) AS _3M_cc_lmt_utl
,MAX(_6M*_cc_lmt_utl) AS _6M_cc_lmt_utl

FROM
	(SELECT
	DT.cust_id
	,DT.card_id
	,DT.stmt_dt
	,target
	,CASE WHEN cl_bin_clss_nm = 'Premier' THEN 1 ELSE 0 END AS _VIPR
	,CASE WHEN cl_bin_clss_nm = 'MasterCard' THEN 1 ELSE 0 END AS _CLMC
	,CASE WHEN cl_bin_clss_nm = 'MC Gold' THEN 1 ELSE 0 END AS _MCGL
	,CASE WHEN cl_bin_clss_nm = 'Classic' THEN 1 ELSE 0 END AS _VICL
	,CASE WHEN cl_bin_clss_nm = 'MC Platinium' THEN 1 ELSE 0 END AS _MCPL
	,CASE WHEN cl_bin_clss_nm = 'MC Standart' THEN 1 ELSE 0 END AS _MCST
	
	,CASE WHEN CC.stmt_dt BETWEEN DT.STMT_DT - INTEGER '31' AND DT.STMT_DT THEN 1 ELSE 0 END AS _1M
	,CASE WHEN CC.stmt_dt BETWEEN DT.STMT_DT - INTEGER '92' AND DT.STMT_DT THEN 1 ELSE 0 END AS _3M
	,CASE WHEN CC.stmt_dt BETWEEN DT.STMT_DT - INTEGER '184' AND DT.STMT_DT THEN 1 ELSE 0 END AS _6M
	
	,CASE WHEN cc_lmt_utl > 1 then 1 ELSE 0 END AS _OVR_LMT
	
	,currency_code AS _currency_code
	,CASE
		WHEN CC.stmt_dt IS NULL THEN 0
		WHEN CC.stmt_dt - CC.last_txn_dt < 0 THEN 0 
		ELSE CC.stmt_dt - CC.last_txn_dt 
		END AS _last_tx_days
	,coalesce(c_limit,0) AS _cc_limit
	,coalesce(cc_lmt_utl,0) AS _cc_lmt_utl 
	,coalesce(total_amnt,0) AS _total_amnt
	
	
	FROM
	RISK.CUST_DT_DUMMY AS DT
	LEFT OUTER JOIN
	risk.statement_info_cc AS CC
	ON
	CC.cust_id = DT.cust_id
	AND
	CC.stmt_dt <= DT.stmt_dt
	AND
	CC.valid_f = 1) AS INNER_TABLE
group by 1,2,3,4
);



GRANT ALL ON RISK.blm_statement_info_vars TO PUBLIC;
ANALYZE RISK.blm_statement_info_vars;

