
--/********************  customer_base_train ********************/
DROP TABLE IF EXISTS "risk"."blm_customer_base_train";
CREATE FACT TABLE "risk"."blm_customer_base_train"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT
              "cust_id"
              ,"card_id"
              ,"stmt_dt"
              ,"target"
FROM sample(
ON (SELECT *, 
CASE 
WHEN target = 0 THEN 'non default'
WHEN target = 1 THEN 'default'
END AS stratum FROM "risk"."blm_model_table")
ConditionOnColumn('stratum')
ConditionOn('non default', 'default')
SampleFraction('0.7', '0.7'))
);

GRANT ALL ON RISK.blm_customer_base_train TO PUBLIC;
ANALYZE RISK.blm_customer_base_train;

--/********************  customer_base_test ********************/

DROP TABLE IF EXISTS "risk"."blm_customer_base_test";
CREATE FACT TABLE "risk"."blm_customer_base_test"() DISTRIBUTE BY HASH("card_id") COMPRESS LOW AS (
SELECT
              "card_id"
              ,"cust_id"
              ,"stmt_dt"
              ,"target"
FROM "risk"."blm_model_table"
EXCEPT
SELECT
              "card_id"
              ,"cust_id"
              ,"stmt_dt"
              ,"target"
FROM "risk"."blm_customer_base_train"
);

GRANT ALL ON RISK.blm_customer_base_test TO PUBLIC;
ANALYZE RISK.blm_customer_base_test;


--/********************  train ADS ********************/

DROP TABLE IF EXISTS "risk"."blm_model_table_train";
CREATE FACT TABLE "risk"."blm_model_table_train"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT
blm_model_table.CUST_ID
,blm_model_table.CARD_ID
,blm_model_table.STMT_DT
,blm_model_table.TARGET
,first_teb_card
,last_prim_cc_iss
,number_actv_cc_6m
,has_virt_cc_6m
,last_supp_cc_iss
,limit_cc_6m
,salary_amt
,credit_sc
,salary_acct_cnt
,credit_sc_nf
,top10pct_med_salary_nf
,_1m_sbscr_insrnc_cnt
,_6m_sbscr_insrnc_cnt
,_6m_pmt_insrnc_sum
,_12m_pmt_insrnc_sum
,_6m_pmt_due_insrnc_sum
,_12m_pmt_due_insrnc_sum
,_1m_trf_amt_otg
,_1m_trf_amt_inter_bnk
,_6m_trf_amt_otg
,_6m_trf_amt_cc
,_6m_trf_frq_otg
,_6m_trf_frq_cc
,_1m_tot_amt_web0
,_1m_tot_amt_web1
,_1m_tot_frq_mc_shp_ctr_pct
,_1m_tot_frq_mc_clth_pct
,_1m_tot_frq_mc_fl_stnt_pct
,_1m_tot_frq_mc_tlcm_pct
,_1m_tot_frq_mc_eltrn_pct
,_1m_tot_frq_mc_hlth_pct
,_1m_tot_frq_mc_othr_pct
,_6m_tot_amt_web0
,_6m_tot_amt_web1
,_6m_tot_frq_web1
,_6m_tot_frq_lc1
,_6m_tot_frq_mc_clth_pct
,_6m_tot_frq_mc_srvc_pct
,_6m_tot_frq_mc_tlcm_pct
,_6m_tot_frq_mc_eltrn_pct
,_6m_tot_frq_mc_hlth_pct
,_6m_tot_frq_mc_othr_pct
,_6m_tot_frq_mc_fd_pct
,_6m_tot_frq_mc_trvl_pct
,_6m_tot_frq_mc_frntr_pct
,_6m_tot_frq_mc_ed_mtrl_pct
,_6m_tot_frq_mc_bdmt_pct
,_6m_tot_frq_mc_arprt_pct
,_6m_tot_frq_mc_srvc_prts_pct
,_al_rst_loan_cnt
,_1m_ovd_limit_ut
FROM
"risk"."blm_customer_base_train"
INNER JOIN
"risk"."blm_model_table"
ON
blm_customer_base_train.CUST_ID = blm_model_table.CUST_ID
AND
blm_customer_base_train.CARD_ID = blm_model_table.CARD_ID
AND 
blm_customer_base_train.STMT_DT = blm_model_table.STMT_DT 
);

GRANT ALL ON RISK.blm_model_table_train TO PUBLIC;
ANALYZE RISK.blm_model_table_train;


--/********************  Test ADS ********************/

DROP TABLE IF EXISTS "risk"."blm_model_table_test";
CREATE FACT TABLE "risk"."blm_model_table_test"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT
blm_model_table.CUST_ID
,blm_model_table.CARD_ID
,blm_model_table.STMT_DT
,blm_model_table.TARGET
,first_teb_card
,last_prim_cc_iss
,number_actv_cc_6m
,has_virt_cc_6m
,last_supp_cc_iss
,limit_cc_6m
,salary_amt
,credit_sc
,salary_acct_cnt
,credit_sc_nf
,top10pct_med_salary_nf
,_1m_sbscr_insrnc_cnt
,_6m_sbscr_insrnc_cnt
,_6m_pmt_insrnc_sum
,_12m_pmt_insrnc_sum
,_6m_pmt_due_insrnc_sum
,_12m_pmt_due_insrnc_sum
,_1m_trf_amt_otg
,_1m_trf_amt_inter_bnk
,_6m_trf_amt_otg
,_6m_trf_amt_cc
,_6m_trf_frq_otg
,_6m_trf_frq_cc
,_1m_tot_amt_web0
,_1m_tot_amt_web1
,_1m_tot_frq_mc_shp_ctr_pct
,_1m_tot_frq_mc_clth_pct
,_1m_tot_frq_mc_fl_stnt_pct
,_1m_tot_frq_mc_tlcm_pct
,_1m_tot_frq_mc_eltrn_pct
,_1m_tot_frq_mc_hlth_pct
,_1m_tot_frq_mc_othr_pct
,_6m_tot_amt_web0
,_6m_tot_amt_web1
,_6m_tot_frq_web1
,_6m_tot_frq_lc1
,_6m_tot_frq_mc_clth_pct
,_6m_tot_frq_mc_srvc_pct
,_6m_tot_frq_mc_tlcm_pct
,_6m_tot_frq_mc_eltrn_pct
,_6m_tot_frq_mc_hlth_pct
,_6m_tot_frq_mc_othr_pct
,_6m_tot_frq_mc_fd_pct
,_6m_tot_frq_mc_trvl_pct
,_6m_tot_frq_mc_frntr_pct
,_6m_tot_frq_mc_ed_mtrl_pct
,_6m_tot_frq_mc_bdmt_pct
,_6m_tot_frq_mc_arprt_pct
,_6m_tot_frq_mc_srvc_prts_pct
,_al_rst_loan_cnt
,_1m_ovd_limit_ut
FROM
"risk"."blm_customer_base_test"
INNER JOIN
"risk"."blm_model_table"
ON
blm_customer_base_test.CUST_ID = blm_model_table.CUST_ID
AND
blm_customer_base_test.CARD_ID = blm_model_table.CARD_ID
AND 
blm_customer_base_test.STMT_DT = blm_model_table.STMT_DT 
);

GRANT ALL ON RISK.blm_model_table_test TO PUBLIC;
ANALYZE RISK.blm_model_table_test;

--/******************** train 1 ********************/

DROP TABLE IF EXISTS risk.blm_collectıons_model_1_temp;
select * from GLM
(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.blm_model_table_train')
OutputTable('risk.blm_collectıons_model_1_temp')
ColumnNames('target','first_teb_card','last_prim_cc_iss','number_actv_cc_6m','has_virt_cc_6m','last_supp_cc_iss','limit_cc_6m','salary_amt','credit_sc','salary_acct_cnt','credit_sc_nf','top10pct_med_salary_nf','_1m_sbscr_insrnc_cnt','_6m_sbscr_insrnc_cnt','_6m_pmt_insrnc_sum','_12m_pmt_insrnc_sum','_6m_pmt_due_insrnc_sum','_12m_pmt_due_insrnc_sum')
--CategoricalColumns('maeducationalstatus','mamaritalstatus')
Family('LOGISTIC')
Link('LOGIT')
MaxIterNum('100')
Step('true')
);

GRANT ALL ON RISK.blm_collectıons_model_1_temp TO PUBLIC;
ANALYZE RISK.blm_collectıons_model_1_temp;

--/******************** train 3 ********************/

DROP TABLE IF EXISTS risk.blm_collectıons_model_3_temp;
select * from GLM
(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.blm_model_table_train')
OutputTable('risk.blm_collectıons_model_3_temp')
ColumnNames('target','_6m_tot_frq_mc_arprt_pct','_6m_tot_frq_mc_srvc_prts_pct','_6m_tot_frq_mc_frntr_pct','_6m_tot_frq_mc_ed_mtrl_pct','_6m_tot_frq_mc_bdmt_pct','_6m_tot_frq_mc_othr_pct','_6m_tot_frq_mc_fd_pct','_6m_tot_frq_mc_trvl_pct','_6m_tot_frq_mc_tlcm_pct','_6m_tot_frq_mc_eltrn_pct','_6m_tot_frq_mc_hlth_pct','_6m_tot_frq_lc1','_6m_tot_frq_mc_clth_pct','_6m_tot_frq_mc_srvc_pct','_6m_tot_amt_web0','_6m_tot_amt_web1','_6m_tot_frq_web1','_1m_tot_frq_mc_eltrn_pct','_1m_tot_frq_mc_hlth_pct','_1m_tot_frq_mc_othr_pct','_1m_tot_frq_mc_clth_pct','_1m_tot_frq_mc_fl_stnt_pct','_1m_tot_frq_mc_tlcm_pct','_1m_tot_amt_web0','_1m_tot_amt_web1','_1m_tot_frq_mc_shp_ctr_pct','first_teb_card','last_prim_cc_iss','number_actv_cc_6m','has_virt_cc_6m','last_supp_cc_iss','limit_cc_6m','salary_amt','credit_sc','salary_acct_cnt','credit_sc_nf','top10pct_med_salary_nf','_1m_sbscr_insrnc_cnt','_6m_sbscr_insrnc_cnt','_6m_pmt_insrnc_sum','_12m_pmt_insrnc_sum','_6m_pmt_due_insrnc_sum','_12m_pmt_due_insrnc_sum','_1m_trf_amt_otg','_1m_trf_amt_inter_bnk','_6m_trf_amt_otg','_6m_trf_amt_cc','_6m_trf_frq_otg','_6m_trf_frq_cc')
--CategoricalColumns('maeducationalstatus','mamaritalstatus')
Family('LOGISTIC')
Link('LOGIT')
MaxIterNum('100')
--Step('true')
);

GRANT ALL ON RISK.blm_collectıons_model_3_temp TO PUBLIC;
ANALYZE RISK.blm_collectıons_model_3_temp;


SELECT
*
FROM
risk.blm_collectıons_model_3_temp;


--/******************** train 4 ********************/

--After keepıng only the useful varıables that have one star or more.

DROP TABLE IF EXISTS risk.blm_collectıons_model_4_temp;
select * from GLM
(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.blm_model_table_train')
OutputTable('risk.blm_collectıons_model_4_temp')
ColumnNames('target','_6m_tot_frq_mc_arprt_pct','_6m_tot_frq_mc_srvc_prts_pct','_al_rst_loan_cnt','_6m_tot_frq_mc_frntr_pct','_6m_tot_frq_mc_ed_mtrl_pct','_6m_tot_frq_mc_bdmt_pct','_6m_tot_frq_mc_othr_pct','_6m_tot_frq_mc_fd_pct','_6m_tot_frq_mc_trvl_pct','_6m_tot_frq_mc_tlcm_pct','_6m_tot_frq_mc_eltrn_pct','_6m_tot_frq_lc1','_6m_tot_frq_mc_clth_pct','_6m_tot_frq_mc_srvc_pct','_6m_tot_amt_web0','_6m_tot_amt_web1','_1m_tot_frq_mc_eltrn_pct','_1m_tot_frq_mc_hlth_pct','_1m_tot_frq_mc_othr_pct','_1m_tot_frq_mc_clth_pct','_1m_tot_frq_mc_fl_stnt_pct','_1m_tot_frq_mc_tlcm_pct','_1m_tot_amt_web0','_1m_tot_amt_web1','_1m_tot_frq_mc_shp_ctr_pct','first_teb_card','last_prim_cc_iss','last_supp_cc_iss','limit_cc_6m','salary_amt','credit_sc','salary_acct_cnt','top10pct_med_salary_nf','_1m_sbscr_insrnc_cnt','_6m_sbscr_insrnc_cnt','_12m_pmt_insrnc_sum','_12m_pmt_due_insrnc_sum','_6m_trf_amt_cc','_6m_trf_frq_otg','_6m_trf_frq_cc')
--CategoricalColumns('maeducationalstatus','mamaritalstatus')
Family('LOGISTIC')
--Link('LOGIT')
MaxIterNum('100')
--Step('true')
);

GRANT ALL ON RISK.blm_collectıons_model_4_temp TO PUBLIC;
ANALYZE RISK.blm_collectıons_model_4_temp;

SELECT
*
FROM
risk.blm_collectıons_model_4_temp

--/********************  Collectıons Model Scoring ********************/

DROP TABLE IF EXISTS RISK.blm_collections_model_4_temp_score;
CREATE TABLE RISK.blm_collections_model_4_temp_score
DISTRIBUTE BY HASH (CUST_ID)
AS
(SELECT
*
FROM
GLMPredict(
ON RISK.blm_model_table_test
MODELTABLE('RISK.blm_collectıons_model_4_temp')
ACCUMULATE('target', 'CUST_ID', 'CARD_ID', 'STMT_DT')
FAMILY('LOGISTIC')
LINK('LOGIT'))
);

GRANT ALL ON RISK.blm_collections_model_4_temp_score TO PUBLIC;
ANALYZE RISK.blm_collections_model_4_temp_score;

SELECT
*
FROM
RISK.blm_collections_model_4_temp_score;

-----------------------------------------------------------
--------------------------Gini Calculation-----------------
-----------------------------------------------------------

SELECT
'Model 4' model_type, 
max(cm_diff_p)*100 ks_value, 
sum((fpr - fpr_lead) * tpr)*100 auc, 
((sum((fpr - fpr_lead) * tpr))*2 - 1)*100 gini_coeff, 
(((sum((fpr - fpr_lead) * tpr))- .5)*2)*100 gini_coeff_2
FROM
(
	SELECT
	fitted_value, 
	count_positive, 
	count_negative, 
	count_all, 
	cm_positive,
	cm_negative, 
	cm_all, 
	cm_pos_p,
	cm_neg_p, 
	abs(cm_pos_p - cm_neg_p) cm_diff_p, 
	tpr, 
	fpr, 
	LEAD(fpr, 1, 0) OVER (ORDER BY fitted_value ASC) fpr_lead
	FROM
	(
		SELECT
		fitted_value, 
		count_positive, 
		count_negative, 
		count_all, 
		cm_positive,
		cm_negative, 
		cm_all, 
		cm_positive / SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) cm_pos_p,
		cm_negative / SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) cm_neg_p, 
		1 - (cm_positive / SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) tpr, 
		1 - (cm_negative / SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) fpr 
		FROM
		(
			SELECT
			fitted_value, 
			count_positive, 
			count_negative, 
			count_all, 
			SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_positive,
			SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_negative, 
			SUM(count_all) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_all 
			FROM
			(
				SELECT 
				fitted_value, 
				SUM(CASE WHEN target=1 THEN 1 ELSE 0 END) count_positive, 
				SUM(CASE WHEN target=0 THEN 1 ELSE 0 END) count_negative, 
				COUNT(*) count_all
				FROM risk.blm_collections_model_4_temp_score
				GROUP BY 1
				ORDER BY 1 DESC
			) x1
		) x2
	) x3
) x4

--------------------------------------------------------------------
-------------------------Sessıon wıth the team----------------------
--------------------------------------------------------------------

DROP TABLE IF EXISTS risk.blm_collectıons_model_0_temp; -- Selected columns
select * from GLM
(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.blm_model_table_train')
OutputTable('risk.blm_collectıons_model_0_temp')
ColumnNames('target','limit_cc_6m' ,'_6m_tot_amt_web1')
Family('LOGISTIC')
Link('LOGIT')
MaxIterNum('100')
--Step('true')
);


DROP TABLE IF EXISTS risk.blm_collectıons_model_0_temp; -- Selected columns
select * from Forest_drive
(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.blm_model_table_train')
OutputTable('risk.blm_collectıons_model_0_temp')
NumericInputs('limit_cc_6m','_6m_tot_frq_lc1','_6m_tot_amt_web0','_6m_tot_frq_web1','_6m_tot_amt_web1','_1m_tot_amt_web0','_6m_trf_frq_otg','_1m_tot_amt_web1','_6m_tot_frq_mc_clth_pct','first_teb_card','_6m_trf_frq_cc','_6m_trf_amt_otg','_1m_ovd_limit_ut','_1m_tot_frq_mc_clth_pct','number_actv_cc_6m','_6m_tot_frq_mc_eltrn_pct','_6m_tot_frq_mc_srvc_pct','has_virt_cc_6m','_1m_trf_amt_inter_bnk','_6m_tot_frq_mc_frntr_pct','_1m_trf_amt_otg','_6m_trf_amt_cc','_1m_tot_frq_mc_shp_ctr_pct','_6m_sbscr_insrnc_cnt','last_supp_cc_iss','_1m_tot_frq_mc_eltrn_pct','_6m_tot_frq_mc_hlth_pct','_6m_tot_frq_mc_bdmt_pct','_6m_tot_frq_mc_ed_mtrl_pct','_6m_tot_frq_mc_srvc_prts_pct','_1m_tot_frq_mc_fl_stnt_pct','_12m_pmt_insrnc_sum','_1m_tot_frq_mc_othr_pct','_6m_pmt_insrnc_sum','_1m_sbscr_insrnc_cnt','_1m_tot_frq_mc_hlth_pct','_6m_tot_frq_mc_arprt_pct','_6m_tot_frq_mc_othr_pct','_6m_tot_frq_mc_trvl_pct','_6m_pmt_due_insrnc_sum','_12m_pmt_due_insrnc_sum','_6m_tot_frq_mc_tlcm_pct','salary_amt','_1m_tot_frq_mc_tlcm_pct','last_prim_cc_iss','_6m_tot_frq_mc_fd_pct','_al_rst_loan_cnt','credit_sc_nf','top10pct_med_salary_nf')
Response('target')
NumTrees(50)
MaxDepth(5)
MinNodeSize(5)
);

SELECT
*
from
RISK.blm_collectıons_model_0_temp


_6m_tot_amt_web1
_1m_tot_amt_web0
_6m_trf_frq_otg
_1m_tot_amt_web1
_6m_tot_frq_mc_clth_pct
first_teb_card
_6m_trf_frq_cc
_6m_trf_amt_otg
_1m_ovd_limit_ut
---------------------------------
_6m_tot_frq_web1
---------------------------------
_6m_tot_frq_lc1
_6m_tot_amt_web0


--------------------------------------------------------------------
-------------------------GLM Score----------------------------------
--------------------------------------------------------------------

DROP TABLE IF EXISTS RISK.blm_collections_model_0_temp_score;
CREATE TABLE RISK.blm_collections_model_0_temp_score
DISTRIBUTE BY HASH (CUST_ID)
AS
(SELECT
*
FROM
GLMPredict(
ON RISK.blm_model_table_test
MODELTABLE('RISK.blm_collectıons_model_0_temp')
ACCUMULATE('target', 'CUST_ID', 'CARD_ID', 'STMT_DT')
FAMILY('LOGISTIC')
LINK('LOGIT'))
);

--------------------------------------------------------------------
----------------------Forest Score----------------------------------
--------------------------------------------------------------------

DROP TABLE IF EXISTS RISK.blm_collections_model_0_temp_scr;
CREATE TABLE RISK.blm_collections_model_0_temp_scr
DISTRIBUTE BY HASH (JOINKEY)
AS
(SELECT
JOINKEY
,prediction as fitted_value
FROM
Forest_predict(
ON RISK.blm_model_table_test
Forest('RISK.blm_collectıons_model_0_temp')
NumericInputs('limit_cc_6m','_6m_tot_frq_lc1','_6m_tot_amt_web0','_6m_tot_frq_web1','_6m_tot_amt_web1','_1m_tot_amt_web0','_6m_trf_frq_otg','_1m_tot_amt_web1','_6m_tot_frq_mc_clth_pct','first_teb_card','_6m_trf_frq_cc','_6m_trf_amt_otg','_1m_ovd_limit_ut','_1m_tot_frq_mc_clth_pct','number_actv_cc_6m','_6m_tot_frq_mc_eltrn_pct','_6m_tot_frq_mc_srvc_pct','has_virt_cc_6m','_1m_trf_amt_inter_bnk','_6m_tot_frq_mc_frntr_pct','_1m_trf_amt_otg','_6m_trf_amt_cc','_1m_tot_frq_mc_shp_ctr_pct','_6m_sbscr_insrnc_cnt','last_supp_cc_iss','_1m_tot_frq_mc_eltrn_pct','_6m_tot_frq_mc_hlth_pct','_6m_tot_frq_mc_bdmt_pct','_6m_tot_frq_mc_ed_mtrl_pct','_6m_tot_frq_mc_srvc_prts_pct','_1m_tot_frq_mc_fl_stnt_pct','_12m_pmt_insrnc_sum','_1m_tot_frq_mc_othr_pct','_6m_pmt_insrnc_sum','_1m_sbscr_insrnc_cnt','_1m_tot_frq_mc_hlth_pct','_6m_tot_frq_mc_arprt_pct','_6m_tot_frq_mc_othr_pct','_6m_tot_frq_mc_trvl_pct','_6m_pmt_due_insrnc_sum','_12m_pmt_due_insrnc_sum','_6m_tot_frq_mc_tlcm_pct','salary_amt','_1m_tot_frq_mc_tlcm_pct','last_prim_cc_iss','_6m_tot_frq_mc_fd_pct','_al_rst_loan_cnt','credit_sc_nf','top10pct_med_salary_nf')
IDCol('JOINKEY')
)
);


DROP TABLE IF EXISTS RISK.blm_collections_model_0_temp_score;
CREATE TABLE RISK.blm_collections_model_0_temp_score
DISTRIBUTE BY HASH (CUST_ID)
AS
(SELECT
target, CUST_ID, CARD_ID, STMT_DT, blm_collections_model_0_temp_scr.fitted_value
from
RISK.blm_collections_model_0_temp_scr
INNER JOIN
RISK.blm_model_table_test
ON
blm_collections_model_0_temp_scr.JOINKEY = blm_model_table_test.JOINKEY
);



GRANT ALL ON RISK.blm_collections_model_0_temp_score TO PUBLIC;
ANALYZE RISK.blm_collections_model_0_temp_score;


-----------------------------------------------------------
--------------------------Gini Calculation-----------------
-----------------------------------------------------------


SELECT
              'Model 2' model_type, 
              max(cm_diff_p)*100 ks_value, 
              sum((fpr - fpr_lead) * tpr)*100 auc, 
              ((sum((fpr - fpr_lead) * tpr))*2 - 1)*100 gini_coeff, 
              (((sum((fpr - fpr_lead) * tpr))- .5)*2)*100 gini_coeff_2
FROM
(
SELECT
              fitted_value, 
              count_positive, 
              count_negative, 
              count_all, 
              cm_positive,
              cm_negative, 
              cm_all, 
              cm_pos_p,
              cm_neg_p, 
              abs(cm_pos_p - cm_neg_p) cm_diff_p, 
              tpr, 
              fpr, 
              LEAD(fpr, 1, 0) OVER (ORDER BY fitted_value ASC) fpr_lead
FROM
(
SELECT
              fitted_value, 
              count_positive, 
              count_negative, 
              count_all, 
              cm_positive,
              cm_negative, 
              cm_all, 
              cm_positive / SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) cm_pos_p,
              cm_negative / SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) cm_neg_p, 
              1 - (cm_positive / SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) tpr, 
              1 - (cm_negative / SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) fpr 
FROM
(
SELECT
              fitted_value, 
              count_positive, 
              count_negative, 
              count_all, 
              SUM(count_positive) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_positive,
              SUM(count_negative) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_negative, 
              SUM(count_all) OVER (ORDER BY fitted_value ASC ROWS UNBOUNDED PRECEDING) cm_all 
FROM
(
SELECT 
              fitted_value, 
              SUM(CASE WHEN target=1 THEN 1 ELSE 0 END) count_positive, 
              SUM(CASE WHEN target=0 THEN 1 ELSE 0 END) count_negative, 
              COUNT(*) count_all
FROM risk.blm_collections_model_0_temp_score
GROUP BY 1
ORDER BY 1 DESC
) x1
) x2
) x3
) x4

