 /* CREATED BY : KAZIM ANIL EREN
  * CREATED ON : 2018-08-28
  * EDITED  ON : 2018-10-12
 */

-- JANUARY, 2018.
 
/* Creating Information on Salary */
DROP TABLE IF EXISTS risk.maas_tarihler; 
CREATE	ANALYTIC TABLE risk.maas_tarihler
DISTRIBUTE BY REPLICATION
AS
SELECT	CAST('2017-08-01' as DATE) as frst_date, 
		CAST('2017-10-31' as DATE) as last_date;
GRANT 	ALL ON risk.maas_tarihler to public;

DROP TABLE IF EXISTS risk.odenen_maas;
CREATE ANALYTIC TABLE risk.odenen_maas
DISTRIBUTE BY HASH(emp_id)
AS
	SELECT	firma_cmusno as emp_id, 
			calisan_cmusno as cmusno, 
			ROUND(SUM(tut_tl) / 3, 2) as maas -- salary info from salary accounts.
	FROM	dw_out.dwf_maas_kesit maas
		JOIN staging.pov_dwd_kon_musteri kon_mus on maas.calisan_cmusno=kon_mus.cmusno 
	        and kon_mus.mus_tip=2 and kon_mus.d_ref_mus_drm='1' 
			and kon_mus.portfoy_tip in('8','4') 
			and kon_mus.ref_mus_dosya in ('K', '') 
	JOIN	risk.maas_tarihler tarih
		ON	1 = 1
	WHERE	tarih >= frst_date
		AND	tarih <= last_date
	GROUP	BY firma_cmusno, calisan_cmusno;
GRANT ALL ON risk.odenen_maas to public; 

/* Necessary Steps for Top 10 PCT */
DROP TABLE IF EXISTS risk.maas_sira;
CREATE ANALYTIC TABLE risk.maas_sira
DISTRIBUTE BY HASH(emp_id)
AS
	SELECT	om.emp_id, 
			cmusno,
			maas,
			SALARY_ACCT_CNT,
			CAST(100.0 * DENSE_RANK() OVER (PARTITION BY om.emp_id ORDER BY maas DESC) / SALARY_ACCT_CNT AS DECIMAL(8,4)) AS yuzde,
			DENSE_RANK() OVER (PARTITION BY om.emp_id ORDER BY maas DESC) AS sira
	FROM 	risk.odenen_maas om
	JOIN	(SELECT emp_id, 
					count(cmusno) as SALARY_ACCT_CNT 
		 	FROM risk.odenen_maas 
		 	GROUP BY emp_id) om2
		ON	om.emp_id = om2.emp_id;
GRANT ALL ON risk.maas_sira to public; 

/* Top10 Median Calculation */
DROP TABLE IF EXISTS risk.maas_ortanca;
CREATE ANALYTIC TABLE risk.maas_ortanca
DISTRIBUTE BY HASH(emp_id)
AS
SELECT	emp_id,
		ROUND(AVG(maas), 2) as TOP10PCT_MED_SALARY
FROM	(
	SELECT	ms1.*, 
			TOP10_CNT,
			CASE WHEN TOP10_CNT % 2 = 1 THEN
				CASE WHEN 	CEIL(TOP10_CNT / 2.0) = sira 
					THEN 1 ELSE 0 END
				WHEN TOP10_CNT % 2 = 0 THEN
				CASE WHEN 	sira = CEIL((TOP10_CNT+1) / 2.0) OR 
							sira = FLOOR((TOP10_CNT+1) / 2.0)
					THEN 1 ELSE 0 END
				WHEN SALARY_ACCT_CNT < 10 THEN 1
				ELSE NULL END AS MEDIAN_CHECK
	FROM	risk.maas_sira ms1
	JOIN	(
		SELECT	emp_id,
				COUNT(*) as TOP10_CNT
		FROM	risk.maas_sira
		WHERE	yuzde <= 10
		GROUP	BY emp_id
			) ms2
		ON	ms1.emp_id = ms2.emp_id	
		) mqry -- median query
WHERE	median_check = 1
GROUP	BY emp_id;
GRANT ALL ON risk.maas_ortanca to public; 

/* Creating Data for Credit Score */
DROP TABLE IF EXISTS risk.ref_kkb_score_oct17;
CREATE ANALYTIC TABLE risk.ref_kkb_score_oct17
DISTRIBUTE BY HASH(CMUSNO)
AS
SELECT	bd1.CMUSNO,
		MAX(KKB_256_KKB_SCORE) AS CREDIT_SC
FROM	RISK.BUREAU_DATA bd1
JOIN	(SELECT CMUSNO, 
				MAX(KKB_LAST_INQ_DATE) AS MAX_DATE 
		 FROM 	RISK.BUREAU_DATA
		 WHERE	KKB_LAST_INQ_DATE < '2017-11-01'
	 	 GROUP	BY CMUSNO
	 	 ) bd2
	ON	bd1.CMUSNO = bd2.CMUSNO
	AND	bd1.KKB_LAST_INQ_DATE = bd2.MAX_DATE
GROUP	BY bd1.CMUSNO;
GRANT ALL ON risk.ref_kkb_score_oct17 to public;

/* Final Table Creation */
DROP TABLE IF EXISTS risk.emp_info_oct17;
CREATE TABLE risk.emp_info_oct17
DISTRIBUTE BY HASH (emp_id)
AS (
SELECT	avg_salary.emp_id as EMP_ID, -- employer ID
		CREDIT_SC, -- Credit Score
		SALARY_ACCT_CNT, -- Amount of Salary Accounts
		AVG_SALARY, -- OVERALL AVERAGE
		TOP10PCT_AVG_SALARY, -- TOP 10 PCT AVERAGE
		TOP10PCT_MED_SALARY  -- TOP 10 PCT MEDIAN
FROM	(SELECT	emp_id, 
				ROUND(AVG(maas), 2) AS AVG_SALARY,
				COUNT(*) AS SALARY_ACCT_CNT
		 FROM risk.odenen_maas 
		 GROUP BY emp_id
		 ) avg_salary
LEFT JOIN	risk.ref_kkb_score_oct17 kkb
	ON		avg_salary.emp_id = kkb.cmusno
LEFT JOIN	risk.maas_ortanca mo 
	ON		avg_salary.emp_id = mo.emp_id
LEFT JOIN	(SELECT	emp_id,
					ROUND(AVG(maas), 2) as TOP10PCT_AVG_SALARY
			 FROM	risk.maas_sira
			 WHERE	yuzde <= 10 OR SALARY_ACCT_CNT < 10
			 GROUP 	BY emp_id
			 ) avg_top10salary
	ON		avg_salary.emp_id = avg_top10salary.emp_id
);

GRANT ALL ON risk.emp_info_oct17 to public;

DROP TABLE risk.maas_tarihler;
DROP TABLE risk.odenen_maas;
DROP TABLE risk.maas_sira;
DROP TABLE risk.maas_ortanca;