/* End of table */
CREATE	ANALYTIC TABLE risk.last_days_of_month
DISTRIBUTE BY REPLICATION
AS
SELECT	trx_date
FROM	(
	SELECT 	distinct(trx_date) as trx_date 
	FROM 	risk.merchant_segment_table
		) dis_date -- distinct dates from the table.
WHERE	trx_date = CAST( CAST( date_trunc('month', trx_date) AS DATE) + interval '1 month' AS DATE) - 1;
GRANT ALL ON risk.last_days_of_month to public;

/* Preparation for CC Spending */
DROP TABLE IF EXISTS risk.prep_kart_harcama;
CREATE	TABLE risk.prep_kart_harcama
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT	cust_id, card_id, trx_date, Monthly_Spending, Monthly_Trx
FROM	(
	SELECT	cust_id, 
			card_id, 
			date_part('year', trx_date) as Year, 
			date_part('month', trx_date) as Month,
			ROUND(sum(trx_amt_tl), 2) as Monthly_Spending,
			sum(trx_cnt) as Monthly_Trx
	FROM	risk.merchant_segment_table
	WHERE	trx_date IN (SELECT * FROM risk.last_days_of_month)
		AND ( 
			(ISLEMKODU ='BI' and ISLEMSUBKODU ='IN')
			OR	(ISLEMKODU ='BK' and ISLEMSUBKODU in ('EW','MW','SA','WS'))
			OR	ISLEMKODU IN ('SA','NA')
			)
		AND	late_instalment_flg = 0
	GROUP	BY cust_id, card_id, date_part('year', trx_date), date_part('month', trx_date)
	) a
JOIN	(SELECT trx_date, date_part('year', trx_date) as Year, date_part('month', trx_date) as Month FROM risk.last_days_of_month) b
	ON	a.Year  = b.Year
	AND	a.Month = b.Month
	);
	
CREATE 	INDEX index_prep_kart_harcama
	ON 	risk.prep_kart_harcama (card_id);
	
GRANT ALL ON risk.prep_kart_harcama to public;