DROP TABLE IF EXISTS risk.temp_pol_cust;
CREATE 	ANALYTIC TABLE risk.temp_pol_cust
DISTRIBUTE	BY HASH(cmusno)
COMPRESS LOW
AS
SELECT	cmusno  
		,own.hesno
		,own.sube
		,tree_family_code 
		,tree_single_code
		,ybs.hes_tur
		,ybs.vadekod
		,ybs.bankaurunid
		,kap_tar
		,krd_no
FROM	staging.pov_ybs_hesap_ortak_musteri ybs	
JOIN  "dw_out"."dw_hesap_ktr" own 
	ON ybs.sube = own.sube 
   and ybs.hesno = own.hesno
where cmusno in (select cust_id from risk.cust_info_monthly_v02)
	;

DROP TABLE IF EXISTS risk.temp_pol_cust_t2;
CREATE 	ANALYTIC TABLE risk.temp_pol_cust_t2
DISTRIBUTE	BY HASH(cmusno)
COMPRESS LOW
AS
select a.*,b.label,
 case when tree_family_code is null then tree_family_code_v2
 	when tree_family_code is not null then tree_family_code
 		end as tree_family_code_v2,
 case when tree_single_code is null then tree_single_code_v2 
 	when tree_single_code is not null then tree_single_code
 		end as tree_single_code_v2 		
from risk.temp_pol_cust a
inner join "risk"."ref_bankaurunid_updated_v2" b
	on a.bankaurunid=b.level0
;

	
DROP TABLE IF EXISTS risk.PROD_OWNSHIP;
CREATE TABLE risk.PROD_OWNSHIP
DISTRIBUTE	BY HASH(cust_id)
COMPRESS LOW
AS
SELECT	cust_id, 
		Yr_Mnth,
		tree_family_code_v2, 
		tree_single_code_v2,
		SUM(Balance) as Balance, -- Balance
		COUNT(hesno) as Prod_Cnt -- Qty_Owned
FROM	(
	SELECT	 ybs.cmusno as cust_id
			,hskst.hesno as hesno
			,hskst.sube as sube 
			,tarih as Yr_Mnth
			,parakod as currency
			,hskst.tl_bky as Balance
			,hskst.faiz_orani as Int_Rate
			,tree_family_code_v2 
			,tree_single_code_v2
	FROM risk.temp_pol_cust_t2 ybs
	JOIN (	
		select	 hesno
				,sube
				,tl_bky
				,faiz_orani
				,tarih
				,parakod 
				,krd_no
		from	staging.pov_v_hes_kesit_v3
		where	drm ='A' and tarih in (select * from risk.last_days_of_month) --account is open
		) hskst
		ON	ybs.hesno=hskst.hesno 
		and	ybs.sube=hskst.sube
		) innerquery
GROUP	BY cust_id, Yr_Mnth, tree_family_code_v2, tree_single_code_v2;

grant all on risk.PROD_OWNSHIP to public;
analyze risk.PROD_OWNSHIP;






