

DROP TABLE IF EXISTS risk.PROD_OWNSHIP;
CREATE TABLE risk.PROD_OWNSHIP()
DISTRIBUTE BY HASH(cust_id)
AS (
SELECT 	cust_id, 
		Yr_Mnth,
		Prod_Type,
		SUM(Loan_Balance) as Balance, -- Balance
		COUNT(Loan_Balance) as Prod_Cnt -- Qty_Owned
FROM   (
       SELECT 	cust_id, Yr_Mnth, Prod_Key, Loan_Balance, Paid_Amount,              
				CASE WHEN Prod_Key = 1174 THEN 'DEK Bireysel Finansman Kredisi'
					 WHEN Prod_Key IN (1175, 1185) THEN 'DEK İhtiyaç Kredileri'
					 WHEN Prod_Key = 1176 THEN 'DEK İşyeri Kredileri'
					 WHEN Prod_Key = 1340 THEN 'DEK Konut Kredisi'
					 WHEN Prod_Key = 1177 THEN 'DEK Taşıt Kredileri'
					 WHEN Prod_Key = 1182 THEN 'Nakdi Banka Kaynaklı YP Taksitli Konut Kredileri'
					 WHEN Prod_Key = 1178 THEN 'TL Bireysel Finansman Kredisi'
					 WHEN Prod_Key IN (1179, 1188) THEN 'TL İhtiyaç Kredileri'
					 WHEN Prod_Key = 1180 THEN 'TL İşyeri Kredileri'
					 WHEN Prod_Key = 1341 THEN 'TL Konut Kredileri'
					 WHEN Prod_Key IN (1181, 1190) THEN 'TL Taşıt Kredileri'
					 ELSE NULL END AS Prod_Type
       FROM   (
              SELECT cmusno as cust_id, tarih as Yr_Mnth, bankaurunid as Prod_Key,
                     krd_drm, toplam_odenen_taksit, 
                     tl_bky as Loan_Balance, 
                     tl_bky - lag(tl_bky, 1, 0) over(partition by cmusno, krdno order by tarih) as Paid_Amount 
              FROM	staging.pov_dwf_banka_urun_kesit_kredi
              WHERE	bankaurunid IN (1177, 1181, 1190, 1340, 1341, 1175, 1179, 1183, 1184, 1185, 1188, 1174, 1178, 1180, 1176, 1189)
                    --AND for a possible date filter.      
              ) hamveri
       WHERE  Loan_Balance < 0 OR Paid_Amount > 0
       ) filtrelendi
GROUP BY cust_id, Yr_Mnth, Prod_Type
);

GRANT ALL ON risk.PROD_OWNSHIP TO public;

DROP 	TABLE IF EXISTS risk.temp_pol;
CREATE 	ANALYTIC TABLE risk.temp_pol
DISTRIBUTE	BY HASH(cmusno)
AS
SELECT	cmusno, 
		attribute as Prod_Key, 
		tarih_id as Yr_Mnth,
		Value as Balance
FROM 	unpivot (
	ON (
	SELECT	cmusno, tarih_id 
			,MEVDUAT_VDLI_TL_BOLUNMUS as VADELI_TL
			,MEVDUAT_VDLI_YP_BOLUNMUS as VADELI_YP
			,MEVDUAT_VDSIZ_TL_BOLUNMUS as VADESIZ_TL
			,MEVDUAT_VDSIZ_YP_BOLUNMUS as VADESIZ_YP
			,KMH_RISK as OVD
			,KMH_LIMIT 
			,MEVDUAT_VDLI_TL_AY_TL_ORT_BOL
			,MEVDUAT_VDLI_YP_AY_TL_ORT_BOL
			,MEVDUAT_VDSIZ_TL_AY_TL_ORT_BOL
			,MEVDUAT_VDSIZ_YP_AY_TL_ORT_BOL
			,KMH_AY_TL_ORT_BOLUNMUS
	FROM	staging.pov_dwf_kon_varlik
	WHERE	tarih_id IN (SELECT * FROM risk.last_days_of_month)
		) 
		colsToUnpivot('VADELI_TL', 'VADELI_YP', 'VADESIZ_TL', 'VADESIZ_YP', 'OVD', 'KMH_LIMIT', 'MEVDUAT_VDLI_TL_AY_TL_ORT_BOL',
					  'MEVDUAT_VDLI_YP_AY_TL_ORT_BOL', 'MEVDUAT_VDSIZ_TL_AY_TL_ORT_BOL', 'MEVDUAT_VDSIZ_YP_AY_TL_ORT_BOL', 'KMH_AY_TL_ORT_BOLUNMUS')
		colsToAccumulate('cmusno', 'tarih_id')
	)
WHERE	value IS NOT NULL;

CREATE 	INDEX temp_po1 -- dont ask why I have written 1 instead of l
	ON 	risk.temp_pol (Prod_Key);
	
DROP	TABLE IF EXISTS risk.temp_accnt_cnt;
CREATE 	ANALYTIC TABLE risk.temp_accnt_cnt
DISTRIBUTE	BY HASH(cmusno)
AS
SELECT	cmusno, trx_date, lower(label) as Prod_Key, count(*) as PROD_CNT
FROM	staging.pov_ybs_hesap_ortak_musteri hom
JOIN	risk.last_days_of_month dom
	ON	hom.ac_tar  <= dom.trx_date
	AND	COALESCE(hom.kap_tar, DATE '2018-08-31') >= dom.trx_date
JOIN	risk.ref_bankaurunid_updated_v2 ref
	ON	hom.bankaurunid = ref.level0
GROUP	BY cmusno, trx_date, label;

CREATE 	INDEX temp_accnt_cn1 -- dont ask why I have written 1 instead of t
	ON 	risk.temp_accnt_cnt (Prod_Key);
	
/* Merger of Two Lover Tables */
INSERT	INTO risk.prod_ownship
SELECT	a.cmusno as cust_id,
		a.yr_mnth as yr_mnth,
		a.prod_key as prod_type,
		CAST(a.balance AS NUMERIC(18,2)) balance,
		b.prod_cnt
FROM	risk.temp_pol a
LEFT 	JOIN	risk.temp_accnt_cnt b
	ON	a.cmusno = b.cmusno
	AND	a.Yr_Mnth = b.trx_date
	AND	a.Prod_Key = b.Prod_key;
	
ANALYZE risk.prod_ownship;
	
DROP 	TABLE risk.temp_pol;
DROP	TABLE risk.temp_accnt_cnt;