-- Join Clause from ARES to d_cmusno & cc_no
CREATE ANALYTIC TABLE risk.ref_prod_target
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	d_cmusno as cust_id, COALESCE(ikincilmusterino, musterino) as cust_no, kartno as cc_no
FROM	staging.pov_dwd_kart
WHERE 	CAST(tarih_id as date) IN ('2017-10-31', '2017-12-31', '2017-08-31')
	AND	kartbastarih IS NOT NULL AND kartbastarih != '1900-01-01'
	AND	d_gecerli_eh = 'E'
	AND	is_expired   = 'N'
	AND D_KREDIDEBIT = 'C' 
    AND KAYITGECERLI = 'Y' 
    AND KARTSTATUSU  = 'N' 
    AND TAKIPSTATU   = 'N' 
    AND KARTALTSTATU IS NULL
GROUP	BY d_cmusno, COALESCE(ikincilmusterino, musterino), kartno;
	
CREATE INDEX index_ref_prod_target 
	ON risk.ref_target_table (cust_id, cc_no);
	
GRANT ALL on risk.ref_prod_target to public;

-- Source of information for statement dates.
DROP TABLE IF EXISTS risk.pt_1;
CREATE ANALYTIC TABLE risk.pt_1
DISTRIBUTE BY HASH (cc_no)
AS
SELECT	cust_id, cc_no, pmt_amt, min_amt, currency, stmt_dt, due_dt
FROM	(SELECT CAST(account_no as INTEGER) as cust_no, 
				min_amnt as min_amt, total_amnt as pmt_amt,
				CASE 	WHEN currency_code IN ('949', '0') THEN 'TL'
						WHEN currency_code = '840'		  THEN 'USD'
						WHEN currency_code = '978'		  THEN 'EUR'
					ELSE NULL END AS currency,
				TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD') as stmt_dt,
				TO_DATE(CAST(prev_due_date as CHAR(8)), 'YYYYMMDD') as due_dt
		 FROM 	dw_out.EOC_REDISCOUNT_SUMMARY_ALL
		) t1
JOIN	risk.ref_prod_target t2
	ON	t1.cust_no = t2.cust_no;

ANALYZE risk.pt_1; GRANT ALL ON risk.pt_1 to PUBLIC;

-- Source of information for money paid by the customer.
DROP TABLE IF EXISTS risk.pt_2;
CREATE ANALYTIC TABLE risk.pt_2
DISTRIBUTE BY HASH (cc_no)
AS
SELECT	cc_no, 
		coalesce(t1.trx_amt, 0) as trx_amt, coalesce(t1.trx_dt, t2.trx_dt) as trx_dt,
		stmt_dt, currency
FROM	(SELECT	kartno as cc_no, islemtutariorg as trx_amt, 	
				islemtarih as trx_dt, CAST(ekstretarihi AS DATE) as stmt_dt,
				CASE 	WHEN islemparabirimi IN ('949', '0') THEN 'TL'
						WHEN islemparabirimi = '840'		 THEN 'USD'
						WHEN islemparabirimi = '978'		 THEN 'EUR'
						ELSE NULL END AS currency 
		FROM	staging.pov_dwf_kart_harbilgi
		WHERE	OTC = '21'
			AND	islemparabirimi IN ('949', '0', '840', '949') -- For Nov 17 Case
		) t1
JOIN	(SELECT	DISTINCT(islemtarih) FROM	staging.pov_dwf_kart_harbilgi) t2
	ON	1=1

ANALYZE risk.pt_2; GRANT ALL ON risk.pt_2 to PUBLIC;
DROP TABLE risk.ref_target_table;

/*

SELECT	cc_no, currency, stmt_dt, trx_dt
FROM	
(
SELECT	cc_no, currency, stmt_dt, LEAD(stmt_dt, 1, CURRENT_DATE) OVER (PARTITION BY cc_no, currency ORDER BY trx_dt) as stmt_dt_1 
FROM	risk.pt_2
WHERE	stmt_dt IS NOT NULL or stmt_dt != '1900-01-01'
) t1
JOIN
( 
SELECT	DISTINCT(tarih_id) as trx_dt
FROM	staging.pov_dwf_kart_harbilgi
) t2 
	ON trx_dt >= stmt_dt_1
	AND	trx_dt < stmt_dt_1