﻿-- Source of information for statement and due dates. Also contains minimum amount to be paid.
DROP TABLE IF EXISTS risk.oct17_stmt;
CREATE ANALYTIC TABLE risk.oct17_stmt
DISTRIBUTE BY HASH (cust_no)
AS
SELECT 	CAST(account_no as INTEGER) as cust_no, 
		--min_amnt as min_amt, total_amnt as pmt_amt, 
		TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD') as stmt_dt, -- neden rediscount = prev_stmt
		TO_DATE(CAST(prev_due_date as CHAR(8)), 'YYYYMMDD') as due_dt
FROM 	dw_out.EOC_REDISCOUNT_SUMMARY_ALL
WHERE	min_amnt > 0
	AND	TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD') BETWEEN '2017-11-01' AND '2017-11-30'
GROUP	BY	CAST(account_no as INTEGER), 
			TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD'),
			TO_DATE(CAST(prev_due_date as CHAR(8)), 'YYYYMMDD');

-- Source of Customer Status
DROP TABLE IF EXISTS risk.oct17_stat;
CREATE ANALYTIC TABLE risk.oct17_stat
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	CAST(ACCOUNT_NO AS INTEGER) as cust_no, 
		new_value as status,
		CAST(op_date AS DATE) as str_date,
		LEAD(CAST(op_date AS DATE), 1, NOW()::DATE) OVER (PARTITION BY ACCOUNT_NO ORDER BY op_date) as end_date
FROM	dw_out.mis_statement_history
WHERE	ACCOUNT_NO != '' AND ACCOUNT_NO != ' ';	

-- Join Clause from ARES to d_cmusno & cc_no
DROP	TABLE IF EXISTS risk.ref_oct17_tt;
CREATE 	ANALYTIC TABLE risk.ref_oct17_tt
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	d_cmusno as cust_id, COALESCE(ikincilmusterino, musterino) as cust_no, kartno as cc_no
FROM	staging.pov_dwd_kart
WHERE 	CAST(tarih_id as date) = '2017-10-31' -- For Nov 17 Case
	AND	kartbastarih IS NOT NULL AND kartbastarih != '1900-01-01'
	AND	d_gecerli_eh = 'E'
	AND	is_expired   = 'N'
	AND D_KREDIDEBIT = 'C' 
    AND KAYITGECERLI = 'Y' 
    AND KARTSTATUSU  = 'N' 
    AND TAKIPSTATU   = 'N' 
    AND KARTALTSTATU IS NULL;
	
CREATE	INDEX index_ref_oct17_tt
	ON 	risk.ref_oct17_tt (cust_id, cc_no);
	
GRANT 	ALL on risk.ref_oct17_tt to public;

/* DPD Calculation */
DROP	TABLE IF EXISTS risk.dpd_oct17_tt;
CREATE	ANALYTIC TABLE	risk.dpd_oct17_tt
DISTRIBUTE BY HASH (cust_id)
AS
SELECT	ref.cust_id, ref.cc_no,  mt.stmt_dt, mt.due_dt, -- mt.min_amt, mt.pmt_amt,
		MIN(COALESCE(at2.str_date, NOW()::DATE) - at.end_date) as DPD 
		-- I have used LEFT JOIN & COALESCE in order to avoid missing non-payers who did not ever return to 'N' status. 
FROM	risk.oct17_stmt mt
JOIN	risk.oct17_stat at
	ON	mt.cust_no = at.cust_no 	-- singularity
	AND	mt.stmt_dt BETWEEN at.str_date AND at.end_date
	AND	at.status = 'N'				-- should be Normal before training period (and previous line) 
	AND due_dt = at.end_date 		-- status should change by due_dt 
LEFT JOIN	risk.oct17_stat at2
	ON	at.cust_no = at2.cust_no	-- singularity
	AND	at.end_date <= at2.str_date	-- new status must be newer than older status.
	AND	at2.status = 'N'			-- new status must be 'N' (DPD check)
JOIN	(	SELECT 	t2.cust_id, cust_no, cc_no
			FROM 	risk.cust_info_oct17 t1
			JOIN	risk.ref_oct17_tt t2
				ON	t1.cust_id = t2.cust_id
			GROUP	BY t2.cust_id, cust_no, cc_no
		) ref
	ON	mt.cust_no = ref.cust_no	-- should be individiual customer
GROUP	BY ref.cust_id, ref.cc_no, mt.stmt_dt, mt.due_dt; --  mt.min_amt, mt.pmt_amt

CREATE	INDEX index_dpd_oct17_tt
	ON 	risk.dpd_oct17_tt (cc_no);
	
GRANT 	ALL on risk.dpd_oct17_tt to public;

DROP	TABLE risk.oct17_stmt;
DROP	TABLE risk.oct17_stat;
DROP	TABLE risk.ref_oct17_tt;

/* Target Table */
DROP	TABLE IF EXISTS risk.target_oct17;
CREATE	ANALYTIC TABLE	risk.target_oct17
DISTRIBUTE BY HASH (cust_id)
AS
SELECT	cust_id, cc_no, stmt_dt,
		CASE WHEN DPD > 3 THEN 1 ELSE 0 END as target 
FROM	risk.dpd_oct17_tt;

CREATE	INDEX index_target_oct17
	ON 	risk.target_oct17 (cc_no);
	
GRANT 	ALL on risk.target_oct17 to public;
	
/* Gizem did not want obsolete work deleted.
-- Source of information for money paid by the customer.
DROP TABLE IF EXISTS risk.tt_2_nov17;
CREATE ANALYTIC TABLE risk.tt_2_nov17
DISTRIBUTE BY HASH (cc_no)
AS
SELECT	kartno as cc_no, islemtutariorg as trx_amt, 	
		islemtarih as trx_dt, CAST(ekstretarihi AS DATE) as stmt_dt,
		CASE 	WHEN islemparabirimi IN ('949', '0') THEN 'TL'
				WHEN islemparabirimi = '840'		 THEN 'USD'
				WHEN islemparabirimi = '978'		 THEN 'EUR'
				ELSE NULL END AS currency 
FROM	staging.pov_dwf_kart_harbilgi
WHERE	OTC = '21'
	AND	tarih_id > '2017-10-31'
	AND tarih_id < '2018-01-01'
	AND	islemparabirimi IN ('949', '0', '840', '978'); -- For Nov 17 Case

-- Source of information for previous month's status
DROP TABLE IF EXISTS risk.tt_filter_nov17;
CREATE ANALYTIC TABLE risk.tt_filter_nov17
DISTRIBUTE BY HASH (cust_no)
AS
SELECT 	CAST(ss_acc_no AS INTEGER) as cust_no
FROM	dw_out.CRD_CTR_SMY_HIST t1
JOIN	(SELECT	cust_no, min(stmt_dt) - 1 as dt FROM risk.tt_1 GROUP BY cust_no) t2
	ON	t2.cust_no = t1.ss_acc_no
	AND	t2.dt = t1.as_of_dt -- Date Filter. (Filtered by date via join: Nov17)
WHERE	(cl_worst_xtrt_Pymt_St_Tp_Code IS NULL OR cl_worst_xtrt_Pymt_St_Tp_Code = 'N')
	AND	CAST(ss_acc_no AS INTEGER) IN (	SELECT 	cust_no
										FROM 	risk.cust_info_oct17 t1
										WHERE	cust_id IN (SELECT cust_id FROM risk.ref_target_table_nov17)
										); -- Indiviudal Customers.

GRANT ALL ON risk.tt_filter to public;

-- Statements List 
DROP 	TABLE IF EXISTS risk.target_statements_nov17;
CREATE 	ANALYTIC TABLE risk.target_statements_nov17
DISTRIBUTE BY HASH(cc_no)
AS
SELECT	cust_id, cc_no, currency, 
		stmt_dt, LEAD(stmt_dt, 1, '2018-01-01') OVER (PARTITION BY cc_no, currency ORDER BY stmt_dt) as next_stmt_dt, -- date choice is not arbitrary. it is the day after the last date in tt_2 table.
		due_dt, min_amnt
FROM	risk.tt_1 t1
JOIN	risk.ref_target_table t2 -- inner because t1 and t2 has important filters.
	ON	CAST(t1.cust_no AS NUMERIC) = t2.cust_no;
	
CREATE 	INDEX index_target_statements
	ON	risk.target_statements (currency);

-- Empty table 
DROP 	TABLE IF EXISTS risk.target_nov17_step1;
CREATE 	ANALYTIC TABLE risk.target_nov17_step1
DISTRIBUTE BY HASH(cc_no)
AS
SELECT	CJ_Date as Trx_Dt, st.*
FROM	CJ_Dates_nov17 dt
JOIN	risk.target_statements_nov17 st -- or 
	ON	1 = 1
*/