-- Source of information for statement and due dates. Also contains minimum amount to be paid.
DROP TABLE IF EXISTS risk.aug17_stmt;
CREATE ANALYTIC TABLE risk.aug17_stmt
DISTRIBUTE BY HASH (cust_no)
AS
SELECT 	CAST(account_no as INTEGER) as cust_no, 
		--min_amnt as min_amt, total_amnt as pmt_amt, 
		TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD') as stmt_dt, -- neden rediscount = prev_stmt
		TO_DATE(CAST(prev_due_date as CHAR(8)), 'YYYYMMDD') as due_dt
FROM 	dw_out.EOC_REDISCOUNT_SUMMARY_ALL
WHERE	min_amnt > 0
	AND	TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD') BETWEEN '2017-09-01' AND '2017-09-30'
GROUP	BY	CAST(account_no as INTEGER), 
			TO_DATE(CAST(prev_stmt_date as CHAR(8)), 'YYYYMMDD'),
			TO_DATE(CAST(prev_due_date as CHAR(8)), 'YYYYMMDD');

-- Source of Customer Status
DROP TABLE IF EXISTS risk.aug17_stat;
CREATE ANALYTIC TABLE risk.aug17_stat
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	CAST(ACCOUNT_NO AS INTEGER) as cust_no, 
		new_value as status,
		CAST(op_date AS DATE) as str_date,
		LEAD(CAST(op_date AS DATE), 1, NOW()::DATE) OVER (PARTITION BY ACCOUNT_NO ORDER BY op_date) as end_date
FROM	dw_out.mis_statement_history
WHERE	ACCOUNT_NO != '' AND ACCOUNT_NO != ' ';	

-- Join Clause from ARES to d_cmusno & cc_no
DROP	TABLE IF EXISTS risk.ref_aug17_tt;
CREATE 	ANALYTIC TABLE risk.ref_aug17_tt
DISTRIBUTE BY HASH (cust_no)
AS
SELECT	d_cmusno as cust_id, COALESCE(ikincilmusterino, musterino) as cust_no, kartno as cc_no
FROM	staging.pov_dwd_kart
WHERE 	CAST(tarih_id as date) = '2017-08-31' -- For Nov 17 Case
	AND	kartbastarih IS NOT NULL AND kartbastarih != '1900-01-01'
	AND	d_gecerli_eh = 'E'
	AND	is_expired   = 'N'
	AND D_KREDIDEBIT = 'C' 
    AND KAYITGECERLI = 'Y' 
    AND KARTSTATUSU  = 'N' 
    AND TAKIPSTATU   = 'N' 
    AND KARTALTSTATU IS NULL;
	
CREATE	INDEX index_ref_aug17_tt
	ON 	risk.ref_aug17_tt (cust_id, cc_no);
	
GRANT 	ALL on risk.ref_aug17_tt to public;

/* DPD Calculation */
DROP	TABLE IF EXISTS risk.dpd_aug17_tt;
CREATE	ANALYTIC TABLE	risk.dpd_aug17_tt
DISTRIBUTE BY HASH (cust_id)
AS
SELECT	ref.cust_id, ref.cc_no,  mt.stmt_dt, mt.due_dt, -- mt.min_amt, mt.pmt_amt,
		MIN(COALESCE(at2.str_date, NOW()::DATE) - at.end_date) as DPD 
		-- I have used LEFT JOIN & COALESCE in order to avoid missing non-payers who did not ever return to 'N' status. 
FROM	risk.aug17_stmt mt
JOIN	risk.aug17_stat at
	ON	mt.cust_no = at.cust_no 	-- singularity
	AND	mt.stmt_dt BETWEEN at.str_date AND at.end_date
	AND	at.status = 'N'				-- should be Normal before training period (and previous line) 
	AND due_dt = at.end_date 		-- status should change by due_dt 
LEFT JOIN	risk.aug17_stat at2
	ON	at.cust_no = at2.cust_no	-- singularity
	AND	at.end_date <= at2.str_date	-- new status must be newer than older status.
	AND	at2.status = 'N'			-- new status must be 'N' (DPD check)
JOIN	(	SELECT 	t2.cust_id, cust_no, cc_no
			FROM 	risk.cust_info_aug17 t1
			JOIN	risk.ref_aug17_tt t2
				ON	t1.cust_id = t2.cust_id
			GROUP	BY t2.cust_id, cust_no, cc_no
		) ref
	ON	mt.cust_no = ref.cust_no	-- should be individiual customer
GROUP	BY ref.cust_id, ref.cc_no, mt.stmt_dt, mt.due_dt; --  mt.min_amt, mt.pmt_amt

CREATE	INDEX index_dpd_aug17_tt
	ON 	risk.dpd_aug17_tt (cc_no);
	
GRANT 	ALL on risk.dpd_aug17_tt to public;

DROP	TABLE risk.aug17_stmt;
DROP	TABLE risk.aug17_stat;
DROP	TABLE risk.ref_aug17_tt;

/* Target Table */
DROP	TABLE IF EXISTS risk.target_aug17;
CREATE	ANALYTIC TABLE	risk.target_aug17
DISTRIBUTE BY HASH (cust_id)
AS
SELECT	cust_id, cc_no, stmt_dt,
		CASE WHEN DPD > 3 THEN 1 ELSE 0 END as target 
FROM	risk.dpd_aug17_tt;

CREATE	INDEX index_target_aug17
	ON 	risk.target_aug17 (cc_no);
	
GRANT 	ALL on risk.target_aug17 to public;