DROP 	TABLE IF EXISTS risk.emp_date_interval; 
CREATE	TABLE risk.emp_date_interval()
DISTRIBUTE	BY HASH(calisan_cmusno)
AS (
	select
		calisan_cmusno , 
		firma_cmusno ,
		sum(tut_tl) sum_tut_tl,
		CAST(odm_tar_mon - 90 as DATE)  as start_date,
		odm_tar_mon  as end_date
	from
		(
		select 
			calisan_cmusno , 
			firma_cmusno ,
			tut_tl, 
			cast(date_trunc('month', cast(odm_tar as DATE)) as date) as odm_tar_mon
		from dw_out.dwf_maas_kesit
		where firma_cmusno IN (	SELECT	KARSI_CMUSNO as emp_id
								FROM	staging.pov_dwd_cmus_iliski
								WHERE	DRM = 'G' 
									AND	ILISKITURNO = 3
									AND	tarih = '2017-10-31'
															
									UNION ALL
														
								SELECT	CMUSNO as emp_id
								FROM	staging.pov_dwd_cmus_iliski
								WHERE	DRM = 'G' 
									AND	ILISKITURNO = 4
									AND	tarih = '2017-10-31')		
		)a
	group by calisan_cmusno, firma_cmusno, odm_tar_mon);
GRANT 	ALL ON risk.emp_date_interval to public;

DROP	TABLE IF EXISTS risk.emp_mon_salary; 
CREATE	TABLE risk.emp_mon_salary()
DISTRIBUTE	BY HASH(calisan_cmusno)
AS (
select 
		calisan_cmusno,
		firma_cmusno,
		cast(date_trunc('month', cast (odm_tar as date)) as date) odm_tar_s
	from dw_out.dwf_maas_kesit 			
	where firma_cmusno IN (	SELECT	KARSI_CMUSNO as emp_id
						FROM	staging.pov_dwd_cmus_iliski
						WHERE	DRM = 'G' 
							AND	ILISKITURNO = 3
							AND	tarih = '2017-10-31'
													
							UNION ALL
												
						SELECT	CMUSNO as emp_id
						FROM	staging.pov_dwd_cmus_iliski
						WHERE	DRM = 'G' 
							AND	ILISKITURNO = 4
							AND	tarih = '2017-10-31')	
		and calisan_cmusno not in (select distinct cmusno from staging.pov_dwd_kon_musteri where ref_mus_dosya='P')
	group by calisan_cmusno, firma_cmusno,date_trunc('month', cast (odm_tar as date))
	);
GRANT 	ALL ON risk.emp_mon_salary to public;

DROP	TABLE IF EXISTS risk.employer_employee;
CREATE	TABLE risk.employer_employee()
DISTRIBUTE	BY HASH(CUST_ID)
as(
select
	calisan_cmusno as cust_id,
	firma_cmusno as employer_id,
	extract(year from odm_tar_s)||'-'||extract(month from odm_tar_s) as yearmonth,
	salary_amt,
	case when salary_amt<2500 then 1
		when 2500<=salary_amt and salary_amt<5000 then 2
		when 5000<=salary_amt and salary_amt<7500 then 3
		when 7500<=salary_amt and salary_amt<10000 then 4
		when 10000<=salary_amt then 5
	end as tax_info /*gelir 2500lik araliklara bolunmustur. En dusuk gelir grubu 1 en yuksek gelir grubu 5 ile olacak sekilde flaglenmistir.*/
from
(
select 
	a.calisan_cmusno,
	a.firma_cmusno, 
	round(avg(sum_tut_tl),2) as salary_amt, 
	odm_tar_s 
from 
	(
	select
		calisan_cmusno , 
		firma_cmusno ,
		sum_tut_tl,
		start_date,
		end_date
	from risk.emp_date_interval
	)a
inner join 
	(
	select 
		calisan_cmusno,
		firma_cmusno,
		odm_tar_s
	from risk.emp_mon_salary
	)b
on a.calisan_cmusno=b.calisan_cmusno
and a.firma_cmusno=b.firma_cmusno
where
	start_Date<=odm_tar_s
	and end_date>=odm_tar_s
group by a.calisan_cmusno,a.firma_cmusno, odm_tar_s
) x
);
		
GRANT 	ALL ON risk.employer_employee to public;