/********************  customer_base_train ********************/
DROP TABLE IF EXISTS "public"."customer_base_train";
CREATE FACT TABLE "public"."customer_base_train"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
	 "cust_id"
	,"card_no"
	,"stmt_dt"
	,"target"
FROM sample(
ON (SELECT *, 
CASE 
WHEN target = 0 THEN 'non default'
WHEN target = 1 THEN 'default'
END AS stratum FROM "public"."customer_base")
ConditionOnColumn('stratum')
ConditionOn('non default', 'default')
SampleFraction('0.7', '0.7'))
);
/********************  customer_base_test ********************/

DROP TABLE IF EXISTS "public"."customer_base_test";
CREATE FACT TABLE "public"."customer_base_test"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
 	 "card_no"
	,"cust_id"
	,"stmt_dt"
	,"target"
FROM "public"."customer_base"
EXCEPT
SELECT
 	 "card_no"
	,"cust_id"
	,"stmt_dt"
	,"target"
FROM "public"."customer_base_train"
);
/********************  merchseg_str1_stp1 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp1";
CREATE FACT TABLE "public"."merchseg_str1_stp1"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,COUNT(DISTINCT "_twmVC0"."card_no") AS "distinct_cards_per_merchant"
	,SUM("_twmVC0"."freq_of_use") AS "total_transaction_count"
	,SUM("_twmVC0"."transaction_amount") AS "total_transaction_amount"
	,SUM("_twmVC0"."transaction_amount") / CAST(SUM("_twmVC0"."freq_of_use") AS FLOAT) AS "average_transaction_amount"
FROM "public"."merchant_segmentation_source" AS "_twmVC0"
GROUP BY 1
);
/********************  merchseg_str1_stp2 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp2";
CREATE FACT TABLE "public"."merchseg_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."merchant_id" AS "merchant_id"
	,COUNT(DISTINCT (EXTRACT('YEAR' FROM "_twmVC0"."statement_date") * 100) + EXTRACT('MONTH' FROM "_twmVC0"."statement_date")) AS "card_active_months"
FROM "public"."merchant_segmentation_source" AS "_twmVC0"
GROUP BY 1, 2
);
/********************  merchseg_str1_stp3 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp3";
CREATE FACT TABLE "public"."merchseg_str1_stp3"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,AVG("_twmVC0"."card_active_months") AS "average_active_month"
	,COUNT(DISTINCT "_twmVC0"."card_no") AS "active_cards"
FROM "public"."merchseg_str1_stp2" AS "_twmVC0"
GROUP BY 1
HAVING COUNT(DISTINCT "_twmVC0"."card_no") > 100
);
/********************  merchseg_str1_stp4 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp4";
CREATE FACT TABLE "public"."merchseg_str1_stp4"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,COUNT(DISTINCT "_twmVC0"."card_no") AS "merchant_total_cards"
	,COUNT(DISTINCT "_twmVC1"."card_no") AS "merchant_total_default_cards"
	,COUNT(DISTINCT "_twmVC1"."card_no") / CAST(COUNT(DISTINCT "_twmVC0"."card_no") AS FLOAT) AS "merchant_card_default_ratio"
FROM "public"."merchseg_str1_stp2" AS "_twmVC0"
	LEFT OUTER JOIN "public"."card_default_source" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
GROUP BY 1
HAVING COUNT(DISTINCT "_twmVC0"."card_no") > 2
);
/********************  merchseg_str1_stp5 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp5";
CREATE FACT TABLE "public"."merchseg_str1_stp5"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,"_twmVC0"."average_transaction_amount" AS "average_transaction_amount"
	,"_twmVC1"."active_cards" AS "active_cards"
	,"_twmVC1"."average_active_month" AS "average_active_month"
	,"_twmVC2"."merchant_card_default_ratio" AS "merchant_card_default_ratio"
FROM "public"."merchseg_str1_stp1" AS "_twmVC0"
	INNER JOIN "public"."merchseg_str1_stp3" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
	INNER JOIN "public"."merchseg_str1_stp4" AS "_twmVC2"
		ON "_twmVC0"."merchant_id" = "_twmVC2"."merchant_id"
);
/********************  merchseg_str1_stp6 ********************/

DROP TABLE IF EXISTS "public"."merchseg_str1_stp6";
CREATE FACT TABLE "public"."merchseg_str1_stp6"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT
 "A"."merchant_id" AS "merchant_id"
,("active_cards" - "_twm_mean2") / "_twm_std2" AS "active_cards"
,("average_active_month" - "_twm_mean3") / "_twm_std3" AS "average_active_month"
,("average_transaction_amount" - "_twm_mean4") / "_twm_std4" AS "average_transaction_amount"
,("merchant_card_default_ratio" - "_twm_mean5") / "_twm_std5" AS "merchant_card_default_ratio"
FROM "public"."merchseg_str1_stp5" "A"
,(SELECT
 AVG("active_cards" ) AS "_twm_mean2"
,STDDEV_POP(CAST("active_cards" AS FLOAT)) AS "_twm_std2"
,AVG("average_active_month" ) AS "_twm_mean3"
,STDDEV_POP(CAST("average_active_month" AS FLOAT)) AS "_twm_std3"
,AVG("average_transaction_amount" ) AS "_twm_mean4"
,STDDEV_POP(CAST("average_transaction_amount" AS FLOAT)) AS "_twm_std4"
,AVG("merchant_card_default_ratio" ) AS "_twm_mean5"
,STDDEV_POP(CAST("merchant_card_default_ratio" AS FLOAT)) AS "_twm_std5"
FROM "public"."merchseg_str1_stp5"
) "B"
);
/********************  8_Merchant_Segments ********************/
drop table if exists merchant_segmentation_score;
drop table if exists merchant_segmentation_centroids;
SELECT
*
FROM
kmeans(
ON (SELECT 1)
PARTITION BY 1
--domain('153.65.146.154')
---database('beehive')
InputTable('merchseg_str1_stp6')
OutputTable('merchant_segmentation_centroids')
--userid('beehive')
--password('beehive')
NumberK ('4')
--Threshold ('0.01')
--MaxIterNum ('170')
ClusteredOutput ('merchant_segmentation_score')
);
/*
CREATE FACT TABLE merchant_segmentation_score() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
	SELECT *
	FROM kmeansplot (
	ON merchseg_str1_stp6 as a PARTITION BY ANY
	ON merchant_segmentation_centroids as b DIMENSION 
	CENTROIDSTABLE('b')
	)
);*/
/********************  merchseg_usg_sprd_str1_stp1 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp1";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,COALESCE("_twmVC1"."clusterid", 99) AS "clusterid"
	,SUM("_twmVC0"."transaction_amount") AS "transaction_amount"
	,SUM("_twmVC0"."freq_of_use") AS "transaction_count"
FROM "public"."merchant_segmentation_source" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchant_segmentation_score" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
GROUP BY 1, 2
);
/********************  merchseg_usg_sprd_str1_stp2 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp2";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."clusterid" AS "clusterid"
	,"_twmVC0"."transaction_count" AS "transaction_count"
	,"_twmVC0"."transaction_amount" AS "transaction_amount"
	,SUM("_twmVC0"."transaction_count") OVER (PARTITION BY "_twmVC0"."card_no" ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total_transaction_count"
	,SUM("_twmVC0"."transaction_amount") OVER (PARTITION BY "_twmVC0"."card_no" ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total_transaction_amount"
FROM "public"."merchseg_usg_sprd_str1_stp1" AS "_twmVC0"
);
/********************  merchseg_usg_sprd_str1_stp3 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp3";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."clusterid" AS "clusterid"
	,"_twmVC0"."transaction_count" / CAST("_twmVC0"."total_transaction_count" AS FLOAT) AS "freq_of_use_share"
	,"_twmVC0"."transaction_amount" / CAST("_twmVC0"."total_transaction_amount" AS FLOAT) AS "amount_share"
FROM "public"."merchseg_usg_sprd_str1_stp2" AS "_twmVC0"
WHERE ("_twmVC0"."total_transaction_amount" > 0) AND ("_twmVC0"."total_transaction_count" > 0)
);
/********************  merchseg_usg_sprd_str1_stp4 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp4";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp4"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "C0_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "C1_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "C2_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "C3_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "C4_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "C5_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "C6_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "C7_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "C99_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "C0_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "C1_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "C2_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "C3_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "C4_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "C5_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "C6_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "C7_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "C99_amount_share"
	,"_twmVC0"."freq_of_use_share" AS "freq_of_use_share"
	,"_twmVC0"."amount_share" AS "amount_share"
FROM "public"."merchseg_usg_sprd_str1_stp3" AS "_twmVC0"
);
/********************  merchseg_usg_sprd_str1_stp5 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp5";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp5"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C0_transaction_share") AS "_C0_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C1_transaction_share") AS "_C1_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C2_transaction_share") AS "_C2_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C3_transaction_share") AS "_C3_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C4_transaction_share") AS "_C4_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C5_transaction_share") AS "_C5_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C6_transaction_share") AS "_C6_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C7_transaction_share") AS "_C7_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C99_transaction_share") AS "_C99_transaction_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C0_amount_share") AS "_C0_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C1_amount_share") AS "_C1_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C2_amount_share") AS "_C2_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C3_amount_share") AS "_C3_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C4_amount_share") AS "_C4_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C5_amount_share") AS "_C5_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C6_amount_share") AS "_C6_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C7_amount_share") AS "_C7_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C99_amount_share") AS "_C99_amount_share"
FROM "public"."merchseg_usg_sprd_str1_stp4" AS "_twmVC0"
GROUP BY 1
);
/********************  merchseg_usg_sprd_str1_stp6 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp6";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp6"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."_C0_transaction_share" AS "_C0_transaction_share"
	,"_twmVC1"."_C1_transaction_share" AS "_C1_transaction_share"
	,"_twmVC1"."_C2_transaction_share" AS "_C2_transaction_share"
	,"_twmVC1"."_C3_transaction_share" AS "_C3_transaction_share"
	,"_twmVC1"."_C4_transaction_share" AS "_C4_transaction_share"
	,"_twmVC1"."_C5_transaction_share" AS "_C5_transaction_share"
	,"_twmVC1"."_C6_transaction_share" AS "_C6_transaction_share"
	,"_twmVC1"."_C7_transaction_share" AS "_C7_transaction_share"
	,"_twmVC1"."_C99_transaction_share" AS "_C99_transaction_share"
	,"_twmVC1"."_C0_amount_share" AS "_C0_amount_share"
	,"_twmVC1"."_C1_amount_share" AS "_C1_amount_share"
	,"_twmVC1"."_C2_amount_share" AS "_C2_amount_share"
	,"_twmVC1"."_C3_amount_share" AS "_C3_amount_share"
	,"_twmVC1"."_C4_amount_share" AS "_C4_amount_share"
	,"_twmVC1"."_C5_amount_share" AS "_C5_amount_share"
	,"_twmVC1"."_C6_amount_share" AS "_C6_amount_share"
	,"_twmVC1"."_C7_amount_share" AS "_C7_amount_share"
	,"_twmVC1"."_C99_amount_share" AS "_C99_amount_share"
FROM "public"."customer_base" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchseg_usg_sprd_str1_stp5" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  merchseg_usg_sprd_str1_stp7 ********************/

DROP TABLE IF EXISTS "public"."merchseg_usg_sprd_str1_stp7";
CREATE FACT TABLE "public"."merchseg_usg_sprd_str1_stp7"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."_C0_transaction_share", 0) AS "_C0_transaction_share"
	,COALESCE("_twmVC0"."_C1_transaction_share", 0) AS "_C1_transaction_share"
	,COALESCE("_twmVC0"."_C2_transaction_share", 0) AS "_C2_transaction_share"
	,COALESCE("_twmVC0"."_C3_transaction_share", 0) AS "_C3_transaction_share"
	,COALESCE("_twmVC0"."_C4_transaction_share", 0) AS "_C4_transaction_share"
	,COALESCE("_twmVC0"."_C5_transaction_share", 0) AS "_C5_transaction_share"
	,COALESCE("_twmVC0"."_C6_transaction_share", 0) AS "_C6_transaction_share"
	,COALESCE("_twmVC0"."_C7_transaction_share", 0) AS "_C7_transaction_share"
	,COALESCE("_twmVC0"."_C99_transaction_share", 0) AS "_C99_transaction_share"
	,COALESCE("_twmVC0"."_C0_amount_share", 0) AS "_C0_amount_share"
	,COALESCE("_twmVC0"."_C1_amount_share", 0) AS "_C1_amount_share"
	,COALESCE("_twmVC0"."_C2_amount_share", 0) AS "_C2_amount_share"
	,COALESCE("_twmVC0"."_C3_amount_share", 0) AS "_C3_amount_share"
	,COALESCE("_twmVC0"."_C4_amount_share", 0) AS "_C4_amount_share"
	,COALESCE("_twmVC0"."_C5_amount_share", 0) AS "_C5_amount_share"
	,COALESCE("_twmVC0"."_C6_amount_share", 0) AS "_C6_amount_share"
	,COALESCE("_twmVC0"."_C7_amount_share", 0) AS "_C7_amount_share"
	,COALESCE("_twmVC0"."_C99_amount_share", 0) AS "_C99_amount_share"
FROM "public"."merchseg_usg_sprd_str1_stp6" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp1 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp1";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,(EXTRACT('YEAR' FROM "_twmVC0"."statement_date") * 100) + EXTRACT('MONTH' FROM "_twmVC0"."statement_date") AS "stmt_year_month"
	,COALESCE("_twmVC1"."clusterid", 99) AS "clusterid"
	,SUM("_twmVC0"."transaction_amount") AS "amount"
	,SUM("_twmVC0"."freq_of_use") AS "freq_of_use"
	,"_twmVC2"."target" AS "target"
FROM "public"."merchant_segmentation_source" AS "_twmVC0"
	LEFT OUTER JOIN "public"."target_table_source" AS "_twmVC2"
		ON "_twmVC0"."card_no" = "_twmVC2"."card_no"
	LEFT OUTER JOIN "public"."merchant_segmentation_score" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
GROUP BY 1, 2, 3, 6
);
/********************  sax_on_merchseg_str1_stp2 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp2";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."amount" AS "amount"
	,"_twmVC0"."freq_of_use" AS "freq_of_use"
	,"_twmVC0"."target" AS "target"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "clusterid_0"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "clusterid_1"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "clusterid_2"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "clusterid_3"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "clusterid_4"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "clusterid_5"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "clusterid_6"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "clusterid_7"
	,CASE WHEN "_twmVC0"."clusterid" = 8 THEN 1 ELSE 0 END AS "clusterid_8"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "clusterid_99"
FROM "public"."sax_on_merchseg_str1_stp1" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp3 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp3";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,MAX("_twmVC0"."clusterid_0" * "_twmVC0"."amount") AS "clusterid_0_amount"
	,MAX("_twmVC0"."clusterid_1" * "_twmVC0"."amount") AS "clusterid_1_amount"
	,MAX("_twmVC0"."clusterid_2" * "_twmVC0"."amount") AS "clusterid_2_amount"
	,MAX("_twmVC0"."clusterid_3" * "_twmVC0"."amount") AS "clusterid_3_amount"
	,MAX("_twmVC0"."clusterid_4" * "_twmVC0"."amount") AS "clusterid_4_amount"
	,MAX("_twmVC0"."clusterid_5" * "_twmVC0"."amount") AS "clusterid_5_amount"
	,MAX("_twmVC0"."clusterid_6" * "_twmVC0"."amount") AS "clusterid_6_amount"
	,MAX("_twmVC0"."clusterid_7" * "_twmVC0"."amount") AS "clusterid_7_amount"
	,MAX("_twmVC0"."clusterid_8" * "_twmVC0"."amount") AS "clusterid_8_amount"
	,MAX("_twmVC0"."clusterid_99" * "_twmVC0"."amount") AS "clusterid_99_amount"
	,MAX("_twmVC0"."clusterid_0" * "_twmVC0"."freq_of_use") AS "clusterid_0_freq"
	,MAX("_twmVC0"."clusterid_1" * "_twmVC0"."freq_of_use") AS "clusterid_1_freq"
	,MAX("_twmVC0"."clusterid_2" * "_twmVC0"."freq_of_use") AS "clusterid_2_freq"
	,MAX("_twmVC0"."clusterid_3" * "_twmVC0"."freq_of_use") AS "clusterid_3_freq"
	,MAX("_twmVC0"."clusterid_4" * "_twmVC0"."freq_of_use") AS "clusterid_4_freq"
	,MAX("_twmVC0"."clusterid_5" * "_twmVC0"."freq_of_use") AS "clusterid_5_freq"
	,MAX("_twmVC0"."clusterid_6" * "_twmVC0"."freq_of_use") AS "clusterid_6_freq"
	,MAX("_twmVC0"."clusterid_7" * "_twmVC0"."freq_of_use") AS "clusterid_7_freq"
	,MAX("_twmVC0"."clusterid_8" * "_twmVC0"."freq_of_use") AS "clusterid_8_freq"
	,MAX("_twmVC0"."clusterid_99" * "_twmVC0"."freq_of_use") AS "clusterid_99_freq"
FROM "public"."sax_on_merchseg_str1_stp2" AS "_twmVC0"
GROUP BY 1, 2, 3
);
/********************  sax_on_merchseg_str1_stp4 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp4";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp4"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."clusterid_0_amount", 0) AS "clusterid_0_amount"
	,COALESCE("_twmVC0"."clusterid_1_amount", 0) AS "clusterid_1_amount"
	,COALESCE("_twmVC0"."clusterid_2_amount", 0) AS "clusterid_2_amount"
	,COALESCE("_twmVC0"."clusterid_3_amount", 0) AS "clusterid_3_amount"
	,COALESCE("_twmVC0"."clusterid_4_amount", 0) AS "clusterid_4_amount"
	,COALESCE("_twmVC0"."clusterid_5_amount", 0) AS "clusterid_5_amount"
	,COALESCE("_twmVC0"."clusterid_6_amount", 0) AS "clusterid_6_amount"
	,COALESCE("_twmVC0"."clusterid_7_amount", 0) AS "clusterid_7_amount"
	,COALESCE("_twmVC0"."clusterid_8_amount", 0) AS "clusterid_8_amount"
	,COALESCE("_twmVC0"."clusterid_99_amount", 0) AS "clusterid_99_amount"
	,COALESCE("_twmVC0"."clusterid_0_freq", 0) AS "clusterid_0_freq"
	,COALESCE("_twmVC0"."clusterid_1_freq", 0) AS "clusterid_1_freq"
	,COALESCE("_twmVC0"."clusterid_2_freq") AS "clusterid_2_freq"
	,COALESCE("_twmVC0"."clusterid_3_freq", 0) AS "clusterid_3_freq"
	,COALESCE("_twmVC0"."clusterid_4_freq", 0) AS "clusterid_4_freq"
	,COALESCE("_twmVC0"."clusterid_5_freq", 0) AS "clusterid_5_freq"
	,COALESCE("_twmVC0"."clusterid_6_freq", 0) AS "clusterid_6_freq"
	,COALESCE("_twmVC0"."clusterid_7_freq", 0) AS "clusterid_7_freq"
	,COALESCE("_twmVC0"."clusterid_8_freq", 0) AS "clusterid_8_freq"
	,COALESCE("_twmVC0"."clusterid_99_freq", 0) AS "clusterid_99_freq"
FROM "public"."sax_on_merchseg_str1_stp3" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp5 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp5";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp5"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_0_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_0_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_1_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_1_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_2_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_2_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_3_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_3_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_4_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_4_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_5_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_5_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_6_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_6_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_7_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_7_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_8_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_8_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_99_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_99_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_0_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_0_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_1_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_1_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_2_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_2_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_3_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_3_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_4_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_4_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_5_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_5_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_6_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_6_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_7_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_7_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_8_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_8_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_99_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_99_freq_n"
FROM "public"."sax_on_merchseg_str1_stp4" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp6 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp6";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp6"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 BTRIM("_twmVC0"."card_no") AS "card_no"
FROM "public"."customer_base" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_merchseg_str1_stp7 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp7";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp7"() DISTRIBUTE BY HASH("stmt_year_month") COMPRESS LOW AS (
SELECT 
	 CAST("_twmVC0"."stmt_year_month" AS INTEGER) AS "stmt_year_month"
FROM "public"."sax_on_merchseg_str1_stp5" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_merchseg_str1_stp8 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp8";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp8"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 CAST("_twmVC0"."card_no" AS VARCHAR(50)) AS "card_no"
	,"_twmVC1"."stmt_year_month" AS "stmt_year_month"
FROM "public"."sax_on_merchseg_str1_stp6" AS "_twmVC0"
	, "public"."sax_on_merchseg_str1_stp7" AS "_twmVC1"
GROUP BY 1, 2
);
/********************  sax_on_merchseg_str1_stp9 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp9";
/********************  sax_on_merchseg_str1_stp10 ********************/

DROP VIEW IF EXISTS "public"."sax_on_merchseg_str1_stp10";
CREATE VIEW "public"."sax_on_merchseg_str1_stp10" AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."clusterid_0_amount_n", 0) AS "clusterid_0_amount_n"
	,COALESCE("_twmVC0"."clusterid_0_freq_n", 0) AS "clusterid_0_freq_n"
	,COALESCE("_twmVC0"."clusterid_1_amount_n", 0) AS "clusterid_1_amount_n"
	,COALESCE("_twmVC0"."clusterid_1_freq_n", 0) AS "clusterid_1_freq_n"
	,COALESCE("_twmVC0"."clusterid_2_amount_n", 0) AS "clusterid_2_amount_n"
	,COALESCE("_twmVC0"."clusterid_2_freq_n", 0) AS "clusterid_2_freq_n"
	,COALESCE("_twmVC0"."clusterid_3_amount_n", 0) AS "clusterid_3_amount_n"
	,COALESCE("_twmVC0"."clusterid_3_freq_n", 0) AS "clusterid_3_freq_n"
	,COALESCE("_twmVC0"."clusterid_4_amount_n", 0) AS "clusterid_4_amount_n"
	,COALESCE("_twmVC0"."clusterid_4_freq_n", 0) AS "clusterid_4_freq_n"
	,COALESCE("_twmVC0"."clusterid_5_amount_n", 0) AS "clusterid_5_amount_n"
	,COALESCE("_twmVC0"."clusterid_5_freq_n", 0) AS "clusterid_5_freq_n"
	,COALESCE("_twmVC0"."clusterid_6_amount_n", 0) AS "clusterid_6_amount_n"
	,COALESCE("_twmVC0"."clusterid_6_freq_n", 0) AS "clusterid_6_freq_n"
	,COALESCE("_twmVC0"."clusterid_7_amount_n", 0) AS "clusterid_7_amount_n"
	,COALESCE("_twmVC0"."clusterid_7_freq_n", 0) AS "clusterid_7_freq_n"
	,COALESCE("_twmVC0"."clusterid_8_amount_n", 0) AS "clusterid_8_amount_n"
	,COALESCE("_twmVC0"."clusterid_8_freq_n", 0) AS "clusterid_8_freq_n"
	,COALESCE("_twmVC0"."clusterid_99_amount_n", 0) AS "clusterid_99_amount_n"
	,COALESCE("_twmVC0"."clusterid_99_freq_n", 0) AS "clusterid_99_freq_n"
FROM "public"."sax_on_merchseg_str1_stp9" AS "_twmVC0"
);
/********************  SAX = 4 Letters and 3 Alphabhets - Merchant Segmentation ********************/
DROP TABLE IF EXISTS "sax_merch_freq_amount_n";
CREATE FACT TABLE "sax_merch_freq_amount_n"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
	SELECT * from SAX ( 
		ON (SELECT card_no, stmt_year_month, clusterid_0_freq_n, clusterid_0_amount_n
			FROM  sax_on_merchseg_str1_stp10 ) 
	PARTITION BY card_no
	ORDER BY stmt_year_month 
	Value_Column_Names ('clusterid_0_freq_n', 'clusterid_0_amount_n') 
	PAA_Size ('4') -- Time Duration
	Alphabet_Size ('3') -- Number of possible Characters 
	Accumulate ('card_no') 
	)
);
/********************  sax_on_merchseg_str1_stp11 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp11";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp11"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC0"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,"_twmVC1"."target" AS "target"
FROM "public"."sax_merch_freq_amount_n" AS "_twmVC0"
	RIGHT OUTER JOIN "public"."customer_base" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  sax_on_merchseg_str1_stp12 - train ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp12";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp12"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC1"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,"_twmVC1"."target" AS "target"
FROM "public"."customer_base_train" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp11" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  sax_on_merchseg_str1_stp13 - test ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp13";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp13"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC1"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
FROM "public"."customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp11" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  sax_on_merchseg_str1_stp14 - s0 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp14";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp14"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / COUNT(*) AS "delinquency_ratio"
FROM "public"."sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_merchseg_str1_stp15 - s0_2 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp15";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp15"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 100 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_0_freq_n" END AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "public"."sax_on_merchseg_str1_stp14" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_merchseg_str1_stp16 - s0_3 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp16";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp16"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "public"."sax_on_merchseg_str1_stp15" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp17 - train_t1 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp17";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp17"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."woe" AS "woe0"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
FROM "public"."sax_on_merchseg_str1_stp12" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp16" AS "_twmVC1"
		ON "_twmVC0"."sax_code_clusterid_0_freq_n" = "_twmVC1"."sax_code_clusterid_0_freq_n"
);
/********************  sax_on_merchseg_str1_stp18 - train_t2 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp18";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp18"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_freq_n", '____') AS "sax_code_clusterid_0_freq_n"
FROM "public"."sax_on_merchseg_str1_stp17" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp19 - train ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp19";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp19"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC1"."woe" AS "woe_freq_cluster0"
FROM "public"."sax_on_merchseg_str1_stp18" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp16" AS "_twmVC1"
		ON "_twmVC0"."sax_code_clusterid_0_freq_n" = "_twmVC1"."sax_code_clusterid_0_freq_n"
);
/********************  sax_on_merchseg_str1_stp20 - test_t1 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp20";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp20"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."woe" AS "woe0"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
FROM "public"."sax_on_merchseg_str1_stp13" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp16" AS "_twmVC1"
		ON "_twmVC0"."sax_code_clusterid_0_freq_n" = "_twmVC1"."sax_code_clusterid_0_freq_n"
);
/********************  sax_on_merchseg_str1_stp21 - test_t2 ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp21";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp21"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_freq_n", '____') AS "sax_code_clusterid_0_freq_n"
FROM "public"."sax_on_merchseg_str1_stp20" AS "_twmVC0"
);
/********************  sax_on_merchseg_str1_stp22 - test ********************/

DROP TABLE IF EXISTS "public"."sax_on_merchseg_str1_stp22";
CREATE FACT TABLE "public"."sax_on_merchseg_str1_stp22"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC1"."woe" AS "woe_freq_cluster0"
FROM "public"."sax_on_merchseg_str1_stp21" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_merchseg_str1_stp16" AS "_twmVC1"
		ON "_twmVC0"."sax_code_clusterid_0_freq_n" = "_twmVC1"."sax_code_clusterid_0_freq_n"
);
/********************  ---------------Merchant Segmentation - Top 4----------------- ********************/
drop table zt_all_cc_cfilter_def;
create table zt_all_cc_cfilter_def
(
col1_item1 varchar(100),
col1_item2 varchar(100),
cntb integer,
cnt1 integer,
cnt2 integer,
target integer
) DISTRIBUTE BY hash(col1_item1);
/********************  merchseg_top_4_str1_stp1 ********************/

DROP TABLE IF EXISTS "public"."merchseg_top_4_str1_stp1";
CREATE FACT TABLE "public"."merchseg_top_4_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,COALESCE("_twmVC1"."clusterid", 99) AS "clusterid"
	,SUM("_twmVC0"."transaction_amount") AS "amount"
	,SUM("_twmVC0"."freq_of_use") AS "freq_of_use"
FROM "public"."merchant_segmentation_source" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchant_segmentation_score" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
GROUP BY 1, 2
);
/********************  merchseg_top4_str1_stp2 - creating the order ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp2";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp2"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."clusterid" AS "clusterid"
	,"_twmVC0"."amount" AS "amount"
	,"_twmVC0"."freq_of_use" AS "freq_of_use"
	,ROW_NUMBER() OVER (PARTITION BY "_twmVC0"."card_no" ORDER BY "_twmVC0"."amount" DESC NULLS LAST ) AS "amount_order"
	,ROW_NUMBER() OVER (PARTITION BY "_twmVC0"."card_no" ORDER BY "_twmVC0"."freq_of_use" DESC NULLS LAST ) AS "frequency_order"
FROM "public"."merchseg_top_4_str1_stp1" AS "_twmVC0"
);
/********************  merchseg_top4_str1_stp3 - transpose of order ********************/

DROP TABLE IF EXISTS "public"."_twm_transform";
CREATE FACT TABLE "public"."_twm_transform"() DISTRIBUTE BY HASH("_twm_key1") COMPRESS LOW AS (
SELECT
 "card_no" AS "_twm_key1"
,COALESCE( "amount_order", 0) AS "_twm_val1"
,COALESCE( "frequency_order", 0) AS "_twm_val2"
FROM "public"."merchseg_top4_str1_stp2" "A"
);

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp3";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
 "A"."card_no" AS "card_no"
,"A"."clusterid" AS "clusterid"
,CASE WHEN "_twm_val1" = 1 THEN 1 ELSE 0 END AS "1_amount_order"
,CASE WHEN "_twm_val1" = 2 THEN 1 ELSE 0 END AS "2_amount_order"
,CASE WHEN "_twm_val1" = 3 THEN 1 ELSE 0 END AS "3_amount_order"
,CASE WHEN "_twm_val1" = 4 THEN 1 ELSE 0 END AS "4_amount_order"
,CASE WHEN "_twm_val1" = 5 THEN 1 ELSE 0 END AS "5_amount_order"
,CASE WHEN "_twm_val1" = 6 THEN 1 ELSE 0 END AS "6_amount_order"
,CASE WHEN "_twm_val1" = 7 THEN 1 ELSE 0 END AS "7_amount_order"
,CASE WHEN "_twm_val1" = 8 THEN 1 ELSE 0 END AS "8_amount_order"
,CASE WHEN "_twm_val1" = 9 THEN 1 ELSE 0 END AS "9_amount_order"
,CASE WHEN "_twm_val2" = 1 THEN 1 ELSE 0 END AS "1_frequency_order"
,CASE WHEN "_twm_val2" = 2 THEN 1 ELSE 0 END AS "2_frequency_order"
,CASE WHEN "_twm_val2" = 3 THEN 1 ELSE 0 END AS "3_frequency_order"
,CASE WHEN "_twm_val2" = 4 THEN 1 ELSE 0 END AS "4_frequency_order"
,CASE WHEN "_twm_val2" = 5 THEN 1 ELSE 0 END AS "5_frequency_order"
,CASE WHEN "_twm_val2" = 6 THEN 1 ELSE 0 END AS "6_frequency_order"
,CASE WHEN "_twm_val2" = 7 THEN 1 ELSE 0 END AS "7_frequency_order"
,CASE WHEN "_twm_val2" = 8 THEN 1 ELSE 0 END AS "8_frequency_order"
,CASE WHEN "_twm_val2" = 9 THEN 1 ELSE 0 END AS "9_frequency_order"
FROM "public"."merchseg_top4_str1_stp2" "A"
,"public"."_twm_transform" "C"
WHERE "card_no" = "_twm_key1"
);
/********************  merchseg_top4_str1_stp4 - segment order ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp4";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp4"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."1_amount_order") AS "segment_1_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."2_amount_order") AS "segment_2_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."3_amount_order") AS "segment_3_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."4_amount_order") AS "segment_4_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."5_amount_order") AS "segment_5_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."6_amount_order") AS "segment_6_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."7_amount_order") AS "segment_7_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."8_amount_order") AS "segment_8_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."9_amount_order") AS "segment_9_amount_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."1_frequency_order") AS "segment_1_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."2_frequency_order") AS "segment_2_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."3_frequency_order") AS "segment_3_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."4_frequency_order") AS "segment_4_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."5_frequency_order") AS "segment_5_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."6_frequency_order") AS "segment_6_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."7_frequency_order") AS "segment_7_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."8_frequency_order") AS "segment_8_frequency_order"
	,MAX("_twmVC0"."clusterid" * "_twmVC0"."9_frequency_order") AS "segment_9_frequency_order"
FROM "public"."merchseg_top4_str1_stp3" AS "_twmVC0"
GROUP BY 1
);
/********************  merchseg_top4_str1_stp5 - train ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp5";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp5"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC1"."segment_1_amount_order", 0) AS "segment_1_amount_order"
	,COALESCE("_twmVC1"."segment_1_frequency_order", 0) AS "segment_1_frequency_order"
	,COALESCE("_twmVC1"."segment_2_amount_order", 0) AS "segment_2_amount_order"
	,COALESCE("_twmVC1"."segment_2_frequency_order", 0) AS "segment_2_frequency_order"
	,COALESCE("_twmVC1"."segment_3_amount_order", 0) AS "segment_3_amount_order"
	,COALESCE("_twmVC1"."segment_3_frequency_order", 0) AS "segment_3_frequency_order"
	,COALESCE("_twmVC1"."segment_4_amount_order", 0) AS "segment_4_amount_order"
	,COALESCE("_twmVC1"."segment_4_frequency_order", 0) AS "segment_4_frequency_order"
	,COALESCE("_twmVC1"."segment_5_amount_order", 0) AS "segment_5_amount_order"
	,COALESCE("_twmVC1"."segment_5_frequency_order", 0) AS "segment_5_frequency_order"
	,COALESCE("_twmVC1"."segment_6_amount_order", 0) AS "segment_6_amount_order"
	,COALESCE("_twmVC1"."segment_6_frequency_order", 0) AS "segment_6_frequency_order"
	,COALESCE("_twmVC1"."segment_7_amount_order", 0) AS "segment_7_amount_order"
	,COALESCE("_twmVC1"."segment_7_frequency_order", 0) AS "segment_7_frequency_order"
	,COALESCE("_twmVC1"."segment_8_amount_order", 0) AS "segment_8_amount_order"
	,COALESCE("_twmVC1"."segment_8_frequency_order", 0) AS "segment_8_frequency_order"
	,COALESCE("_twmVC1"."segment_9_amount_order", 0) AS "segment_9_amount_order"
	,COALESCE("_twmVC1"."segment_9_frequency_order", 0) AS "segment_9_frequency_order"
FROM "public"."customer_base_train" AS "_twmVC0"
	INNER JOIN "public"."merchseg_top4_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  merchseg_top4_str1_stp6 - test ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp6";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp6"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC1"."segment_1_amount_order", 0) AS "segment_1_amount_order"
	,COALESCE("_twmVC1"."segment_1_frequency_order", 0) AS "segment_1_frequency_order"
	,COALESCE("_twmVC1"."segment_2_amount_order", 0) AS "segment_2_amount_order"
	,COALESCE("_twmVC1"."segment_2_frequency_order", 0) AS "segment_2_frequency_order"
	,COALESCE("_twmVC1"."segment_3_amount_order", 0) AS "segment_3_amount_order"
	,COALESCE("_twmVC1"."segment_3_frequency_order", 0) AS "segment_3_frequency_order"
	,COALESCE("_twmVC1"."segment_4_amount_order", 0) AS "segment_4_amount_order"
	,COALESCE("_twmVC1"."segment_4_frequency_order", 0) AS "segment_4_frequency_order"
	,COALESCE("_twmVC1"."segment_5_amount_order", 0) AS "segment_5_amount_order"
	,COALESCE("_twmVC1"."segment_5_frequency_order", 0) AS "segment_5_frequency_order"
	,COALESCE("_twmVC1"."segment_6_amount_order", 0) AS "segment_6_amount_order"
	,COALESCE("_twmVC1"."segment_6_frequency_order", 0) AS "segment_6_frequency_order"
	,COALESCE("_twmVC1"."segment_7_amount_order", 0) AS "segment_7_amount_order"
	,COALESCE("_twmVC1"."segment_7_frequency_order", 0) AS "segment_7_frequency_order"
	,COALESCE("_twmVC1"."segment_8_amount_order", 0) AS "segment_8_amount_order"
	,COALESCE("_twmVC1"."segment_8_frequency_order", 0) AS "segment_8_frequency_order"
	,COALESCE("_twmVC1"."segment_9_amount_order", 0) AS "segment_9_amount_order"
	,COALESCE("_twmVC1"."segment_9_frequency_order", 0) AS "segment_9_frequency_order"
FROM "public"."customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchseg_top4_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  merchseg_top4_str1_stp7 - woe stp1 ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp7";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp7"() DISTRIBUTE BY HASH("count_target") AS (
SELECT 
	 "_twmVC0"."segment_1_amount_order" AS "segment_1_amount_order"
	,"_twmVC0"."segment_2_amount_order" AS "segment_2_amount_order"
	,"_twmVC0"."segment_3_amount_order" AS "segment_3_amount_order"
	,"_twmVC0"."segment_4_amount_order" AS "segment_4_amount_order"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / COUNT(*) AS "delinquent_ratio"
FROM "public"."merchseg_top4_str1_stp5" AS "_twmVC0"
GROUP BY 1, 2, 3, 4
);
/********************  merchseg_top4_str1_stp8 - step 2club small ones ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp8";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp8"() DISTRIBUTE BY HASH("count_target") AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 100 THEN 0 ELSE "_twmVC0"."segment_1_amount_order" END AS "segment_1_amount_order"
	,CASE WHEN "_twmVC0"."count_total" < 100 THEN 0 ELSE "_twmVC0"."segment_2_amount_order" END AS "segment_2_amount_order"
	,CASE WHEN "_twmVC0"."count_total" < 100 THEN 0 ELSE "_twmVC0"."segment_3_amount_order" END AS "segment_3_amount_order"
	,CASE WHEN "_twmVC0"."count_total" < 100 THEN 0 ELSE "_twmVC0"."segment_4_amount_order" END AS "segment_4_amount_order"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "public"."merchseg_top4_str1_stp7" AS "_twmVC0"
GROUP BY 1, 2, 3, 4
);
/********************  merchseg_top4_str1_stp9 - step3 calculate woe  ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp9";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp9"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."segment_1_amount_order" AS "segment_1_amount_order"
	,"_twmVC0"."segment_2_amount_order" AS "segment_2_amount_order"
	,"_twmVC0"."segment_3_amount_order" AS "segment_3_amount_order"
	,"_twmVC0"."segment_4_amount_order" AS "segment_4_amount_order"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "public"."merchseg_top4_str1_stp8" AS "_twmVC0"
);
/********************  merchseg_top4_str1_stp10 - step 1applying woe to testing ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp10";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp10"() DISTRIBUTE BY HASH("cust_id") AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC0"."segment_1_amount_order" AS "segment_1_amount_order"
	,"_twmVC0"."segment_2_amount_order" AS "segment_2_amount_order"
	,"_twmVC0"."segment_3_amount_order" AS "segment_3_amount_order"
	,"_twmVC0"."segment_4_amount_order" AS "segment_4_amount_order"
	,COALESCE("_twmVC1"."segment_1_amount_order", 0) AS "segment_1_amount_order_nr"
	,COALESCE("_twmVC1"."segment_2_amount_order", 0) AS "segment_2_amount_order_nr"
	,COALESCE("_twmVC1"."segment_3_amount_order", 0) AS "segment_3_amount_order_nr"
	,COALESCE("_twmVC1"."segment_4_amount_order", 0) AS "segment_4_amount_order_nr"
	,"_twmVC1"."woe" AS "woe"
FROM "public"."merchseg_top4_str1_stp6" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchseg_top4_str1_stp9" AS "_twmVC1"
		ON "_twmVC0"."segment_1_amount_order" = "_twmVC1"."segment_1_amount_order"
		AND "_twmVC0"."segment_2_amount_order" = "_twmVC1"."segment_2_amount_order"
		AND "_twmVC0"."segment_3_amount_order" = "_twmVC1"."segment_3_amount_order"
		AND "_twmVC0"."segment_4_amount_order" = "_twmVC1"."segment_4_amount_order"
);
/********************  merchseg_top4_str1_stp11 - step 2applying woe to testing ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp11";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp11"() DISTRIBUTE BY HASH("cust_id") AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC0"."segment_1_amount_order_nr" AS "segment_1_amount_order"
	,"_twmVC0"."segment_2_amount_order_nr" AS "segment_2_amount_order"
	,"_twmVC0"."segment_3_amount_order_nr" AS "segment_3_amount_order"
	,"_twmVC0"."segment_4_amount_order_nr" AS "segment_4_amount_order"
	,"_twmVC1"."woe" AS "woe"
FROM "public"."merchseg_top4_str1_stp10" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchseg_top4_str1_stp9" AS "_twmVC1"
		ON "_twmVC0"."segment_1_amount_order_nr" = "_twmVC1"."segment_1_amount_order"
		AND "_twmVC0"."segment_2_amount_order_nr" = "_twmVC1"."segment_2_amount_order"
		AND "_twmVC0"."segment_3_amount_order_nr" = "_twmVC1"."segment_3_amount_order"
		AND "_twmVC0"."segment_4_amount_order_nr" = "_twmVC1"."segment_4_amount_order"
);
/********************  merchseg_top4_str1_stp12 - woe for replacing nulls ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp12";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp12"() DISTRIBUTE BY HASH("woe") AS (
SELECT 
	 "_twmVC0"."woe" AS "woe"
FROM "public"."merchseg_top4_str1_stp9" AS "_twmVC0"
WHERE ("_twmVC0"."segment_1_amount_order" = 0) AND ("_twmVC0"."segment_2_amount_order" = 0) AND ("_twmVC0"."segment_3_amount_order" = 0) AND ("_twmVC0"."segment_4_amount_order" = 0)
GROUP BY 1
);
/********************  merchseg_top4_str1_stp13 - top 4 train ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp13";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp13"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC1"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC2"."woe", "_twmVC3"."woe") AS "top4_amount_woe"
FROM "public"."customer_base_train" AS "_twmVC0"
	LEFT OUTER JOIN "public"."merchseg_top4_str1_stp5" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
	LEFT OUTER JOIN "public"."merchseg_top4_str1_stp9" AS "_twmVC2"
		ON "_twmVC1"."segment_1_amount_order" = "_twmVC2"."segment_1_amount_order"
		AND "_twmVC1"."segment_2_amount_order" = "_twmVC2"."segment_2_amount_order"
		AND "_twmVC1"."segment_3_amount_order" = "_twmVC2"."segment_3_amount_order"
		AND "_twmVC1"."segment_4_amount_order" = "_twmVC2"."segment_4_amount_order"
	, "public"."merchseg_top4_str1_stp12" AS "_twmVC3"
);
/********************  merchseg_top4_str1_stp14 - top 4 test ********************/

DROP TABLE IF EXISTS "public"."merchseg_top4_str1_stp14";
CREATE FACT TABLE "public"."merchseg_top4_str1_stp14"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC0"."woe" AS "top4_amount_woe"
FROM "public"."merchseg_top4_str1_stp11" AS "_twmVC0"
);
/********************  sax_on_var_str1_stp1 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp1";
CREATE FACT TABLE "public"."sax_on_var_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
FROM "public"."customer_base" AS "_twmVC0"
GROUP BY 1, 2
);
/********************  sax_on_var_str1_stp2 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp2";
CREATE DIMENSION TABLE "public"."sax_on_var_str1_stp2"() DISTRIBUTE BY REPLICATION COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."yyyymm" AS "yyyymm"
FROM "public"."status_account_balance_source" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_var_str1_stp3 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp3";
CREATE FACT TABLE "public"."sax_on_var_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC1"."yyyymm" AS "yyyymm"
FROM "public"."sax_on_var_str1_stp1" AS "_twmVC0"
	, "public"."sax_on_var_str1_stp2" AS "_twmVC1"
);
/********************  sax_on_var_str1_stp4 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp4";
CREATE FACT TABLE "public"."sax_on_var_str1_stp4"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."yyyymm" AS "yyyymm"
	,"_twmVC1"."total" AS "total"
FROM "public"."sax_on_var_str1_stp3" AS "_twmVC0"
	LEFT OUTER JOIN "public"."status_account_balance_source" AS "_twmVC1"
		ON "_twmVC0"."cust_id" = "_twmVC1"."cust_id"
		AND "_twmVC0"."yyyymm" = "_twmVC1"."yyyymm"
GROUP BY 1, 2, 3, 4
);
/********************  SAX = 4 Letters and 3 Alphabhets - Var balance ********************/
DROP TABLE IF EXISTS "sax_on_var_balance";
CREATE FACT TABLE "sax_on_var_balance"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT * from SAX ( 
ON 
		(SELECT 
		customer_base.card_no,
		sax_on_var_str1_stp4.yyyymm, 
		sax_on_var_str1_stp4.total
		FROM 
		sax_on_var_str1_stp4
		INNER JOIN 
		customer_base
		ON
		sax_on_var_str1_stp4.card_no = customer_base.card_no)
PARTITION BY card_no
ORDER BY yyyymm 
Value_Column_Names ('total')
PAA_Size ('4') -- Time Duration
Alphabet_Size ('3') -- Number of possible Characters 
Accumulate ('card_no') 
))
/********************  sax_on_var_str1_stp5 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp5";
CREATE FACT TABLE "public"."sax_on_var_str1_stp5"() DISTRIBUTE BY HASH("sax_code_total_balance") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_total" AS "sax_code_total_balance"
	,SUM("_twmVC1"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC1"."target") / CAST(COUNT(*) AS FLOAT) AS "delinquency_ratio"
FROM "public"."sax_on_var_balance" AS "_twmVC0"
	RIGHT OUTER JOIN "public"."customer_base_test" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
GROUP BY 1
);
/********************  sax_on_var_str1_stp6 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp6";
CREATE FACT TABLE "public"."sax_on_var_str1_stp6"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 100 THEN '____' ELSE "_twmVC0"."sax_code_total_balance" END AS "sax_code_total_balance"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "public"."sax_on_var_str1_stp5" AS "_twmVC0"
GROUP BY 1
);
/********************  sax_on_var_str1_stp7 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp7";
CREATE FACT TABLE "public"."sax_on_var_str1_stp7"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_total_balance" AS "sax_code_total_balance"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "public"."sax_on_var_str1_stp6" AS "_twmVC0"
);
/********************  sax_on_var_str1_stp8 ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp8";
CREATE FACT TABLE "public"."sax_on_var_str1_stp8"() DISTRIBUTE BY HASH("woe") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_total_balance" AS "sax_code_total_balance"
	,"_twmVC0"."woe" AS "woe"
FROM "public"."sax_on_var_str1_stp7" AS "_twmVC0"
WHERE ("_twmVC0"."sax_code_total_balance" = '______') OR ("_twmVC0"."sax_code_total_balance" = '_____') OR ("_twmVC0"."sax_code_total_balance" = '____') OR ("_twmVC0"."sax_code_total_balance" = '___')
);
/********************  sax_on_var_str1_stp9 - train ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp9";
CREATE FACT TABLE "public"."sax_on_var_str1_stp9"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,COALESCE("_twmVC1"."card_no", "_twmVC0"."card_no") AS "card_no"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC2"."woe", "_twmVC3"."woe", 0) AS "woe_balance"
FROM "public"."customer_base_train" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_var_balance" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
	LEFT OUTER JOIN "public"."sax_on_var_str1_stp7" AS "_twmVC2"
		ON "_twmVC1"."sax_code_total" = "_twmVC2"."sax_code_total_balance"
	LEFT OUTER JOIN "public"."sax_on_var_str1_stp8" AS "_twmVC3"
ON (1 = 1)
);
/********************  sax_on_var_str1_stp10 - test ********************/

DROP TABLE IF EXISTS "public"."sax_on_var_str1_stp10";
CREATE FACT TABLE "public"."sax_on_var_str1_stp10"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,COALESCE("_twmVC0"."card_no", "_twmVC1"."card_no") AS "card_no"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC2"."woe", "_twmVC3"."woe") AS "woe_balance"
FROM "public"."customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sax_on_var_balance" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
	LEFT OUTER JOIN "public"."sax_on_var_str1_stp7" AS "_twmVC2"
		ON "_twmVC1"."sax_code_total" = "_twmVC2"."sax_code_total_balance"
	LEFT OUTER JOIN "public"."sax_on_var_str1_stp8" AS "_twmVC3"
ON (1 = 1)
);
/********************  ---------------Path----------------- ********************/
sadasd
/********************  path_str1_stp1 - triplets train ********************/
DROP TABLE IF EXISTS public.path_str1_stp1 CASCADE;
CREATE FACT TABLE public.path_str1_stp1 DISTRIBUTE BY HASH(card_no)
AS SELECT card_no
	, path
	, event_qtr
	, start_date
	, end_date
	, end_date - start_date as elapsed_time
	, target
FROM npath(                                        
	on (SELECT a.*
		, b.target
		,  extract( 'year' from event_date)::int || '_' || extract( 'quarter' from event_date)::int as event_qtr
	    FROM path_event_table_train_source a
			INNER JOIN public.customer_base_train b 
			ON a.card_no = b.card_no
		WHERE a.event_cat NOT IN ('default', 'nondefault')
	)
	PARTITION BY card_no
	ORDER BY event_date, event_cat
	MODE('OVERLAPPING')
	SYMBOLS(TRUE as a)
	PATTERN ('a{3}')
	RESULT(ACCUMULATE(event_cat of ANY(a)) as path,
			FIRST(card_no of ANY(a)) as card_no,
			FIRST(target of a) as target,
			FIRST(event_qtr of a) as event_qtr,
			FIRST(event_date of a) as start_date,
			LAST(event_date of  a) as end_date)
	)
WHERE end_date-start_date <= 90;
/********************  path_str1_stp2 - naivebaye triplets model ********************/
DROP TABLE IF EXISTS public.path_str1_stp2;
CREATE TABLE public.path_str1_stp2 DISTRIBUTE BY REPLICATION
AS
SELECT * FROM NaiveBayesTextClassifierTrainer (
	ON (SELECT * FROM NaiveBayesTextClassifierInternal (
		ON (SELECT card_no::varchar card_no
		, replace(replace(path,'[', ''),']','') as path
		, target::varchar as target 
		    FROM public.path_str1_stp1) as a  
		PARTITION BY target
		Token_Column ('path')
		Model_Type ('Bernoulli')
		Doc_ID_Columns ('card_no')
		Doc_Category_Column ('target')
		)
	)
PARTITION BY 1);
/********************  path_str1_stp3 - pivot probabilities ********************/
DROP TABLE IF EXISTS public.path_str1_stp3;
CREATE TABLE public.path_str1_stp3 DISTRIBUTE BY REPLICATION
AS
SELECT '['||token||']' AS path
		, COALESCE(prob_0, 0) AS prob_0
		, COALESCE(prob_1,0) AS prob_1
	FROM pivot ( 
	ON (SELECT * FROM public.path_str1_stp2 WHERE token NOT ilike '%ASTER%')
	PARTITION BY token 
	PARTITIONS ('token')
	pivot_column('category') 
	PIVOT_KEYS('1','0')
	metrics('prob') 
);
/********************  path_str1_stp4 - var targets ********************/

DROP TABLE IF EXISTS "public"."path_str1_stp4";
CREATE FACT TABLE "public"."path_str1_stp4"() DISTRIBUTE BY HASH("path") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."path" AS "path"
	,"_twmVC0"."prob_0" AS "prob_0"
	,"_twmVC0"."prob_1" AS "prob_1"
	,CASE WHEN "_twmVC0"."prob_1" > "_twmVC0"."prob_0" THEN 1 ELSE 0 END AS "target"
	,CASE WHEN "_twmVC0"."prob_1" > (4 * "_twmVC0"."prob_0") THEN 1 ELSE 0 END AS "target40"
	,CASE WHEN "_twmVC0"."prob_0" > (4 * "_twmVC0"."prob_1") THEN 1 ELSE 0 END AS "target0_40"
FROM "public"."path_str1_stp3" AS "_twmVC0"
);
/********************  path_str1_str5 - path aggregates ********************/

DROP TABLE IF EXISTS "public"."path_str1_str5";
CREATE FACT TABLE "public"."path_str1_str5"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM((COALESCE("_twmVC1"."prob_1", 0))) AS "prob_1"
	,SUM((COALESCE("_twmVC1"."prob_0", 0))) AS "prob_0"
	,COUNT(*) AS "total_path_count"
	,SUM("_twmVC1"."target") AS "default_path_count"
	,COUNT(*) - SUM("_twmVC1"."target") AS "nondefault_path_count"
	,SUM("_twmVC1"."target40") AS "target40_count"
	,SUM("_twmVC1"."target0_40") AS "target0_40_count"
FROM "public"."path_str1_stp1" AS "_twmVC0"
	INNER JOIN "public"."path_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."path" = "_twmVC1"."path"
GROUP BY 1
);
/********************  path_str1_str6 - path flags ********************/

DROP TABLE IF EXISTS "public"."path_str1_str6";
CREATE FACT TABLE "public"."path_str1_str6"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."default_path_count" > 0 THEN 1 ELSE 0 END AS "default_path_flag"
	,CASE WHEN "_twmVC0"."nondefault_path_count" > 0 THEN 1 ELSE 0 END AS "nondefault_path_flag"
	,CASE WHEN "_twmVC0"."target40_count" > 0 THEN 1 ELSE 0 END AS "target40_flag"
	,CASE WHEN "_twmVC0"."target0_40_count" > 0 THEN 1 ELSE 0 END AS "target0_40_flag"
	,CAST("_twmVC0"."default_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "default_path_percentage"
	,CAST("_twmVC0"."nondefault_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "nondefault_path_percentage"
	,CAST("_twmVC0"."target40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target40_percentage"
	,CAST("_twmVC0"."target0_40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target0_40_percentage"
FROM "public"."path_str1_str5" AS "_twmVC0"
);
/********************  path_str1_str7 - path ads ********************/

DROP TABLE IF EXISTS "public"."path_str1_str7";
CREATE FACT TABLE "public"."path_str1_str7"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
	 "_twmJoin0"."card_no"
	,"_twmJoin0"."cust_id"
	,"_twmJoin0"."target"
	,"_twmJoin1"."total_path_count"
	,"_twmJoin1"."default_path_count"
	,"_twmJoin1"."nondefault_path_count"
	,"_twmJoin1"."target40_count"
	,"_twmJoin1"."target0_40_count"
	,"_twmJoin2"."default_path_flag"
	,"_twmJoin2"."nondefault_path_flag"
	,"_twmJoin2"."target40_flag"
	,"_twmJoin2"."target0_40_flag"
	,"_twmJoin2"."default_path_percentage"
	,"_twmJoin2"."nondefault_path_percentage"
	,"_twmJoin2"."target40_percentage"
	,"_twmJoin2"."target0_40_percentage"

FROM "public"."customer_base_train" AS "_twmJoin0"
	LEFT OUTER JOIN "public"."path_str1_str5" AS "_twmJoin1"
		ON "_twmJoin0"."card_no" = "_twmJoin1"."card_no"
	LEFT OUTER JOIN "public"."path_str1_str6" AS "_twmJoin2"
		ON "_twmJoin0"."card_no" = "_twmJoin2"."card_no"
);
/********************  path_str1_str8 - ads null replacement ********************/

DROP TABLE IF EXISTS "public"."path_str1_str8";
CREATE FACT TABLE "public"."path_str1_str8"() DISTRIBUTE BY HASH("card_no") AS (
SELECT
 "A"."card_no" AS "card_no"
,"A"."cust_id" AS "cust_id"
,"A"."target" AS "target"
,COALESCE( "default_path_count", 0) AS "default_path_count"
,COALESCE( "default_path_flag", 0.0E+000) AS "default_path_flag"
,COALESCE( "default_path_percentage", 0.0E+000) AS "default_path_percentage"
,COALESCE( "nondefault_path_count", 0) AS "nondefault_path_count"
,COALESCE( "nondefault_path_flag", 0.0E+000) AS "nondefault_path_flag"
,COALESCE( "nondefault_path_percentage", 0.0E+000) AS "nondefault_path_percentage"
,COALESCE( "target0_40_count", 0) AS "target0_40_count"
,COALESCE( "target0_40_flag", 0.0E+000) AS "target0_40_flag"
,COALESCE( "target0_40_percentage", 0.0E+000) AS "target0_40_percentage"
,COALESCE( "target40_count", 0) AS "target40_count"
,COALESCE( "target40_flag", 0.0E+000) AS "target40_flag"
,COALESCE( "target40_percentage", 0.0E+000) AS "target40_percentage"
,COALESCE( "total_path_count", 0) AS "total_path_count"
FROM "public"."path_str1_str7" "A"
);
/********************  path_str1_stp9 - triplets test ********************/
DROP TABLE IF EXISTS public.path_str1_stp9 CASCADE;
CREATE FACT TABLE public.path_str1_stp9 DISTRIBUTE BY HASH(card_no)
AS SELECT card_no
	, path
	, event_qtr
	, start_date
	, end_date
	, end_date - start_date as elapsed_time
	, target
FROM npath(                                        
	on (SELECT a.*
		, b.target
		,  extract( 'year' from event_date)::int || '_' || extract( 'quarter' from event_date)::int as event_qtr
	    FROM path_event_table_test_source a
			INNER JOIN public.customer_base_test b 
			ON a.card_no = b.card_no
		WHERE a.event_cat NOT IN ('default', 'nondefault')
	)
	PARTITION BY card_no
	ORDER BY event_date, event_cat
	MODE('OVERLAPPING')
	SYMBOLS(TRUE as a)
	PATTERN ('a{3}')
	RESULT(ACCUMULATE(event_cat of ANY(a)) as path,
			FIRST(card_no of ANY(a)) as card_no,
			FIRST(target of a) as target,
			FIRST(event_qtr of a) as event_qtr,
			FIRST(event_date of a) as start_date,
			LAST(event_date of  a) as end_date)
	)
WHERE end_date-start_date <= 90;
/********************  path_str1_stp10 - path agg test ********************/

DROP TABLE IF EXISTS "public"."path_str1_stp10";
CREATE FACT TABLE "public"."path_str1_stp10"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM((COALESCE("_twmVC1"."prob_1", 0))) AS "prob_1"
	,SUM((COALESCE("_twmVC1"."prob_0", 0))) AS "prob_0"
	,COUNT(*) AS "total_path_count"
	,SUM("_twmVC1"."target") AS "default_path_count"
	,COUNT(*) - SUM("_twmVC1"."target") AS "nondefault_path_count"
	,SUM("_twmVC1"."target40") AS "target40_count"
	,"_twmVC1"."target0_40" AS "target0_40_count"
FROM "public"."path_str1_stp9" AS "_twmVC0"
	INNER JOIN "public"."path_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."path" = "_twmVC1"."path"
GROUP BY 1, 8
);
/********************  path_str1_str11 - path flags test ********************/

DROP TABLE IF EXISTS "public"."path_str1_stp11";
CREATE FACT TABLE "public"."path_str1_stp11"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."default_path_count" > 0 THEN 1 ELSE 0 END AS "default_path_flag"
	,CASE WHEN "_twmVC0"."nondefault_path_count" > 0 THEN 1 ELSE 0 END AS "nondefault_path_flag"
	,CASE WHEN "_twmVC0"."target40_count" > 0 THEN 1 ELSE 0 END AS "target40_flag"
	,CASE WHEN "_twmVC0"."target0_40_count" > 0 THEN 1 ELSE 0 END AS "target0_40_flag"
	,CAST("_twmVC0"."default_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "default_path_percentage"
	,CAST("_twmVC0"."nondefault_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "nondefault_path_percentage"
	,CAST("_twmVC0"."target40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target40_percentage"
	,CAST("_twmVC0"."target0_40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target0_40_percentage"
FROM "public"."path_str1_stp10" AS "_twmVC0"
);
/********************  path_str1_stp12 - path ads test ********************/

DROP TABLE IF EXISTS "public"."path_str1_stp12";
CREATE FACT TABLE "public"."path_str1_stp12"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."prob_1" AS "prob_1"
	,"_twmVC1"."prob_0" AS "prob_0"
	,"_twmVC1"."total_path_count" AS "total_path_count"
	,"_twmVC1"."default_path_count" AS "default_path_count"
	,"_twmVC1"."nondefault_path_count" AS "nondefault_path_count"
	,"_twmVC1"."target40_count" AS "target40_count"
	,"_twmVC1"."target0_40_count" AS "target0_40_count"
	,"_twmVC2"."default_path_flag" AS "default_path_flag"
	,"_twmVC2"."nondefault_path_flag" AS "nondefault_path_flag"
	,"_twmVC2"."target40_flag" AS "target40_flag"
	,"_twmVC2"."default_path_percentage" AS "default_path_percentage"
	,"_twmVC2"."nondefault_path_percentage" AS "nondefault_path_percentage"
	,"_twmVC2"."target40_percentage" AS "target40_percentage"
	,"_twmVC2"."target0_40_percentage" AS "target0_40_percentage"
	,"_twmVC2"."target0_40_flag" AS "target0_40_flag"
FROM "public"."customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "public"."path_str1_stp11" AS "_twmVC2"
		ON "_twmVC0"."card_no" = "_twmVC2"."card_no"
	LEFT OUTER JOIN "public"."path_str1_stp10" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
/********************  path_str1_stp13 - ads null replacement test ********************/

DROP TABLE IF EXISTS "public"."path_str1_stp13";
CREATE FACT TABLE "public"."path_str1_stp13"() DISTRIBUTE BY HASH("card_no") AS (
SELECT
 "A"."card_no" AS "card_no"
,"A"."cust_id" AS "cust_id"
,"A"."target" AS "target"
,COALESCE( "default_path_count", 0) AS "default_path_count"
,COALESCE( "default_path_flag", 0.0E+000) AS "default_path_flag"
,COALESCE( "default_path_percentage", 0.0E+000) AS "default_path_percentage"
,COALESCE( "nondefault_path_count", 0) AS "nondefault_path_count"
,COALESCE( "nondefault_path_flag", 0.0E+000) AS "nondefault_path_flag"
,COALESCE( "nondefault_path_percentage", 0.0E+000) AS "nondefault_path_percentage"
,COALESCE( "target0_40_count", 0.0E+000) AS "target0_40_count"
,COALESCE( "target0_40_percentage", 0.0E+000) AS "target0_40_percentage"
,COALESCE( "target0_40_flag", 0.0E+000) AS "target0_40_flag"
,COALESCE( "target40_count", 0) AS "target40_count"
,COALESCE( "target40_flag", 0.0E+000) AS "target40_flag"
,COALESCE( "target40_percentage", 0.0E+000) AS "target40_percentage"
,COALESCE( "total_path_count", 0) AS "total_path_count"
FROM "public"."path_str1_stp12" "A"
);
/********************  ---------------SNA----------------- ********************/
asdsa
/********************  sna_str1_stp1 - focus_node_lookup ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp1";
CREATE FACT TABLE "public"."sna_str1_stp1"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."national_id" AS "national_id"
FROM "public"."sna_customers_source" AS "_twmVC0"
WHERE ("_twmVC0"."cust_id" IS NOT NULL) AND ("_twmVC0"."national_id" IS NOT NULL)
);
/********************  sna_str1_stp2 - level_1_node_lookup ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp2";
CREATE FACT TABLE "public"."sna_str1_stp2"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."national_id" AS "national_id"
FROM "public"."sna_customers_source" AS "_twmVC0"
WHERE ("_twmVC0"."cust_id" IS NOT NULL) AND ("_twmVC0"."national_id" IS NOT NULL)
);
/********************  sna_str1_stp3 - family_relations ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp3";
CREATE FACT TABLE "public"."sna_str1_stp3"() DISTRIBUTE BY HASH("focus_national_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."focus_national_id" AS "focus_national_id"
	,"_twmVC0"."level_1_national_id" AS "level_1_national_id"
	,"_twmVC1"."cust_id" AS "focus_customer_id"
	,"_twmVC2"."cust_id" AS "level_1_customer_id"
	,"_twmVC0"."relation_type" AS "relation_type"
	,0 AS "frequency"
	,0 AS "amount"
FROM "public"."sna_family_source" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sna_str1_stp1" AS "_twmVC1"
		ON "_twmVC0"."focus_national_id" = "_twmVC1"."national_id"
	LEFT OUTER JOIN "public"."sna_str1_stp2" AS "_twmVC2"
		ON "_twmVC0"."level_1_national_id" = "_twmVC2"."national_id"
GROUP BY 1, 2, 3, 4, 5, 6, 7
);
/********************  sna_str1_stp4 - money transfer network ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp4";
CREATE FACT TABLE "public"."sna_str1_stp4"() DISTRIBUTE BY HASH("focus_cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."national_id" AS "focus_national_id"
	,"_twmVC1"."national_id" AS "level_1_national_id"
	,"_twmVC2"."sender_cust_id" AS "focus_cust_id"
	,"_twmVC2"."recipient_cust_id" AS "level_1_cust_id"
	,CAST('Money Transfer' AS VARCHAR(50)) AS "relation_type"
	,SUM("_twmVC2"."frequency") AS "frequency"
	,SUM("_twmVC2"."amount") AS "amount"
FROM "public"."sna_money_transfers_source" AS "_twmVC2"
	LEFT OUTER JOIN "public"."sna_str1_stp1" AS "_twmVC0"
		ON "_twmVC2"."sender_cust_id" = "_twmVC0"."cust_id"
	LEFT OUTER JOIN "public"."sna_str1_stp2" AS "_twmVC1"
		ON "_twmVC2"."recipient_cust_id" = "_twmVC1"."cust_id"
GROUP BY 1, 2, 3, 4, 5
);
/********************  sna_str1_stp5 - customer_links ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp5";
CREATE FACT TABLE "public"."sna_str1_stp5"() DISTRIBUTE BY HASH("focus_customer_id") COMPRESS LOW AS (
SELECT
 	 "focus_customer_id"
	,"focus_national_id"
	,"level_1_customer_id"
	,"level_1_national_id"
	,"relation_type"
	,"frequency"
	,"amount"
FROM "public"."sna_str1_stp3"
UNION
SELECT
 	 "focus_cust_id"
	,"focus_national_id"
	,"level_1_cust_id"
	,"level_1_national_id"
	,"relation_type"
	,"frequency"
	,"amount"
FROM "public"."sna_str1_stp4"
);
/********************  sna_str1_stp6 - base 1 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp6";
CREATE FACT TABLE "public"."sna_str1_stp6"() DISTRIBUTE BY HASH("focus_node") COMPRESS LOW AS (
SELECT 
	 COALESCE("_twmVC0"."focus_customer_id", "_twmVC0"."focus_national_id") AS "focus_node"
	,COALESCE("_twmVC0"."level_1_customer_id", "_twmVC0"."level_1_national_id") AS "level_1_node"
	,"_twmVC0"."focus_customer_id" AS "focus_customer_id"
	,"_twmVC0"."focus_national_id" AS "focus_national_id"
	,"_twmVC0"."level_1_customer_id" AS "level_1_customer_id"
	,"_twmVC0"."level_1_national_id" AS "level_1_national_id"
	,MAX("_twmVC0"."relation_type") AS "relation_type"
	,MAX("_twmVC0"."frequency") AS "frequency"
	,MAX("_twmVC0"."amount") AS "amount"
FROM "public"."sna_str1_stp5" AS "_twmVC0"
GROUP BY 1, 2, 3, 4, 5, 6
);
/********************  sna_str1_stp7 - base_step1_dup ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp7";
CREATE FACT TABLE "public"."sna_str1_stp7"() DISTRIBUTE BY HASH("focus_node") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."level_1_node" AS "level_1_node"
	,"_twmVC0"."focus_node" AS "focus_node"
	,"_twmVC0"."level_1_customer_id" AS "level_1_customer_id"
	,"_twmVC0"."level_1_national_id" AS "level_1_national_id"
	,"_twmVC0"."focus_customer_id" AS "focus_customer_id"
	,"_twmVC0"."focus_national_id" AS "focus_national_id"
	,CASE WHEN "_twmVC0"."relation_type" = 'Mother' THEN 'Child' WHEN "_twmVC0"."relation_type" = 'Father' THEN 'Child' ELSE (COALESCE("_twmVC0"."relation_type", 'Money Transfer')) END AS "relation_type"
	,"_twmVC0"."frequency" AS "frequency"
	,"_twmVC0"."amount" AS "amount"
FROM "public"."sna_str1_stp6" AS "_twmVC0"
);
/********************  sna_str1_stp8 - base 2 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp8";
CREATE FACT TABLE "public"."sna_str1_stp8"() DISTRIBUTE BY HASH("focus_node") COMPRESS LOW AS (
SELECT
 	 "focus_node"
	,"level_1_node"
	,"focus_customer_id"
	,"focus_national_id"
	,"level_1_customer_id"
	,"level_1_national_id"
	,"relation_type"
	,"frequency"
	,"amount"
FROM "public"."sna_str1_stp6"
UNION
SELECT
 	 "focus_node"
	,"level_1_node"
	,"focus_customer_id"
	,"focus_national_id"
	,"level_1_customer_id"
	,"level_1_national_id"
	,"relation_type"
	,"frequency"
	,"amount"
FROM "public"."sna_str1_stp7"
);
/********************  sna_str1_stp9 - base 3 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp9";
CREATE FACT TABLE "public"."sna_str1_stp9"() DISTRIBUTE BY HASH("focus_node") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."focus_node" AS "focus_node"
	,"_twmVC0"."level_1_node" AS "level_1_node"
	,"_twmVC0"."focus_customer_id" AS "focus_customer_id"
	,"_twmVC0"."level_1_customer_id" AS "level_1_customer_id"
	,"_twmVC0"."level_1_national_id" AS "level_1_national_id"
	,COALESCE(MAX("_twmVC0"."relation_type"), 'Money Transfer') AS "relation_type"
	,"_twmVC0"."frequency" AS "frequency"
	,"_twmVC0"."amount" AS "amount"
	,COUNT(*) AS "direction_count"
FROM "public"."sna_str1_stp8" AS "_twmVC0"
GROUP BY 1, 2, 3, 4, 5, 7, 8
);
/********************  sna_str1_stp10 - delinq_1 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp10";
CREATE FACT TABLE "public"."sna_str1_stp10"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,CAST("_twmVC0"."yyyymm" AS INTEGER) AS "yyyyymm"
	,"_twmVC0"."number_of_days_delayed" AS "num_delay_day"
	,CASE WHEN "_twmVC0"."number_of_days_delayed" BETWEEN 1 AND 20 THEN 'G0' WHEN "_twmVC0"."number_of_days_delayed" BETWEEN 21 AND 50 THEN 'D1' WHEN "_twmVC0"."number_of_days_delayed" BETWEEN 51 AND 80 THEN 'D2' WHEN "_twmVC0"."number_of_days_delayed" > 80 THEN 'D3' ELSE 'None' END AS "delinq_level"
FROM "public"."payment_delays_source" AS "_twmVC0"
);
/********************  sna_str1_stp11 - delinq_2 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp11";
CREATE FACT TABLE "public"."sna_str1_stp11"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."yyyyymm" AS "yyyyymm"
	,CASE WHEN "_twmVC0"."delinq_level" = 'D1' THEN 1 ELSE 0 END AS "D1_delinq_level"
	,CASE WHEN "_twmVC0"."delinq_level" = 'D2' THEN 1 ELSE 0 END AS "D2_delinq_level"
	,CASE WHEN "_twmVC0"."delinq_level" = 'D3' THEN 1 ELSE 0 END AS "D3_delinq_level"
	,CASE WHEN "_twmVC0"."delinq_level" = 'G0' THEN 1 ELSE 0 END AS "G0_delinq_level"
FROM "public"."sna_str1_stp10" AS "_twmVC0"
);
/********************  sna_str1_stp12 - delinq_3 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp12";
CREATE FACT TABLE "public"."sna_str1_stp12"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."yyyyymm" AS "yyyyymm"
	,SUM("_twmVC0"."G0_delinq_level") AS "G0_delinq_level"
	,SUM("_twmVC0"."D1_delinq_level") AS "D1_delinq_level"
	,SUM("_twmVC0"."D2_delinq_level") AS "D2_delinq_level"
	,SUM("_twmVC0"."D3_delinq_level") AS "D3_delinq_level"
	,SUM("_twmVC0"."G0_delinq_level") + SUM("_twmVC0"."D1_delinq_level") + SUM("_twmVC0"."D2_delinq_level") + SUM("_twmVC0"."D3_delinq_level") AS "total_delinquent_prods"
FROM "public"."sna_str1_stp11" AS "_twmVC0"
GROUP BY 1, 2
);
/********************  sna_str1_stp13 - delinq_4 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp13";
CREATE FACT TABLE "public"."sna_str1_stp13"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."yyyyymm" AS "yyyyymm"
	,"_twmVC0"."G0_delinq_level" AS "G0_delinq_level"
	,"_twmVC0"."D1_delinq_level" AS "D1_delinq_level"
	,"_twmVC0"."D2_delinq_level" AS "D2_delinq_level"
	,"_twmVC0"."D3_delinq_level" AS "D3_delinq_level"
	,"_twmVC0"."total_delinquent_prods" AS "total_delinquent_prods"
	,ROW_NUMBER() OVER (PARTITION BY "_twmVC0"."cust_id" ORDER BY "_twmVC0"."yyyyymm" DESC NULLS LAST ) AS "rank"
FROM "public"."sna_str1_stp12" AS "_twmVC0"
);
/********************  sna_str1_stp14 - delinq_5 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp14";
CREATE FACT TABLE "public"."sna_str1_stp14"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."yyyyymm" AS "yyyyymm"
	,"_twmVC0"."G0_delinq_level" AS "G0_delinq_level"
	,"_twmVC0"."D1_delinq_level" AS "D1_delinq_level"
	,"_twmVC0"."D2_delinq_level" AS "D2_delinq_level"
	,"_twmVC0"."D3_delinq_level" AS "D3_delinq_level"
	,"_twmVC0"."total_delinquent_prods" AS "total_delinquent_prods"
	,"_twmVC0"."rank" AS "rank"
	,"_twmVC0"."G0_delinq_level" / "_twmVC0"."rank" AS "G0_delinq_level_decay"
	,"_twmVC0"."D1_delinq_level" / "_twmVC0"."rank" AS "D1_delinq_level_decay"
	,"_twmVC0"."D2_delinq_level" / "_twmVC0"."rank" AS "D2_delinq_level_decay"
	,"_twmVC0"."D3_delinq_level" / "_twmVC0"."rank" AS "D3_delinq_level_decay"
	,"_twmVC0"."total_delinquent_prods" / "_twmVC0"."rank" AS "total_delinquent_prods_decay"
FROM "public"."sna_str1_stp13" AS "_twmVC0"
);
/********************  sna_str1_stp15 - delinq_6 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp15";
CREATE FACT TABLE "public"."sna_str1_stp15"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,SUM("_twmVC0"."G0_delinq_level") AS "G0_delinq_level"
	,SUM("_twmVC0"."D1_delinq_level") AS "D1_delinq_level"
	,SUM("_twmVC0"."D2_delinq_level") AS "D2_delinq_level"
	,SUM("_twmVC0"."D3_delinq_level") AS "D3_delinq_level"
	,SUM("_twmVC0"."total_delinquent_prods") AS "total_delinquent_prods"
	,SUM("_twmVC0"."G0_delinq_level_decay") AS "G0_delinq_level_decay"
	,SUM("_twmVC0"."D1_delinq_level_decay") AS "D1_delinq_level_decay"
	,SUM("_twmVC0"."D2_delinq_level_decay") AS "D2_delinq_level_decay"
	,SUM("_twmVC0"."D3_delinq_level_decay") AS "D3_delinq_level_decay"
	,SUM("_twmVC0"."total_delinquent_prods_decay") AS "total_delinquent_prods_decay"
FROM "public"."sna_str1_stp14" AS "_twmVC0"
GROUP BY 1
);
/********************  sna_str1_stp16 - base_4 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp16";
CREATE FACT TABLE "public"."sna_str1_stp16"() DISTRIBUTE BY HASH("focus_customer_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."focus_customer_id" AS "focus_customer_id"
	,"_twmVC0"."level_1_customer_id" AS "level_1_customer_id"
	,"_twmVC0"."relation_type" AS "relation_type"
	,COALESCE("_twmVC1"."G0_delinq_level_decay", 0) AS "G0_delinq_level_decay"
	,COALESCE("_twmVC1"."D1_delinq_level_decay", 0) AS "D1_delinq_level_decay"
	,COALESCE("_twmVC1"."D2_delinq_level_decay", 0) AS "D2_delinq_level_decay"
	,COALESCE("_twmVC1"."D3_delinq_level_decay", 0) AS "D3_delinq_level_decay"
	,COALESCE("_twmVC1"."total_delinquent_prods_decay", 0) AS "total_delinquent_prods_decay"
FROM "public"."sna_str1_stp9" AS "_twmVC0"
	LEFT OUTER JOIN "public"."sna_str1_stp15" AS "_twmVC1"
		ON "_twmVC0"."level_1_customer_id" = "_twmVC1"."cust_id"
WHERE (("_twmVC0"."focus_customer_id" IS NOT NULL) AND ("_twmVC0"."level_1_customer_id" IS NOT NULL)) AND "_twmVC0"."relation_type" NOT IN ('Money Transfer')
);
/********************  sna_str1_stp17 - base_5 ********************/

DROP TABLE IF EXISTS "public"."sna_str1_stp17";
CREATE FACT TABLE "public"."sna_str1_stp17"() DISTRIBUTE BY HASH("cust_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."focus_customer_id" AS "cust_id"
	,SUM("_twmVC0"."G0_delinq_level_decay") AS "tot_G0_delinq_level_decay"
	,SUM("_twmVC0"."D1_delinq_level_decay") AS "tot_D1_delinq_level_decay"
	,SUM("_twmVC0"."D2_delinq_level_decay") AS "tot_D2_delinq_level_decay"
	,SUM("_twmVC0"."D3_delinq_level_decay") AS "tot_D3_delinq_level_decay"
	,SUM("_twmVC0"."total_delinquent_prods_decay") AS "tot_total_delinquent_prods_dec"
	,AVG("_twmVC0"."G0_delinq_level_decay") AS "avg_G0_delinq_level_decay"
	,AVG("_twmVC0"."D1_delinq_level_decay") AS "avg_D1_delinq_level_decay"
	,AVG("_twmVC0"."D2_delinq_level_decay") AS "avg_D2_delinq_level_decay"
	,AVG("_twmVC0"."D3_delinq_level_decay") AS "avg_D3_delinq_level_decay"
	,AVG("_twmVC0"."total_delinquent_prods_decay") AS "avg_total_delinquent_prods_dec"
FROM "public"."sna_str1_stp16" AS "_twmVC0"
GROUP BY 1
);
