 --/********************  ---------------Path----------------- ********************/

--SELECT
--*
--FROM
--onboarding.event_list
--where
--event_list.cmusno = '4556450201988770'


SELECT
cust_id
,card_no
,stmt_dt
,target
--,event_id
,event_date
,extract( 'year' from event_date)::int || '_' || extract( 'quarter' from event_date)::int as event_qtr
,domain_type
--,event1
--,event2
--,event3
--,chn_name
FROM
onboarding.event_list
INNER JOIN
risk.mga_customer_base_train
ON
event_list.cmusno = mga_customer_base_train.cust_id

WHERE
domain_type NOT IN ('CALL_CENTER', 'MARKETING_OFFER')
AND
event_date between mga_customer_base_train.stmt_dt - INTEGER '180' AND mga_customer_base_train.stmt_dt
GROUP BY 1,2,3,4,5,6,7;


--/********************  path_str1_stp1 - triplets train ********************/

DROP TABLE IF EXISTS risk.mga_path_str1_stp1 CASCADE;
CREATE FACT TABLE risk.mga_path_str1_stp1 DISTRIBUTE BY HASH(card_no)
AS SELECT card_no
	, path
	, event_qtr
	, start_date
	, end_date
	, end_date - start_date as elapsed_time
	, target
FROM npath(                                        
	on (
			SELECT
			cust_id
			,card_no
			,stmt_dt
			,target
			--,event_id
			,event_date
			,extract( 'year' from event_date)::int || '_' || extract( 'quarter' from event_date)::int as event_qtr
			,domain_type
			--,event1
			--,event2
			--,event3
			--,chn_name
			FROM
			onboarding.event_list
			INNER JOIN
			risk.mga_customer_base_train
			ON
			event_list.cmusno = mga_customer_base_train.cust_id
			
			WHERE
			domain_type NOT IN ('CALL_CENTER', 'MARKETING_OFFER')
			AND
			event_date between mga_customer_base_train.stmt_dt - INTEGER '180' AND mga_customer_base_train.stmt_dt
			GROUP BY 1,2,3,4,5,6,7
	)
	PARTITION BY card_no
	ORDER BY event_date, domain_type
	MODE('OVERLAPPING')
	SYMBOLS(TRUE as a)
	
	PATTERN ('a{3}')
	RESULT(ACCUMULATE(domain_type of ANY(a)) as path,
			FIRST(card_no of ANY(a)) as card_no,
			FIRST(target of a) as target,
			FIRST(event_qtr of a) as event_qtr,
			FIRST(event_date of a) as start_date,
			LAST(event_date of  a) as end_date)
	)
WHERE extract(day from end_date-start_date)<= 90;

--/********************  path_str1_stp2 - naivebaye triplets model ********************/

DROP TABLE IF EXISTS risk.mga_path_str1_stp2;
CREATE TABLE risk.mga_path_str1_stp2 DISTRIBUTE BY REPLICATION
AS
SELECT * FROM NaiveBayesTextClassifierTrainer (
	ON (SELECT * FROM NaiveBayesTextClassifierInternal (
		ON (SELECT card_no::varchar card_no
		, replace(replace(path,'[', ''),']','') as path
		, target::varchar as target 
		    FROM risk.mga_path_str1_stp1) as a  
		PARTITION BY target
		Token_Column ('path')
		Model_Type ('Bernoulli')
		Doc_ID_Columns ('card_no')
		Doc_Category_Column ('target')
		)
	)
PARTITION BY 1);

--/********************  path_str1_stp3 - pivot probabilities ********************/
DROP TABLE IF EXISTS risk.mga_path_str1_stp3;
CREATE TABLE risk.mga_path_str1_stp3 DISTRIBUTE BY REPLICATION
AS
SELECT '['||token||']' AS path
		, COALESCE(prob_0, 0) AS prob_0
		, COALESCE(prob_1,0) AS prob_1
	FROM pivot ( 
	ON (SELECT * FROM risk.mga_path_str1_stp2 WHERE token NOT ilike '%ASTER%')
	PARTITION BY token 
	PARTITIONS ('token')
	pivot_column('category') 
	PIVOT_KEYS('1','0')
	metrics('prob') 
);

--/********************  path_str1_stp4 - var targets ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_stp4";
CREATE FACT TABLE "risk"."mga_path_str1_stp4"() DISTRIBUTE BY HASH("path") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."path" AS "path"
	,"_twmVC0"."prob_0" AS "prob_0"
	,"_twmVC0"."prob_1" AS "prob_1"
	,CASE WHEN "_twmVC0"."prob_1" > "_twmVC0"."prob_0" THEN 1 ELSE 0 END AS "target"
	,CASE WHEN "_twmVC0"."prob_1" > (4 * "_twmVC0"."prob_0") THEN 1 ELSE 0 END AS "target40"
	,CASE WHEN "_twmVC0"."prob_0" > (4 * "_twmVC0"."prob_1") THEN 1 ELSE 0 END AS "target0_40"
FROM "risk"."mga_path_str1_stp3" AS "_twmVC0"
);

--/********************  path_str1_str5 - path aggregates ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_str5";
CREATE FACT TABLE "risk"."mga_path_str1_str5"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM((COALESCE("_twmVC1"."prob_1", 0))) AS "prob_1"
	,SUM((COALESCE("_twmVC1"."prob_0", 0))) AS "prob_0"
	,COUNT(*) AS "total_path_count"
	,SUM("_twmVC1"."target") AS "default_path_count"
	,COUNT(*) - SUM("_twmVC1"."target") AS "nondefault_path_count"
	,SUM("_twmVC1"."target40") AS "target40_count"
	,SUM("_twmVC1"."target0_40") AS "target0_40_count"
FROM "risk"."mga_path_str1_stp1" AS "_twmVC0"
	INNER JOIN "risk"."mga_path_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."path" = "_twmVC1"."path"
GROUP BY 1
);

--/********************  path_str1_str6 - path flags ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_str6";
CREATE FACT TABLE "risk"."mga_path_str1_str6"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."default_path_count" > 0 THEN 1 ELSE 0 END AS "default_path_flag"
	,CASE WHEN "_twmVC0"."nondefault_path_count" > 0 THEN 1 ELSE 0 END AS "nondefault_path_flag"
	,CASE WHEN "_twmVC0"."target40_count" > 0 THEN 1 ELSE 0 END AS "target40_flag"
	,CASE WHEN "_twmVC0"."target0_40_count" > 0 THEN 1 ELSE 0 END AS "target0_40_flag"
	,CAST("_twmVC0"."default_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "default_path_percentage"
	,CAST("_twmVC0"."nondefault_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "nondefault_path_percentage"
	,CAST("_twmVC0"."target40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target40_percentage"
	,CAST("_twmVC0"."target0_40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target0_40_percentage"
FROM "risk"."mga_path_str1_str5" AS "_twmVC0"
);
--/********************  path_str1_str7 - path ads ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_str7";
CREATE FACT TABLE "risk"."mga_path_str1_str7"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
	 "_twmJoin0"."card_no"
	,"_twmJoin0"."cust_id"
	,"_twmJoin0"."target"
	,"_twmJoin1"."total_path_count"
	,"_twmJoin1"."default_path_count"
	,"_twmJoin1"."nondefault_path_count"
	,"_twmJoin1"."target40_count"
	,"_twmJoin1"."target0_40_count"
	,"_twmJoin2"."default_path_flag"
	,"_twmJoin2"."nondefault_path_flag"
	,"_twmJoin2"."target40_flag"
	,"_twmJoin2"."target0_40_flag"
	,"_twmJoin2"."default_path_percentage"
	,"_twmJoin2"."nondefault_path_percentage"
	,"_twmJoin2"."target40_percentage"
	,"_twmJoin2"."target0_40_percentage"

FROM "risk"."mga_customer_base_train" AS "_twmJoin0"
	LEFT OUTER JOIN "risk"."mga_path_str1_str5" AS "_twmJoin1"
		ON "_twmJoin0"."card_no" = "_twmJoin1"."card_no"
	LEFT OUTER JOIN "risk"."mga_path_str1_str6" AS "_twmJoin2"
		ON "_twmJoin0"."card_no" = "_twmJoin2"."card_no"
);
--/********************  path_str1_str8 - ads null replacement ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_str8";
CREATE FACT TABLE "risk"."mga_path_str1_str8"() DISTRIBUTE BY HASH("card_no") AS (
SELECT
 "A"."card_no" AS "card_no"
,"A"."cust_id" AS "cust_id"
,"A"."target" AS "target"
,COALESCE( "default_path_count", 0) AS "default_path_count"
,COALESCE( "default_path_flag", 0.0E+000) AS "default_path_flag"
,COALESCE( "default_path_percentage", 0.0E+000) AS "default_path_percentage"
,COALESCE( "nondefault_path_count", 0) AS "nondefault_path_count"
,COALESCE( "nondefault_path_flag", 0.0E+000) AS "nondefault_path_flag"
,COALESCE( "nondefault_path_percentage", 0.0E+000) AS "nondefault_path_percentage"
,COALESCE( "target0_40_count", 0) AS "target0_40_count"
,COALESCE( "target0_40_flag", 0.0E+000) AS "target0_40_flag"
,COALESCE( "target0_40_percentage", 0.0E+000) AS "target0_40_percentage"
,COALESCE( "target40_count", 0) AS "target40_count"
,COALESCE( "target40_flag", 0.0E+000) AS "target40_flag"
,COALESCE( "target40_percentage", 0.0E+000) AS "target40_percentage"
,COALESCE( "total_path_count", 0) AS "total_path_count"
FROM "risk"."mga_path_str1_str7" "A"
);

grant all on risk.mga_path_str1_str8 to public;
analyze risk.mga_path_str1_str8;

--/********************  path_str1_stp9 - triplets test ********************/

DROP TABLE IF EXISTS risk.mga_path_str1_stp9 CASCADE;
CREATE FACT TABLE risk.mga_path_str1_stp9 DISTRIBUTE BY HASH(card_no)
AS SELECT card_no
	, path
	, event_qtr
	, start_date
	, end_date
	, end_date - start_date as elapsed_time
	, target
FROM npath(                                        
	on (
			SELECT
			cust_id
			,card_no
			,stmt_dt
			,target
			--,event_id
			,event_date
			,extract( 'year' from event_date)::int || '_' || extract( 'quarter' from event_date)::int as event_qtr
			,domain_type
			--,event1
			--,event2
			--,event3
			--,chn_name
			FROM
			onboarding.event_list
			INNER JOIN
			risk.mga_customer_base_test
			ON
			event_list.cmusno = mga_customer_base_test.cust_id
			
			WHERE
			domain_type NOT IN ('CALL_CENTER', 'MARKETING_OFFER')
			AND
			event_date between mga_customer_base_test.stmt_dt - INTEGER '180' AND mga_customer_base_test.stmt_dt
			GROUP BY 1,2,3,4,5,6,7
	   )
	PARTITION BY card_no
	ORDER BY event_date, domain_type
	MODE('OVERLAPPING')
	SYMBOLS(TRUE as a)
	PATTERN ('a{3}')
	RESULT(ACCUMULATE(domain_type of ANY(a)) as path,
			FIRST(card_no of ANY(a)) as card_no,
			FIRST(target of a) as target,
			FIRST(event_qtr of a) as event_qtr,
			FIRST(event_date of a) as start_date,
			LAST(event_date of  a) as end_date)
	)
WHERE extract(day from end_date-start_date) <= 90;

--/********************  path_str1_stp10 - path agg test ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_stp10";
CREATE FACT TABLE "risk"."mga_path_str1_stp10"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM((COALESCE("_twmVC1"."prob_1", 0))) AS "prob_1"
	,SUM((COALESCE("_twmVC1"."prob_0", 0))) AS "prob_0"
	,COUNT(*) AS "total_path_count"
	,SUM("_twmVC1"."target") AS "default_path_count"
	,COUNT(*) - SUM("_twmVC1"."target") AS "nondefault_path_count"
	,SUM("_twmVC1"."target40") AS "target40_count"
	,"_twmVC1"."target0_40" AS "target0_40_count"
FROM "risk"."mga_path_str1_stp9" AS "_twmVC0"
	INNER JOIN "risk"."mga_path_str1_stp4" AS "_twmVC1"
		ON "_twmVC0"."path" = "_twmVC1"."path"
GROUP BY 1, 8
);

--/********************  path_str1_str11 - path flags test ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_stp11";
CREATE FACT TABLE "risk"."mga_path_str1_stp11"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."default_path_count" > 0 THEN 1 ELSE 0 END AS "default_path_flag"
	,CASE WHEN "_twmVC0"."nondefault_path_count" > 0 THEN 1 ELSE 0 END AS "nondefault_path_flag"
	,CASE WHEN "_twmVC0"."target40_count" > 0 THEN 1 ELSE 0 END AS "target40_flag"
	,CASE WHEN "_twmVC0"."target0_40_count" > 0 THEN 1 ELSE 0 END AS "target0_40_flag"
	,CAST("_twmVC0"."default_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "default_path_percentage"
	,CAST("_twmVC0"."nondefault_path_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "nondefault_path_percentage"
	,CAST("_twmVC0"."target40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target40_percentage"
	,CAST("_twmVC0"."target0_40_count" AS FLOAT) / (NULLIF("_twmVC0"."total_path_count", 0)) AS "target0_40_percentage"
FROM "risk"."mga_path_str1_stp10" AS "_twmVC0"
);

--/********************  path_str1_stp12 - path ads test ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_stp12";
CREATE FACT TABLE "risk"."mga_path_str1_stp12"() DISTRIBUTE BY HASH("card_no") AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."prob_1" AS "prob_1"
	,"_twmVC1"."prob_0" AS "prob_0"
	,"_twmVC1"."total_path_count" AS "total_path_count"
	,"_twmVC1"."default_path_count" AS "default_path_count"
	,"_twmVC1"."nondefault_path_count" AS "nondefault_path_count"
	,"_twmVC1"."target40_count" AS "target40_count"
	,"_twmVC1"."target0_40_count" AS "target0_40_count"
	,"_twmVC2"."default_path_flag" AS "default_path_flag"
	,"_twmVC2"."nondefault_path_flag" AS "nondefault_path_flag"
	,"_twmVC2"."target40_flag" AS "target40_flag"
	,"_twmVC2"."default_path_percentage" AS "default_path_percentage"
	,"_twmVC2"."nondefault_path_percentage" AS "nondefault_path_percentage"
	,"_twmVC2"."target40_percentage" AS "target40_percentage"
	,"_twmVC2"."target0_40_percentage" AS "target0_40_percentage"
	,"_twmVC2"."target0_40_flag" AS "target0_40_flag"
FROM "risk"."mga_customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."mga_path_str1_stp11" AS "_twmVC2"
		ON "_twmVC0"."card_no" = "_twmVC2"."card_no"
	LEFT OUTER JOIN "risk"."mga_path_str1_stp10" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);
--/********************  path_str1_stp13 - ads null replacement test ********************/

DROP TABLE IF EXISTS "risk"."mga_path_str1_stp13";
CREATE FACT TABLE "risk"."mga_path_str1_stp13"() DISTRIBUTE BY HASH("card_no") AS (
SELECT
 "A"."card_no" AS "card_no"
,"A"."cust_id" AS "cust_id"
,"A"."target" AS "target"
,COALESCE( "default_path_count", 0) AS "default_path_count"
,COALESCE( "default_path_flag", 0.0E+000) AS "default_path_flag"
,COALESCE( "default_path_percentage", 0.0E+000) AS "default_path_percentage"
,COALESCE( "nondefault_path_count", 0) AS "nondefault_path_count"
,COALESCE( "nondefault_path_flag", 0.0E+000) AS "nondefault_path_flag"
,COALESCE( "nondefault_path_percentage", 0.0E+000) AS "nondefault_path_percentage"
,COALESCE( "target0_40_count", 0.0E+000) AS "target0_40_count"
,COALESCE( "target0_40_percentage", 0.0E+000) AS "target0_40_percentage"
,COALESCE( "target0_40_flag", 0.0E+000) AS "target0_40_flag"
,COALESCE( "target40_count", 0) AS "target40_count"
,COALESCE( "target40_flag", 0.0E+000) AS "target40_flag"
,COALESCE( "target40_percentage", 0.0E+000) AS "target40_percentage"
,COALESCE( "total_path_count", 0) AS "total_path_count"
FROM "risk"."mga_path_str1_stp12" "A"
);

grant all on risk.mga_path_str1_stp13 to public;
analyze risk.mga_path_str1_stp13;