SELECT
*
FROM
"risk"."merchant_segment_table";

-- biz bunu simdi sadece 1 model periyodu icin yapiyoruz. 1 yillik trx icin ay ay target datasi olusturulup oyle yapilmasi lazim
--orn aug target icin july, july target icin june olcak. boyle bir yillik rolling periyod gitcek
-- (unutma) yi asagida arat o stepteki where kosulu elemesini en basta yapman lazimdi

DROP TABLE IF EXISTS "risk"."mga_customer_base";
CREATE FACT TABLE "risk"."mga_customer_base"() DISTRIBUTE BY HASH("card_id") COMPRESS LOW AS (
select cust_id ,card_id ,max(stmt_dt) AS stmt_dt ,max(target) AS target FROM "risk"."cust_dt_dummy" where (Extract(YEAR FROM "stmt_dt")*100) + Extract(MONTH FROM "stmt_dt") = 201709 GROUP BY 1,2
);

GRANT ALL on risk.mga_customer_base to public;
analyze risk.mga_customer_base;
	
--/********************  customer_base_train ********************/

DROP TABLE IF EXISTS "risk"."mga_customer_base_train";
CREATE FACT TABLE "risk"."mga_customer_base_train"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
	 "cust_id"
	,"card_id" as card_no
	,"stmt_dt"
	,"target"
FROM sample(
ON (SELECT *, 
CASE 
WHEN target = 0 THEN 'non default'
WHEN target = 1 THEN 'default'
END AS stratum 
FROM "risk"."mga_customer_base")
ConditionOnColumn('stratum')
ConditionOn('non default', 'default')
SampleFraction('0.7', '0.7'))
);

GRANT ALL on risk.mga_customer_base_train to public;
analyze risk.mga_customer_base_train;

--/********************  customer_base_test ********************/

DROP TABLE IF EXISTS "risk"."mga_customer_base_test";
CREATE FACT TABLE "risk"."mga_customer_base_test"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
 	 "card_id" AS card_no
	,"cust_id"
	,"stmt_dt"
	,"target"
FROM "risk"."mga_customer_base"
EXCEPT
SELECT
 	 "card_no"
	,"cust_id"
	,"stmt_dt"
	,"target"
FROM "risk"."mga_customer_base_train"
);



GRANT ALL on risk.mga_customer_base_test to public;
analyze risk.mga_customer_base_test;


--/********************  merchseg_str1_stp1 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp1";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp1"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 merchant_id
	,COUNT(DISTINCT card_id) AS distinct_cards_per_merchant
	,SUM(trx_cnt) AS total_transaction_count
	,SUM(trx_amt_tl) AS total_transaction_amount
	,SUM(trx_amt_tl) / CAST(SUM(trx_cnt) AS FLOAT) AS average_transaction_amount
FROM 
"risk"."merchant_segment_table"
WHERE
trx_date between to_date('2017-07-31', 'YYYY-MM-DD') - INTEGER '365' AND to_date('2017-07-31', 'YYYY-MM-DD')
GROUP BY 1
);

--/********************  merchseg_str1_stp2 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp2";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 card_id AS card_no
	,merchant_id
	,COUNT(DISTINCT (EXTRACT('YEAR' FROM trx_date) * 100) + EXTRACT('MONTH' FROM trx_date)) AS card_active_months
FROM 
"risk"."merchant_segment_table"
WHERE
trx_date between to_date('2017-07-31', 'YYYY-MM-DD') - INTEGER '365' AND to_date('2017-07-31', 'YYYY-MM-DD')
GROUP BY 1, 2
);

----/********************  merchseg_str1_stp3 ********************/

-- ilgili merchantta kac tane distinct kk kullanildigi bilgisini cekiyorsun. bunun daha sonra analizine bakip karar vermen lazim.
-- simdilik 50 seciyoruz
DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp3";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp3"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,AVG("_twmVC0"."card_active_months") AS "average_active_month"
	,COUNT(DISTINCT "_twmVC0"."card_no") AS "active_cards"
FROM "risk"."mga_merchseg_str1_stp2" AS "_twmVC0"
GROUP BY 1
HAVING COUNT(DISTINCT "_twmVC0"."card_no") > 50
);


/* 
 select
active_cards
,Count(*)
FROM
risk.mga_merchseg_str1_stp3
group by 1
*/
 
----/********************  merchseg_str1_stp4 ********************/

-- This segmentaiton will be for dpd > 0. not only for non lazy customers.

--PLEASE UPDATE THE JOIN HERE	
DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp4";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp4"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,COUNT(DISTINCT "_twmVC0"."card_no") AS "merchant_total_cards"
	,COUNT(DISTINCT "_twmVC1"."cc_no") AS "merchant_total_default_cards"
	,COUNT(DISTINCT "_twmVC1"."cc_no") / CAST(COUNT(DISTINCT "_twmVC0"."card_no") AS FLOAT) AS "merchant_card_default_ratio"
FROM "risk"."mga_merchseg_str1_stp2" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."target_aug17" AS "_twmVC1"
		ON
		"_twmVC0"."card_no" = "_twmVC1"."cc_no"
		--AND
		--(Extract(YEAR FROM "_twmVC1"."stmt_dt")*100) + Extract(MONTH FROM "_twmVC1"."stmt_dt") = 201708
GROUP BY 1
HAVING COUNT(DISTINCT "_twmVC0"."card_no") > 2
);



----/********************  merchseg_str1_stp5 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp5";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp5"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."merchant_id" AS "merchant_id"
	,"_twmVC0"."average_transaction_amount" AS "average_transaction_amount"
	,"_twmVC1"."active_cards" AS "active_cards"
	,"_twmVC1"."average_active_month" AS "average_active_month"
	,"_twmVC2"."merchant_card_default_ratio" AS "merchant_card_default_ratio"
FROM "risk"."mga_merchseg_str1_stp1" AS "_twmVC0"
	INNER JOIN "risk"."mga_merchseg_str1_stp3" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
	INNER JOIN "risk"."mga_merchseg_str1_stp4" AS "_twmVC2"
		ON "_twmVC0"."merchant_id" = "_twmVC2"."merchant_id"
);

----/********************  merchseg_str1_stp6 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_str1_stp6";
CREATE FACT TABLE "risk"."mga_merchseg_str1_stp6"() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
SELECT
 "A"."merchant_id" AS "merchant_id"
,("active_cards" - "_twm_mean2") / "_twm_std2" AS "active_cards"
,("average_active_month" - "_twm_mean3") / "_twm_std3" AS "average_active_month"
,("average_transaction_amount" - "_twm_mean4") / "_twm_std4" AS "average_transaction_amount"
,("merchant_card_default_ratio" - "_twm_mean5") / "_twm_std5" AS "merchant_card_default_ratio"
FROM 
"risk"."mga_merchseg_str1_stp5" AS "A"
,
	(SELECT
	 AVG("active_cards" ) AS "_twm_mean2"
	,STDDEV_POP(CAST("active_cards" AS FLOAT)) AS "_twm_std2"
	,AVG("average_active_month" ) AS "_twm_mean3"
	,STDDEV_POP(CAST("average_active_month" AS FLOAT)) AS "_twm_std3"
	,AVG("average_transaction_amount" ) AS "_twm_mean4"
	,STDDEV_POP(CAST("average_transaction_amount" AS FLOAT)) AS "_twm_std4"
	,AVG("merchant_card_default_ratio" ) AS "_twm_mean5"
	,STDDEV_POP(CAST("merchant_card_default_ratio" AS FLOAT)) AS "_twm_std5"
	FROM "risk"."mga_merchseg_str1_stp5") AS "B"
);

----/********************  merchseg_str1_stp7 ********************/

-- t1 ile t2 nin arasini cok acarsan cok cluster olusuo o yuzden mumkun old birbirine yakin seciosun ve t1 t2'den buyuk olmak zorunda
SELECT * FROM Canopy (
ON (SELECT 1) PARTITION BY 1
InputTable ('risk.mga_merchseg_str1_stp6')
LooseDistance ('2.1') -- T1 cemberin yaricapi
TightDistance ('2') -- T2 2 segmentin birbirine uzakligi 
) ORDER BY canopyid;


SELECT
avg(active_cards) AS active_cards 
,avg(average_active_month) AS average_active_month
,avg(average_transaction_amount) AS average_transaction_amount
,avg(merchant_card_default_ratio) AS merchant_card_default_ratio
FROM
risk.mga_merchseg_str1_stp6;

SELECT
*
FROM
risk.mga_merchseg_str1_stp6
WHERE
active_cards IS NULL
OR
average_active_month IS NULL
OR
average_transaction_amount IS NULL
OR 
merchant_card_default_ratio IS NULL;



----/********************  8_Merchant_Segments ********************/

--canopy ile ilk once t1 ve t2 degistirip excel'de inceleyip kac cluster seccemize karar veriyoruz 
-- 10 cluster secmeye karar verdik o yuzden simdi 10 cluster icin kmeans calistirdik
-- sas'taki hiyerarsik secim aster'de olmadigi icin direkt kmeans yerine ilk once canopy kullaniliyor

-- withinss : with sum of square errors
-- between de onun cluster'lar arasi olani 
-- bu ikisinin mumkun oldugunca kucuk olmasi lazim yani 20 ler 30 lar falan ok ama 100 falan olmasin
-- cluster larin withinss degerlerinin de birbirlerine yakin olmasi lazm
-- maxiternum: default 10 -- biz 70 yapinca converged : yes oldu. yes olana kadar seg kabul diil
-- threshold: conversion threshold. ne kadar converge etmesi gerektigini soyluyorsun

--mga_merchant_segmentation_score score ouput tablosu
drop table if exists risk.mga_merchant_segmentation_score;
drop table if exists risk.mga_merchant_segmentation_centroids;
SELECT
*
FROM
kmeans(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.mga_merchseg_str1_stp6')
OutputTable('risk.mga_merchant_segmentation_centroids')
NumberK ('11')
--Threshold ('0.01')
MaxIterNum ('70')
ClusteredOutput ('risk.mga_merchant_segmentation_score')
);

-- bu asagidaki sekilde skorlayabilirsin
/*
CREATE FACT TABLE risk.mga_merchant_segmentation_score() DISTRIBUTE BY HASH("merchant_id") COMPRESS LOW AS (
	SELECT *
	FROM kmeansplot (
	ON risk.mga_merchseg_str1_stp6 as a PARTITION BY ANY
	ON risk.mga_merchant_segmentation_centroids as b DIMENSION 
	CENTROIDSTABLE('b')
	)
);*/

-- sas'taki seed i aster'de bu asagidaki kodla yapiyorsun
--- segmentasyonda 4 farkli girdi oldugu icin o 4 unu _ ile ayiriyorsun
/*
drop table if exists risk.mga_merchant_segmentation_score;
drop table if exists risk.mga_merchant_segmentation_centroids;
SELECT
*
FROM
kmeans(
ON (SELECT 1)
PARTITION BY 1
InputTable('risk.mga_merchseg_str1_stp6')
OutputTable('risk.mga_merchant_segmentation_centroids')
NumberK ('10')
--Threshold ('0.01')
MaxIterNum ('70')
InitialSeeds ('-0.286099580070262_-0.32263934276635_0.129230883723217_0.0546649038142936','-0.208955307185533_-0.323725556068448_-0.527639468077938_0.313819124169262','5.35170288749674_3.05225614551347_-0.713950508253609_0.787808315656366','-0.382157872106411_-0.480293472488224_0.521253149822098_-2.15552119637093','-0.227043731133755_-0.0906801177165603_-0.56129140523458_1.26846277818019','-0.377553425468367_-0.536900447178061_3.68453636453725_-1.50200008099527','1.49121069061009_0.414483489106721_-0.576730609219956_0.716815204314978','-0.328621682527106_-0.162792790041794_-0.310901284205416_-0.85030165057203','-0.306917833837733_-0.0411945501867459_1.53080196551314_-0.220297594870427','-0.0248234511895917_3.50104052956897_-0.695626710963354_0.033039564953071')
ClusteredOutput ('risk.mga_merchant_segmentation_score')
);
*/


--For Making the Spidercharts

--Population Average
/*
SELECT
avg(active_cards) AS active_cards 
,avg(average_active_month) AS average_active_month
,avg(average_transaction_amount) AS average_transaction_amount
,avg(merchant_card_default_ratio) AS merchant_card_default_ratio
FROM
risk.mga_merchseg_str1_stp6
*/

--Segment Average
/*
SELECT
clusterid
,avg(active_cards) AS active_cards 
,avg(average_active_month) AS average_active_month
,avg(average_transaction_amount) AS average_transaction_amount
,avg(merchant_card_default_ratio) AS merchant_card_default_ratio
FROM
risk.mga_merchant_segmentation_score
LEFT OUTER JOIN
risk.mga_merchseg_str1_stp6
ON 
mga_merchant_segmentation_score.merchant_id = mga_merchseg_str1_stp6.merchant_id
GROUP BY 1
*/

/*
SELECT
*
FROM
risk.mga_merchant_segmentation_score
*/

--/********************  *************************** ********************/
--/********************  merchseg_usg_sprd_str1_stp1 ********************/
--/********************  *************************** ********************/

-- datayi skorlarken segment atamadigin merchantlar olabilir onlar icin 99 atiyorsun
DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp1";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_id" AS "card_no"
	,COALESCE("_twmVC1"."clusterid", 99) AS "clusterid"
	,SUM("_twmVC0"."trx_amt_tl") AS "transaction_amount"
	,SUM("_twmVC0"."trx_cnt") AS "transaction_count"
FROM "risk"."merchant_segment_table" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."mga_merchant_segmentation_score" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
WHERE
trx_date between to_date('2017-08-31', 'YYYY-MM-DD') - INTEGER '365' AND to_date('2017-08-31', 'YYYY-MM-DD')
GROUP BY 1, 2
);

/*
SELECT
*
FROM
risk.mga_merchseg_usg_sprd_str1_stp1
WHERE
card_no = '5530900000845973'
*/

--/********************  merchseg_usg_sprd_str1_stp2 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp2";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."clusterid" AS "clusterid"
	,"_twmVC0"."transaction_count" AS "transaction_count"
	,"_twmVC0"."transaction_amount" AS "transaction_amount"
	,SUM("_twmVC0"."transaction_count") OVER (PARTITION BY "_twmVC0"."card_no" ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total_transaction_count"
	,SUM("_twmVC0"."transaction_amount") OVER (PARTITION BY "_twmVC0"."card_no" ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total_transaction_amount"
FROM "risk"."mga_merchseg_usg_sprd_str1_stp1" AS "_twmVC0"
);

/*
SELECT
*
FROM
risk.mga_merchseg_usg_sprd_str1_stp2
WHERE
card_no = '5530900000845973'
*/

--/********************  merchseg_usg_sprd_str1_stp3 ********************/

-- geri odemeler cc trx datasinde - gozuktugu icin where kosulunda onlari eliyor
-- aslinda bunu en basta yapmasi gerekirdi ama unuttuklari icin burda yapiyorlar (unutma)

DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp3";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."clusterid" AS "clusterid"
	,"_twmVC0"."transaction_count" / CAST("_twmVC0"."total_transaction_count" AS FLOAT) AS "freq_of_use_share"
	,"_twmVC0"."transaction_amount" / CAST("_twmVC0"."total_transaction_amount" AS FLOAT) AS "amount_share"
FROM "risk"."mga_merchseg_usg_sprd_str1_stp2" AS "_twmVC0"
WHERE ("_twmVC0"."total_transaction_amount" > 0) AND ("_twmVC0"."total_transaction_count" > 0)
);

/*
SELECT
*
FROM
risk.mga_merchseg_usg_sprd_str1_stp3
WHERE
card_no = '5530900000845973'
*/

----/********************  merchseg_usg_sprd_str1_stp4 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp4";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp4"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "C0_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "C1_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "C2_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "C3_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "C4_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "C5_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "C6_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "C7_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 8 THEN 1 ELSE 0 END AS "C8_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 9 THEN 1 ELSE 0 END AS "C9_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 10 THEN 1 ELSE 0 END AS "C10_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "C99_transaction_share"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "C0_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "C1_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "C2_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "C3_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "C4_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "C5_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "C6_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "C7_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 8 THEN 1 ELSE 0 END AS "C8_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 9 THEN 1 ELSE 0 END AS "C9_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 10 THEN 1 ELSE 0 END AS "C10_amount_share"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "C99_amount_share"
	,"_twmVC0"."freq_of_use_share" AS "freq_of_use_share"
	,"_twmVC0"."amount_share" AS "amount_share"
FROM "risk"."mga_merchseg_usg_sprd_str1_stp3" AS "_twmVC0"
);

----/********************  merchseg_usg_sprd_str1_stp5 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp5";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp5"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C0_transaction_share") AS "_C0_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C1_transaction_share") AS "_C1_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C2_transaction_share") AS "_C2_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C3_transaction_share") AS "_C3_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C4_transaction_share") AS "_C4_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C5_transaction_share") AS "_C5_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C6_transaction_share") AS "_C6_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C7_transaction_share") AS "_C7_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C8_transaction_share") AS "_C8_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C9_transaction_share") AS "_C9_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C10_transaction_share") AS "_C10_transaction_share"
	,SUM("_twmVC0"."freq_of_use_share" * "_twmVC0"."C99_transaction_share") AS "_C99_transaction_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C0_amount_share") AS "_C0_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C1_amount_share") AS "_C1_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C2_amount_share") AS "_C2_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C3_amount_share") AS "_C3_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C4_amount_share") AS "_C4_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C5_amount_share") AS "_C5_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C6_amount_share") AS "_C6_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C7_amount_share") AS "_C7_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C8_amount_share") AS "_C8_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C9_amount_share") AS "_C9_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C10_amount_share") AS "_C10_amount_share"
	,SUM("_twmVC0"."amount_share" * "_twmVC0"."C99_amount_share") AS "_C99_amount_share"
FROM "risk"."mga_merchseg_usg_sprd_str1_stp4" AS "_twmVC0"
GROUP BY 1
);

----/********************  merchseg_usg_sprd_str1_stp6 ********************/

-- burada bazi musteri/ccno lar icin segment degiskenleri null gelio cunku bu cardid ler cust_dt_dummy tablosundan gelio ama merchant tan gelmio. kontrol edilmesi boyle olmamasi lazim
-- cust dummy burada aslinda mga_customer_base
DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp6";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp6"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_id" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."_C0_transaction_share" AS "_C0_transaction_share"
	,"_twmVC1"."_C1_transaction_share" AS "_C1_transaction_share"
	,"_twmVC1"."_C2_transaction_share" AS "_C2_transaction_share"
	,"_twmVC1"."_C3_transaction_share" AS "_C3_transaction_share"
	,"_twmVC1"."_C4_transaction_share" AS "_C4_transaction_share"
	,"_twmVC1"."_C5_transaction_share" AS "_C5_transaction_share"
	,"_twmVC1"."_C6_transaction_share" AS "_C6_transaction_share"
	,"_twmVC1"."_C7_transaction_share" AS "_C7_transaction_share"
	,"_twmVC1"."_C8_transaction_share" AS "_C8_transaction_share"
	,"_twmVC1"."_C9_transaction_share" AS "_C9_transaction_share"
	,"_twmVC1"."_C10_transaction_share" AS "_C10_transaction_share"
	,"_twmVC1"."_C99_transaction_share" AS "_C99_transaction_share"
	,"_twmVC1"."_C0_amount_share" AS "_C0_amount_share"
	,"_twmVC1"."_C1_amount_share" AS "_C1_amount_share"
	,"_twmVC1"."_C2_amount_share" AS "_C2_amount_share"
	,"_twmVC1"."_C3_amount_share" AS "_C3_amount_share"
	,"_twmVC1"."_C4_amount_share" AS "_C4_amount_share"
	,"_twmVC1"."_C5_amount_share" AS "_C5_amount_share"
	,"_twmVC1"."_C6_amount_share" AS "_C6_amount_share"
	,"_twmVC1"."_C7_amount_share" AS "_C7_amount_share"
	,"_twmVC1"."_C8_amount_share" AS "_C8_amount_share"
	,"_twmVC1"."_C9_amount_share" AS "_C9_amount_share"
	,"_twmVC1"."_C10_amount_share" AS "_C10_amount_share"
	,"_twmVC1"."_C99_amount_share" AS "_C99_amount_share"
FROM "risk"."mga_customer_base" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."mga_merchseg_usg_sprd_str1_stp5" AS "_twmVC1"
		ON "_twmVC0"."card_id" = "_twmVC1"."card_no"
--WHERE
--(Extract(YEAR FROM "_twmVC0"."stmt_dt")*100) + Extract(MONTH FROM "_twmVC0"."stmt_dt") = 201709
);

----/********************  merchseg_usg_sprd_str1_stp7 ********************/

DROP TABLE IF EXISTS "risk"."mga_merchseg_usg_sprd_str1_stp7";
CREATE FACT TABLE "risk"."mga_merchseg_usg_sprd_str1_stp7"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."_C0_transaction_share", 0) AS "_C0_transaction_share"
	,COALESCE("_twmVC0"."_C1_transaction_share", 0) AS "_C1_transaction_share"
	,COALESCE("_twmVC0"."_C2_transaction_share", 0) AS "_C2_transaction_share"
	,COALESCE("_twmVC0"."_C3_transaction_share", 0) AS "_C3_transaction_share"
	,COALESCE("_twmVC0"."_C4_transaction_share", 0) AS "_C4_transaction_share"
	,COALESCE("_twmVC0"."_C5_transaction_share", 0) AS "_C5_transaction_share"
	,COALESCE("_twmVC0"."_C6_transaction_share", 0) AS "_C6_transaction_share"
	,COALESCE("_twmVC0"."_C7_transaction_share", 0) AS "_C7_transaction_share"
	,COALESCE("_twmVC0"."_C8_transaction_share", 0) AS "_C8_transaction_share"
	,COALESCE("_twmVC0"."_C9_transaction_share", 0) AS "_C9_transaction_share"
	,COALESCE("_twmVC0"."_C10_transaction_share", 0) AS "_C10_transaction_share"
	,COALESCE("_twmVC0"."_C99_transaction_share", 0) AS "_C99_transaction_share"
	,COALESCE("_twmVC0"."_C0_amount_share", 0) AS "_C0_amount_share"
	,COALESCE("_twmVC0"."_C1_amount_share", 0) AS "_C1_amount_share"
	,COALESCE("_twmVC0"."_C2_amount_share", 0) AS "_C2_amount_share"
	,COALESCE("_twmVC0"."_C3_amount_share", 0) AS "_C3_amount_share"
	,COALESCE("_twmVC0"."_C4_amount_share", 0) AS "_C4_amount_share"
	,COALESCE("_twmVC0"."_C5_amount_share", 0) AS "_C5_amount_share"
	,COALESCE("_twmVC0"."_C6_amount_share", 0) AS "_C6_amount_share"
	,COALESCE("_twmVC0"."_C7_amount_share", 0) AS "_C7_amount_share"
	,COALESCE("_twmVC0"."_C8_amount_share", 0) AS "_C8_amount_share"
	,COALESCE("_twmVC0"."_C9_amount_share", 0) AS "_C9_amount_share"
	,COALESCE("_twmVC0"."_C10_amount_share", 0) AS "_C10_amount_share"
	,COALESCE("_twmVC0"."_C99_amount_share", 0) AS "_C99_amount_share"
FROM "risk"."mga_merchseg_usg_sprd_str1_stp6" AS "_twmVC0"
);

----/********************  ************************* ********************/
----/********************  sax_on_merchseg_str1_stp1 ********************/
----/********************  ************************* ********************/

-- clusterid bazinda sum yapiyor
-- normalde merhant seg tablosunda statemeent olmasi lazim yani her bir trx in hangi statement periyodunda yapildigi
-- yani asagidaki stmt_year_month alanini olustururken aslinda trx_date yerine statement date'ten gidilmesi lazim

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp1"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_id" AS "card_no"
	,(EXTRACT('YEAR' FROM "_twmVC0"."trx_date") * 100) + EXTRACT('MONTH' FROM "_twmVC0"."trx_date") AS "stmt_year_month"
	,COALESCE("_twmVC1"."clusterid", 99) AS "clusterid"
	,SUM("_twmVC0"."trx_amt_tl") AS "amount"
	,SUM("_twmVC0"."trx_cnt") AS "freq_of_use"
	,"_twmVC2"."target" AS "target"
FROM "risk"."merchant_segment_table" AS "_twmVC0"
	INNER JOIN "risk"."mga_customer_base" AS "_twmVC2"
		ON "_twmVC0"."card_id" = "_twmVC2"."card_id"
	LEFT OUTER JOIN "risk"."mga_merchant_segmentation_score" AS "_twmVC1"
		ON "_twmVC0"."merchant_id" = "_twmVC1"."merchant_id"
WHERE
--(Extract(YEAR FROM "_twmVC2"."stmt_dt")*100) + Extract(MONTH FROM "_twmVC2"."stmt_dt") = 201709
--AND
trx_date between to_date('2017-08-31', 'YYYY-MM-DD') - INTEGER '365' AND to_date('2017-08-31', 'YYYY-MM-DD')
GROUP BY 1, 2, 3, 6
);

----/********************  sax_on_merchseg_str1_stp2 ********************/

-- transpose ediyor
-- eger bir cc farkli farkli clusterlarda bulunuyorda her bir clustr icin ayri satir olusuo orn:
-- cccno c1	c2
--151 	1	0
--151 	0	1
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp2"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."amount" AS "amount"
	,"_twmVC0"."freq_of_use" AS "freq_of_use"
	,"_twmVC0"."target" AS "target"
	,CASE WHEN "_twmVC0"."clusterid" = 0 THEN 1 ELSE 0 END AS "clusterid_0"
	,CASE WHEN "_twmVC0"."clusterid" = 1 THEN 1 ELSE 0 END AS "clusterid_1"
	,CASE WHEN "_twmVC0"."clusterid" = 2 THEN 1 ELSE 0 END AS "clusterid_2"
	,CASE WHEN "_twmVC0"."clusterid" = 3 THEN 1 ELSE 0 END AS "clusterid_3"
	,CASE WHEN "_twmVC0"."clusterid" = 4 THEN 1 ELSE 0 END AS "clusterid_4"
	,CASE WHEN "_twmVC0"."clusterid" = 5 THEN 1 ELSE 0 END AS "clusterid_5"
	,CASE WHEN "_twmVC0"."clusterid" = 6 THEN 1 ELSE 0 END AS "clusterid_6"
	,CASE WHEN "_twmVC0"."clusterid" = 7 THEN 1 ELSE 0 END AS "clusterid_7"
	,CASE WHEN "_twmVC0"."clusterid" = 8 THEN 1 ELSE 0 END AS "clusterid_8"
	,CASE WHEN "_twmVC0"."clusterid" = 9 THEN 1 ELSE 0 END AS "clusterid_9"
	,CASE WHEN "_twmVC0"."clusterid" = 10 THEN 1 ELSE 0 END AS "clusterid_10"
	,CASE WHEN "_twmVC0"."clusterid" = 99 THEN 1 ELSE 0 END AS "clusterid_99"
FROM "risk"."mga_sax_on_merchseg_str1_stp1" AS "_twmVC0"
);

----/********************  sax_on_merchseg_str1_stp3 ********************/

-- amnt ve trx ile carpinca eger o cc o cluster a girmiosa 0 giriyosa ayni (yani trx ya da amnt) sonucunu elde ediyor
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp3"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,MAX("_twmVC0"."clusterid_0" * "_twmVC0"."amount") AS "clusterid_0_amount"
	,MAX("_twmVC0"."clusterid_1" * "_twmVC0"."amount") AS "clusterid_1_amount"
	,MAX("_twmVC0"."clusterid_2" * "_twmVC0"."amount") AS "clusterid_2_amount"
	,MAX("_twmVC0"."clusterid_3" * "_twmVC0"."amount") AS "clusterid_3_amount"
	,MAX("_twmVC0"."clusterid_4" * "_twmVC0"."amount") AS "clusterid_4_amount"
	,MAX("_twmVC0"."clusterid_5" * "_twmVC0"."amount") AS "clusterid_5_amount"
	,MAX("_twmVC0"."clusterid_6" * "_twmVC0"."amount") AS "clusterid_6_amount"
	,MAX("_twmVC0"."clusterid_7" * "_twmVC0"."amount") AS "clusterid_7_amount"
	,MAX("_twmVC0"."clusterid_8" * "_twmVC0"."amount") AS "clusterid_8_amount"
	,MAX("_twmVC0"."clusterid_9" * "_twmVC0"."amount") AS "clusterid_9_amount"
	,MAX("_twmVC0"."clusterid_10" * "_twmVC0"."amount") AS "clusterid_10_amount"
	,MAX("_twmVC0"."clusterid_99" * "_twmVC0"."amount") AS "clusterid_99_amount"
	,MAX("_twmVC0"."clusterid_0" * "_twmVC0"."freq_of_use") AS "clusterid_0_freq"
	,MAX("_twmVC0"."clusterid_1" * "_twmVC0"."freq_of_use") AS "clusterid_1_freq"
	,MAX("_twmVC0"."clusterid_2" * "_twmVC0"."freq_of_use") AS "clusterid_2_freq"
	,MAX("_twmVC0"."clusterid_3" * "_twmVC0"."freq_of_use") AS "clusterid_3_freq"
	,MAX("_twmVC0"."clusterid_4" * "_twmVC0"."freq_of_use") AS "clusterid_4_freq"
	,MAX("_twmVC0"."clusterid_5" * "_twmVC0"."freq_of_use") AS "clusterid_5_freq"
	,MAX("_twmVC0"."clusterid_6" * "_twmVC0"."freq_of_use") AS "clusterid_6_freq"
	,MAX("_twmVC0"."clusterid_7" * "_twmVC0"."freq_of_use") AS "clusterid_7_freq"
	,MAX("_twmVC0"."clusterid_8" * "_twmVC0"."freq_of_use") AS "clusterid_8_freq"
	,MAX("_twmVC0"."clusterid_9" * "_twmVC0"."freq_of_use") AS "clusterid_9_freq"
	,MAX("_twmVC0"."clusterid_10" * "_twmVC0"."freq_of_use") AS "clusterid_10_freq"
	,MAX("_twmVC0"."clusterid_99" * "_twmVC0"."freq_of_use") AS "clusterid_99_freq"
FROM "risk"."mga_sax_on_merchseg_str1_stp2" AS "_twmVC0"
GROUP BY 1, 2, 3
);


----/********************  sax_on_merchseg_str1_stp4 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp4"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."clusterid_0_amount", 0) AS "clusterid_0_amount"
	,COALESCE("_twmVC0"."clusterid_1_amount", 0) AS "clusterid_1_amount"
	,COALESCE("_twmVC0"."clusterid_2_amount", 0) AS "clusterid_2_amount"
	,COALESCE("_twmVC0"."clusterid_3_amount", 0) AS "clusterid_3_amount"
	,COALESCE("_twmVC0"."clusterid_4_amount", 0) AS "clusterid_4_amount"
	,COALESCE("_twmVC0"."clusterid_5_amount", 0) AS "clusterid_5_amount"
	,COALESCE("_twmVC0"."clusterid_6_amount", 0) AS "clusterid_6_amount"
	,COALESCE("_twmVC0"."clusterid_7_amount", 0) AS "clusterid_7_amount"
	,COALESCE("_twmVC0"."clusterid_8_amount", 0) AS "clusterid_8_amount"
	,COALESCE("_twmVC0"."clusterid_9_amount", 0) AS "clusterid_9_amount"
	,COALESCE("_twmVC0"."clusterid_10_amount", 0) AS "clusterid_10_amount"
	,COALESCE("_twmVC0"."clusterid_99_amount", 0) AS "clusterid_99_amount"
	,COALESCE("_twmVC0"."clusterid_0_freq", 0) AS "clusterid_0_freq"
	,COALESCE("_twmVC0"."clusterid_1_freq", 0) AS "clusterid_1_freq"
	,COALESCE("_twmVC0"."clusterid_2_freq", 0) AS "clusterid_2_freq"
	,COALESCE("_twmVC0"."clusterid_3_freq", 0) AS "clusterid_3_freq"
	,COALESCE("_twmVC0"."clusterid_4_freq", 0) AS "clusterid_4_freq"
	,COALESCE("_twmVC0"."clusterid_5_freq", 0) AS "clusterid_5_freq"
	,COALESCE("_twmVC0"."clusterid_6_freq", 0) AS "clusterid_6_freq"
	,COALESCE("_twmVC0"."clusterid_7_freq", 0) AS "clusterid_7_freq"
	,COALESCE("_twmVC0"."clusterid_8_freq", 0) AS "clusterid_8_freq"
	,COALESCE("_twmVC0"."clusterid_9_freq", 0) AS "clusterid_9_freq"
	,COALESCE("_twmVC0"."clusterid_10_freq", 0) AS "clusterid_10_freq"
	,COALESCE("_twmVC0"."clusterid_99_freq", 0) AS "clusterid_99_freq"
FROM "risk"."mga_sax_on_merchseg_str1_stp3" AS "_twmVC0"
);


----/********************  sax_on_merchseg_str1_stp5 ********************/

-- normalisation
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp5"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,"_twmVC0"."target" AS "target"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_0_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_0_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_1_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_1_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_2_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_2_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_3_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_3_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_4_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_4_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_5_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_5_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_6_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_6_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_7_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_7_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_8_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_8_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_9_amount"  / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_9_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_10_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_10_amount_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") = 0 THEN 0 ELSE "_twmVC0"."clusterid_99_amount" / ("_twmVC0"."clusterid_0_amount" + "_twmVC0"."clusterid_1_amount" + "_twmVC0"."clusterid_2_amount" + "_twmVC0"."clusterid_3_amount" + "_twmVC0"."clusterid_4_amount" + "_twmVC0"."clusterid_5_amount" + "_twmVC0"."clusterid_6_amount" + "_twmVC0"."clusterid_7_amount" + "_twmVC0"."clusterid_8_amount" + "_twmVC0"."clusterid_9_amount" + "_twmVC0"."clusterid_10_amount" + "_twmVC0"."clusterid_99_amount") END AS "clusterid_99_amount_n"
	
	
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_0_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_0_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_1_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_1_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_2_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_2_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_3_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_3_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_4_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_4_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_5_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_5_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_6_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_6_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_7_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_7_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_8_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_8_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_9_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_9_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_10_freq"  / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_10_freq_n"
	,CASE WHEN ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") = 0 THEN 0 ELSE "_twmVC0"."clusterid_99_freq" / ("_twmVC0"."clusterid_0_freq" + "_twmVC0"."clusterid_1_freq" + "_twmVC0"."clusterid_2_freq" + "_twmVC0"."clusterid_3_freq" + "_twmVC0"."clusterid_4_freq" + "_twmVC0"."clusterid_5_freq" + "_twmVC0"."clusterid_6_freq" + "_twmVC0"."clusterid_7_freq" + "_twmVC0"."clusterid_8_freq" + "_twmVC0"."clusterid_9_freq" + "_twmVC0"."clusterid_10_freq" + "_twmVC0"."clusterid_99_freq") END AS "clusterid_99_freq_n"
FROM "risk"."mga_sax_on_merchseg_str1_stp4" AS "_twmVC0"
);

----/********************  sax_on_merchseg_str1_stp6 ********************/

-- ilk once distinct cardno'yu cekiyoruz sonra yearmonth u ayni sekilde cekcez. 
-- sax algoritmasi arada trx olmayan aylar icin 0 yazmamiz lazim

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp6"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 BTRIM("_twmVC0"."card_id") AS "card_no"
FROM "risk"."mga_customer_base" AS "_twmVC0"
--WHERE
--(Extract(YEAR FROM "_twmVC0"."stmt_dt")*100) + Extract(MONTH FROM "_twmVC0"."stmt_dt") = 201709
GROUP BY 1
);


----/********************  sax_on_merchseg_str1_stp7 ********************/

-- stat dt i cekiyoruz ayni sekilde 
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp7"() DISTRIBUTE BY HASH("stmt_year_month") COMPRESS LOW AS (
SELECT 
	 CAST("_twmVC0"."stmt_year_month" AS INTEGER) AS "stmt_year_month"
FROM "risk"."mga_sax_on_merchseg_str1_stp5" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp8 ********************/

-- kartezyen join ile birlestiriyoruz 
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp8"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 CAST("_twmVC0"."card_no" AS VARCHAR(50)) AS "card_no"
	,"_twmVC1"."stmt_year_month" AS "stmt_year_month"
FROM "risk"."mga_sax_on_merchseg_str1_stp6" AS "_twmVC0"
	, "risk"."mga_sax_on_merchseg_str1_stp7" AS "_twmVC1"
GROUP BY 1, 2
);

----/********************  sax_on_merchseg_str1_stp9 ********************/


-- burada 0 ile dolduruyoruz. ayni sekilde hic trx olmayan kartlar da 0 yazarak eklemis oluyoruz
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp9"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT
mga_sax_on_merchseg_str1_stp8.card_no
,mga_sax_on_merchseg_str1_stp8.stmt_year_month
,mga_sax_on_merchseg_str1_stp5.target
,coalesce(clusterid_0_amount_n,0) AS clusterid_0_amount_n 
,coalesce(clusterid_1_amount_n,0) AS clusterid_1_amount_n 
,coalesce(clusterid_2_amount_n,0) AS clusterid_2_amount_n 
,coalesce(clusterid_3_amount_n,0) AS clusterid_3_amount_n 
,coalesce(clusterid_4_amount_n,0) AS clusterid_4_amount_n 
,coalesce(clusterid_5_amount_n,0) AS clusterid_5_amount_n 
,coalesce(clusterid_6_amount_n,0) AS clusterid_6_amount_n 
,coalesce(clusterid_7_amount_n,0) AS clusterid_7_amount_n 
,coalesce(clusterid_8_amount_n,0) AS clusterid_8_amount_n 
,coalesce(clusterid_9_amount_n,0) AS clusterid_9_amount_n 
,coalesce(clusterid_10_amount_n,0) AS clusterid_10_amount_n
,coalesce(clusterid_99_amount_n,0) AS clusterid_99_amount_n
,coalesce(clusterid_0_freq_n,0) AS clusterid_0_freq_n   
,coalesce(clusterid_1_freq_n,0) AS clusterid_1_freq_n   
,coalesce(clusterid_2_freq_n,0) AS clusterid_2_freq_n   
,coalesce(clusterid_3_freq_n,0) AS clusterid_3_freq_n   
,coalesce(clusterid_4_freq_n,0) AS clusterid_4_freq_n   
,coalesce(clusterid_5_freq_n,0) AS clusterid_5_freq_n   
,coalesce(clusterid_6_freq_n,0) AS clusterid_6_freq_n   
,coalesce(clusterid_7_freq_n,0) AS clusterid_7_freq_n   
,coalesce(clusterid_8_freq_n,0) AS clusterid_8_freq_n   
,coalesce(clusterid_9_freq_n,0) AS clusterid_9_freq_n   
,coalesce(clusterid_10_freq_n,0) AS clusterid_10_freq_n  
,coalesce(clusterid_99_freq_n,0) AS clusterid_99_freq_n  
FROM
"risk"."mga_sax_on_merchseg_str1_stp8"
LEFT OUTER JOIN
"risk"."mga_sax_on_merchseg_str1_stp5"
ON
mga_sax_on_merchseg_str1_stp8.card_no = mga_sax_on_merchseg_str1_stp5.card_no
AND
mga_sax_on_merchseg_str1_stp8.stmt_year_month = mga_sax_on_merchseg_str1_stp5.stmt_year_month
);

----/********************  sax_on_merchseg_str1_stp10 ********************/

-- targeti eklemek icin

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp10"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."stmt_year_month" AS "stmt_year_month"
	,COALESCE("_twmVC0"."target", "_twmVC1"."target") AS "target"
	,COALESCE("_twmVC0"."clusterid_0_amount_n", 0) AS "clusterid_0_amount_n"
	,COALESCE("_twmVC0"."clusterid_0_freq_n", 0) AS "clusterid_0_freq_n"
	,COALESCE("_twmVC0"."clusterid_1_amount_n", 0) AS "clusterid_1_amount_n"
	,COALESCE("_twmVC0"."clusterid_1_freq_n", 0) AS "clusterid_1_freq_n"
	,COALESCE("_twmVC0"."clusterid_2_amount_n", 0) AS "clusterid_2_amount_n"
	,COALESCE("_twmVC0"."clusterid_2_freq_n", 0) AS "clusterid_2_freq_n"
	,COALESCE("_twmVC0"."clusterid_3_amount_n", 0) AS "clusterid_3_amount_n"
	,COALESCE("_twmVC0"."clusterid_3_freq_n", 0) AS "clusterid_3_freq_n"
	,COALESCE("_twmVC0"."clusterid_4_amount_n", 0) AS "clusterid_4_amount_n"
	,COALESCE("_twmVC0"."clusterid_4_freq_n", 0) AS "clusterid_4_freq_n"
	,COALESCE("_twmVC0"."clusterid_5_amount_n", 0) AS "clusterid_5_amount_n"
	,COALESCE("_twmVC0"."clusterid_5_freq_n", 0) AS "clusterid_5_freq_n"
	,COALESCE("_twmVC0"."clusterid_6_amount_n", 0) AS "clusterid_6_amount_n"
	,COALESCE("_twmVC0"."clusterid_6_freq_n", 0) AS "clusterid_6_freq_n"
	,COALESCE("_twmVC0"."clusterid_7_amount_n", 0) AS "clusterid_7_amount_n"
	,COALESCE("_twmVC0"."clusterid_7_freq_n", 0) AS "clusterid_7_freq_n"
	,COALESCE("_twmVC0"."clusterid_8_amount_n", 0) AS "clusterid_8_amount_n"
	,COALESCE("_twmVC0"."clusterid_8_freq_n", 0) AS "clusterid_8_freq_n"
	,COALESCE("_twmVC0"."clusterid_9_amount_n", 0) AS "clusterid_9_amount_n"
	,COALESCE("_twmVC0"."clusterid_9_freq_n", 0) AS "clusterid_9_freq_n"
	,COALESCE("_twmVC0"."clusterid_10_amount_n", 0) AS "clusterid_10_amount_n"
	,COALESCE("_twmVC0"."clusterid_10_freq_n", 0) AS "clusterid_10_freq_n"
	,COALESCE("_twmVC0"."clusterid_99_amount_n", 0) AS "clusterid_99_amount_n"
	,COALESCE("_twmVC0"."clusterid_99_freq_n", 0) AS "clusterid_99_freq_n"
FROM 
"risk"."mga_sax_on_merchseg_str1_stp9" AS "_twmVC0"
LEFT OUTER JOIN
"risk"."mga_customer_base" AS "_twmVC1"
ON
--(Extract(YEAR FROM "_twmVC1"."stmt_dt")*100) + Extract(MONTH FROM "_twmVC1"."stmt_dt") = 201709
--AND
"_twmVC0".card_no = "_twmVC1".card_id
);


----/********************  SAX = 4 Letters and 3 Alphabhets - Merchant Segmentation ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_merch_freq_amount_n";
CREATE FACT TABLE "risk"."mga_sax_merch_freq_amount_n"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
	SELECT * from SAX ( 
		ON (SELECT card_no, stmt_year_month, clusterid_0_freq_n, clusterid_0_amount_n , clusterid_1_freq_n, clusterid_1_amount_n , clusterid_2_freq_n, clusterid_2_amount_n , clusterid_3_freq_n, clusterid_3_amount_n , clusterid_4_freq_n, clusterid_4_amount_n , clusterid_5_freq_n, clusterid_5_amount_n , clusterid_6_freq_n, clusterid_6_amount_n , clusterid_7_freq_n, clusterid_7_amount_n , clusterid_8_freq_n, clusterid_8_amount_n , clusterid_9_freq_n, clusterid_9_amount_n , clusterid_10_freq_n, clusterid_10_amount_n , clusterid_99_freq_n, clusterid_99_amount_n
			FROM  risk.mga_sax_on_merchseg_str1_stp10 ) 
	PARTITION BY card_no
	ORDER BY stmt_year_month 
	Value_Column_Names ('clusterid_0_freq_n', 'clusterid_0_amount_n ', 'clusterid_1_freq_n', 'clusterid_1_amount_n ', 'clusterid_2_freq_n', 'clusterid_2_amount_n ', 'clusterid_3_freq_n', 'clusterid_3_amount_n ', 'clusterid_4_freq_n', 'clusterid_4_amount_n ', 'clusterid_5_freq_n', 'clusterid_5_amount_n ', 'clusterid_6_freq_n', 'clusterid_6_amount_n ', 'clusterid_7_freq_n', 'clusterid_7_amount_n ', 'clusterid_8_freq_n', 'clusterid_8_amount_n ', 'clusterid_9_freq_n', 'clusterid_9_amount_n ', 'clusterid_10_freq_n', 'clusterid_10_amount_n ', 'clusterid_99_freq_n', 'clusterid_99_amount_n') 
	PAA_Size ('4') -- Time Duration
	Alphabet_Size ('3') -- Number of possible Characters 
	Accumulate ('card_no') 
	)
);


----/********************  sax_on_merchseg_str1_stp11 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp11";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp11"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC0"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,"_twmVC0"."sax_code_clusterid_1_freq_n" AS "sax_code_clusterid_1_freq_n"
	,"_twmVC0"."sax_code_clusterid_1_amount_n" AS "sax_code_clusterid_1_amount_n"
	,"_twmVC0"."sax_code_clusterid_2_freq_n" AS "sax_code_clusterid_2_freq_n"
	,"_twmVC0"."sax_code_clusterid_2_amount_n" AS "sax_code_clusterid_2_amount_n"
	,"_twmVC0"."sax_code_clusterid_3_freq_n" AS "sax_code_clusterid_3_freq_n"
	,"_twmVC0"."sax_code_clusterid_3_amount_n" AS "sax_code_clusterid_3_amount_n"
	,"_twmVC0"."sax_code_clusterid_4_freq_n" AS "sax_code_clusterid_4_freq_n"
	,"_twmVC0"."sax_code_clusterid_4_amount_n" AS "sax_code_clusterid_4_amount_n"
	,"_twmVC0"."sax_code_clusterid_5_freq_n" AS "sax_code_clusterid_5_freq_n"
	,"_twmVC0"."sax_code_clusterid_5_amount_n" AS "sax_code_clusterid_5_amount_n"
	,"_twmVC0"."sax_code_clusterid_6_freq_n" AS "sax_code_clusterid_6_freq_n"
	,"_twmVC0"."sax_code_clusterid_6_amount_n" AS "sax_code_clusterid_6_amount_n"
	,"_twmVC0"."sax_code_clusterid_7_freq_n" AS "sax_code_clusterid_7_freq_n"
	,"_twmVC0"."sax_code_clusterid_7_amount_n" AS "sax_code_clusterid_7_amount_n"
	,"_twmVC0"."sax_code_clusterid_8_freq_n" AS "sax_code_clusterid_8_freq_n"
	,"_twmVC0"."sax_code_clusterid_8_amount_n" AS "sax_code_clusterid_8_amount_n"
	,"_twmVC0"."sax_code_clusterid_9_freq_n" AS "sax_code_clusterid_9_freq_n"
	,"_twmVC0"."sax_code_clusterid_9_amount_n" AS "sax_code_clusterid_9_amount_n"
	,"_twmVC0"."sax_code_clusterid_10_freq_n" AS "sax_code_clusterid_10_freq_n"
	,"_twmVC0"."sax_code_clusterid_10_amount_n" AS "sax_code_clusterid_10_amount_n"
	,"_twmVC0"."sax_code_clusterid_99_freq_n" AS "sax_code_clusterid_99_freq_n"
	,"_twmVC0"."sax_code_clusterid_99_amount_n" AS "sax_code_clusterid_99_amount_n"
	,"_twmVC1"."target" AS "target"
FROM "risk"."mga_sax_merch_freq_amount_n" AS "_twmVC0"
	RIGHT OUTER JOIN "risk"."mga_customer_base" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_id"
);

--/********************  sax_on_merchseg_str1_stp12 - train ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp12";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp12"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."card_no" AS "card_no"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC1"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,"_twmVC1"."sax_code_clusterid_1_freq_n" AS "sax_code_clusterid_1_freq_n"
	,"_twmVC1"."sax_code_clusterid_1_amount_n" AS "sax_code_clusterid_1_amount_n"
	,"_twmVC1"."sax_code_clusterid_2_freq_n" AS "sax_code_clusterid_2_freq_n"
	,"_twmVC1"."sax_code_clusterid_2_amount_n" AS "sax_code_clusterid_2_amount_n"
	,"_twmVC1"."sax_code_clusterid_3_freq_n" AS "sax_code_clusterid_3_freq_n"
	,"_twmVC1"."sax_code_clusterid_3_amount_n" AS "sax_code_clusterid_3_amount_n"
	,"_twmVC1"."sax_code_clusterid_4_freq_n" AS "sax_code_clusterid_4_freq_n"
	,"_twmVC1"."sax_code_clusterid_4_amount_n" AS "sax_code_clusterid_4_amount_n"
	,"_twmVC1"."sax_code_clusterid_5_freq_n" AS "sax_code_clusterid_5_freq_n"
	,"_twmVC1"."sax_code_clusterid_5_amount_n" AS "sax_code_clusterid_5_amount_n"
	,"_twmVC1"."sax_code_clusterid_6_freq_n" AS "sax_code_clusterid_6_freq_n"
	,"_twmVC1"."sax_code_clusterid_6_amount_n" AS "sax_code_clusterid_6_amount_n"
	,"_twmVC1"."sax_code_clusterid_7_freq_n" AS "sax_code_clusterid_7_freq_n"
	,"_twmVC1"."sax_code_clusterid_7_amount_n" AS "sax_code_clusterid_7_amount_n"
	,"_twmVC1"."sax_code_clusterid_8_freq_n" AS "sax_code_clusterid_8_freq_n"
	,"_twmVC1"."sax_code_clusterid_8_amount_n" AS "sax_code_clusterid_8_amount_n"
	,"_twmVC1"."sax_code_clusterid_9_freq_n" AS "sax_code_clusterid_9_freq_n"
	,"_twmVC1"."sax_code_clusterid_9_amount_n" AS "sax_code_clusterid_9_amount_n"
	,"_twmVC1"."sax_code_clusterid_10_freq_n" AS "sax_code_clusterid_10_freq_n"
	,"_twmVC1"."sax_code_clusterid_10_amount_n" AS "sax_code_clusterid_10_amount_n"
	,"_twmVC1"."sax_code_clusterid_99_freq_n" AS "sax_code_clusterid_99_freq_n"
	,"_twmVC1"."sax_code_clusterid_99_amount_n" AS "sax_code_clusterid_99_amount_n"
	,"_twmVC1"."target" AS "target"
FROM "risk"."mga_customer_base_train" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."mga_sax_on_merchseg_str1_stp11" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);

--/********************  sax_on_merchseg_str1_stp13 - test ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp13";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp13"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,"_twmVC1"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,"_twmVC1"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,"_twmVC1"."sax_code_clusterid_1_freq_n" AS "sax_code_clusterid_1_freq_n"
	,"_twmVC1"."sax_code_clusterid_1_amount_n" AS "sax_code_clusterid_1_amount_n"
	,"_twmVC1"."sax_code_clusterid_2_freq_n" AS "sax_code_clusterid_2_freq_n"
	,"_twmVC1"."sax_code_clusterid_2_amount_n" AS "sax_code_clusterid_2_amount_n"
	,"_twmVC1"."sax_code_clusterid_3_freq_n" AS "sax_code_clusterid_3_freq_n"
	,"_twmVC1"."sax_code_clusterid_3_amount_n" AS "sax_code_clusterid_3_amount_n"
	,"_twmVC1"."sax_code_clusterid_4_freq_n" AS "sax_code_clusterid_4_freq_n"
	,"_twmVC1"."sax_code_clusterid_4_amount_n" AS "sax_code_clusterid_4_amount_n"
	,"_twmVC1"."sax_code_clusterid_5_freq_n" AS "sax_code_clusterid_5_freq_n"
	,"_twmVC1"."sax_code_clusterid_5_amount_n" AS "sax_code_clusterid_5_amount_n"
	,"_twmVC1"."sax_code_clusterid_6_freq_n" AS "sax_code_clusterid_6_freq_n"
	,"_twmVC1"."sax_code_clusterid_6_amount_n" AS "sax_code_clusterid_6_amount_n"
	,"_twmVC1"."sax_code_clusterid_7_freq_n" AS "sax_code_clusterid_7_freq_n"
	,"_twmVC1"."sax_code_clusterid_7_amount_n" AS "sax_code_clusterid_7_amount_n"
	,"_twmVC1"."sax_code_clusterid_8_freq_n" AS "sax_code_clusterid_8_freq_n"
	,"_twmVC1"."sax_code_clusterid_8_amount_n" AS "sax_code_clusterid_8_amount_n"
	,"_twmVC1"."sax_code_clusterid_9_freq_n" AS "sax_code_clusterid_9_freq_n"
	,"_twmVC1"."sax_code_clusterid_9_amount_n" AS "sax_code_clusterid_9_amount_n"
	,"_twmVC1"."sax_code_clusterid_10_freq_n" AS "sax_code_clusterid_10_freq_n"
	,"_twmVC1"."sax_code_clusterid_10_amount_n" AS "sax_code_clusterid_10_amount_n"
	,"_twmVC1"."sax_code_clusterid_99_freq_n" AS "sax_code_clusterid_99_freq_n"
	,"_twmVC1"."sax_code_clusterid_99_amount_n" AS "sax_code_clusterid_99_amount_n"
FROM "risk"."mga_customer_base_test" AS "_twmVC0"
	LEFT OUTER JOIN "risk"."mga_sax_on_merchseg_str1_stp11" AS "_twmVC1"
		ON "_twmVC0"."card_no" = "_twmVC1"."card_no"
);

--/********************  sax_on_merchseg_str1_stp14 - s0 ********************/

-- her bir sax code cluster'in del ratiosunun yuksek olup olmadigini anlamak icin toplam kitleninkine bakmayi unutma
-- burada orn _ ratiosu 70 ustunde cikio ama top kitlenin de oyle oldugu icin 0 clusterindan alisveris yapmayanlarin yuksek del ratio demek anlamina gelmio, ortalamadalar
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s0"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);



--/********************  sax_on_merchseg_str1_stp15 - s0_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s0"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_0_freq_n" END AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s0" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp16 - s0_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s0"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_freq_n" AS "sax_code_clusterid_0_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s0" AS "_twmVC0"
);



--/********************  sax_on_merchseg_str1_stp14 - s1 ********************/

-- her bir sax code cluster'in del ratiosunun yuksek olup olmadigini anlamak icin toplam kitleninkine bakmayi unutma
-- burada orn _ ratiosu 70 ustunde cikio ama top kitlenin de oyle oldugu icin 0 clusterindan alisveris yapmayanlarin yuksek del ratio demek anlamina gelmio, ortalamadalar
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s1"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_1_freq_n" AS "sax_code_clusterid_1_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp15 - s1_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s1"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_1_freq_n" END AS "sax_code_clusterid_1_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s1" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp16 - s1_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s1"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_1_freq_n" AS "sax_code_clusterid_1_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s1" AS "_twmVC0"
);


--/********************  sax_on_merchseg_str1_stp14 - s2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s2"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_2_freq_n" AS "sax_code_clusterid_2_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp15 - s2_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s2"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_2_freq_n" END AS "sax_code_clusterid_2_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s2" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp16 - s2_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s2"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_2_freq_n" AS "sax_code_clusterid_2_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s2" AS "_twmVC0"
);

--/********************  ******************************* ********************/
--/********************  sax_on_merchseg_str1_stp14 - s3 ********************/
--/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s3"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_3_freq_n" AS "sax_code_clusterid_3_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp15 - s3_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s3"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_3_freq_n" END AS "sax_code_clusterid_3_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s3" AS "_twmVC0"
GROUP BY 1
);

--/********************  sax_on_merchseg_str1_stp16 - s3_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s3"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_3_freq_n" AS "sax_code_clusterid_3_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s3" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s4 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s4"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_4_freq_n" AS "sax_code_clusterid_4_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s4_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s4"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_4_freq_n" END AS "sax_code_clusterid_4_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s4" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s4_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s4"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_4_freq_n" AS "sax_code_clusterid_4_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s4" AS "_twmVC0"
);
----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s5 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s5"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_5_freq_n" AS "sax_code_clusterid_5_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s5_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s5"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_5_freq_n" END AS "sax_code_clusterid_5_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s5" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s5_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s5"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_5_freq_n" AS "sax_code_clusterid_5_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s5" AS "_twmVC0"
);
----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s6 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s6"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_6_freq_n" AS "sax_code_clusterid_6_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s6_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s6"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_6_freq_n" END AS "sax_code_clusterid_6_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s6" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s6_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s6"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_6_freq_n" AS "sax_code_clusterid_6_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s6" AS "_twmVC0"
);


----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s7 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s7"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_7_freq_n" AS "sax_code_clusterid_7_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s7_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s7"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_7_freq_n" END AS "sax_code_clusterid_7_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s7" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s7_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s7"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_7_freq_n" AS "sax_code_clusterid_7_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s7" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s8 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s8"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_8_freq_n" AS "sax_code_clusterid_8_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s8_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s8"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_8_freq_n" END AS "sax_code_clusterid_8_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s8" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s8_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s8"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_8_freq_n" AS "sax_code_clusterid_8_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s8" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s9 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s9"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_9_freq_n" AS "sax_code_clusterid_9_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s9_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s9"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_9_freq_n" END AS "sax_code_clusterid_9_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s9" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s9_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s9"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_9_freq_n" AS "sax_code_clusterid_9_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s9" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s10 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s10"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_10_freq_n" AS "sax_code_clusterid_10_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s10_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s10"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_10_freq_n" END AS "sax_code_clusterid_10_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s10" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s10_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s10"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_10_freq_n" AS "sax_code_clusterid_10_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s10" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s99 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_s99"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_99_freq_n" AS "sax_code_clusterid_99_freq_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s99_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_s99"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_99_freq_n" END AS "sax_code_clusterid_99_freq_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_s99" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s99_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_s99"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_99_freq_n" AS "sax_code_clusterid_99_freq_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_s99" AS "_twmVC0"
);


----/********************  sax_on_merchseg_str1_stp14 - s0 ********************/

-- her bir sax code cluster'in del ratiosunun yuksek olup olmadigini anlamak icin toplam kitleninkine bakmayi unutma
-- burada orn _ ratiosu 70 ustunde cikio ama top kitlenin de oyle oldugu icin 0 clusterindan alisveris yapmayanlarin yuksek del ratio demek anlamina gelmio, ortalamadalar
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s0"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);



----/********************  sax_on_merchseg_str1_stp15 - s0_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s0"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_0_amount_n" END AS "sax_code_clusterid_0_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s0" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s0_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s0";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s0"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_0_amount_n" AS "sax_code_clusterid_0_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s0" AS "_twmVC0"
);



----/********************  sax_on_merchseg_str1_stp14 - s1 ********************/

-- her bir sax code cluster'in del ratiosunun yuksek olup olmadigini anlamak icin toplam kitleninkine bakmayi unutma
-- burada orn _ ratiosu 70 ustunde cikio ama top kitlenin de oyle oldugu icin 0 clusterindan alisveris yapmayanlarin yuksek del ratio demek anlamina gelmio, ortalamadalar
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s1"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_1_amount_n" AS "sax_code_clusterid_1_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s1_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s1"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_1_amount_n" END AS "sax_code_clusterid_1_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s1" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s1_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s1";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s1"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_1_amount_n" AS "sax_code_clusterid_1_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s1" AS "_twmVC0"
);


----/********************  sax_on_merchseg_str1_stp14 - s2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s2"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_2_amount_n" AS "sax_code_clusterid_2_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s2_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s2"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_2_amount_n" END AS "sax_code_clusterid_2_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s2" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s2_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s2";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s2"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_2_amount_n" AS "sax_code_clusterid_2_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s2" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s3 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s3"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_3_amount_n" AS "sax_code_clusterid_3_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s3_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s3"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_3_amount_n" END AS "sax_code_clusterid_3_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s3" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s3_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s3";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s3"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_3_amount_n" AS "sax_code_clusterid_3_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s3" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s4 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s4"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_4_amount_n" AS "sax_code_clusterid_4_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s4_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s4"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_4_amount_n" END AS "sax_code_clusterid_4_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s4" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s4_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s4";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s4"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_4_amount_n" AS "sax_code_clusterid_4_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s4" AS "_twmVC0"
);
----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s5 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s5"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_5_amount_n" AS "sax_code_clusterid_5_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s5_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s5"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_5_amount_n" END AS "sax_code_clusterid_5_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s5" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s5_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s5";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s5"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_5_amount_n" AS "sax_code_clusterid_5_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s5" AS "_twmVC0"
);
----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s6 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s6"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_6_amount_n" AS "sax_code_clusterid_6_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s6_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s6"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_6_amount_n" END AS "sax_code_clusterid_6_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s6" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s6_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s6";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s6"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_6_amount_n" AS "sax_code_clusterid_6_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s6" AS "_twmVC0"
);


----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s7 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s7"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_7_amount_n" AS "sax_code_clusterid_7_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s7_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s7"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_7_amount_n" END AS "sax_code_clusterid_7_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s7" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s7_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s7";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s7"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_7_amount_n" AS "sax_code_clusterid_7_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s7" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s8 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s8"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_8_amount_n" AS "sax_code_clusterid_8_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s8_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s8"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_8_amount_n" END AS "sax_code_clusterid_8_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s8" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s8_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s8";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s8"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_8_amount_n" AS "sax_code_clusterid_8_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s8" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s9 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s9"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_9_amount_n" AS "sax_code_clusterid_9_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s9_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s9"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_9_amount_n" END AS "sax_code_clusterid_9_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s9" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s9_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s9";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s9"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_9_amount_n" AS "sax_code_clusterid_9_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s9" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s10 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s10"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_10_amount_n" AS "sax_code_clusterid_10_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s10_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s10"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_10_amount_n" END AS "sax_code_clusterid_10_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s10" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s10_3 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s10";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s10"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_10_amount_n" AS "sax_code_clusterid_10_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_s10" AS "_twmVC0"
);

----/********************  ******************************* ********************/
----/********************  sax_on_merchseg_str1_stp14 - s99 ********************/
----/********************  ******************************* ********************/


DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp14_amt_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp14_amt_s99"() DISTRIBUTE BY HASH("count_total") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_99_amount_n" AS "sax_code_clusterid_99_amount_n"
	,SUM("_twmVC0"."target") AS "count_target"
	,COUNT(*) AS "count_total"
	,SUM("_twmVC0"."target") / cast(COUNT(*) AS float) AS "delinquency_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp12" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp15 - s99_2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp15_amt_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp15_amt_s99"() DISTRIBUTE BY HASH("count_target") COMPRESS LOW AS (
SELECT 
	 CASE WHEN "_twmVC0"."count_total" < 50 THEN '____' ELSE "_twmVC0"."sax_code_clusterid_99_amount_n" END AS "sax_code_clusterid_99_amount_n"
	,SUM("_twmVC0"."count_target") AS "count_target"
	,SUM("_twmVC0"."count_total") AS "count_total"
	,SUM("_twmVC0"."count_target") / SUM("_twmVC0"."count_total") AS "delinquent_ratio"
FROM "risk"."mga_sax_on_merchseg_str1_stp14_amt_s99" AS "_twmVC0"
GROUP BY 1
);

----/********************  sax_on_merchseg_str1_stp16 - s99_3 ********************/
								--woe hesabı yapıyoruz buada		

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp16_amt_s99";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp16_amt_s99"() DISTRIBUTE BY HASH("target") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."sax_code_clusterid_99_amount_n" AS "sax_code_clusterid_99_amount_n"
	,SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "target"
	,SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "total"
	,"_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) AS "p"
	,("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) AS "not_p"
	,("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING))) AS "odds_ratio"
	,CASE WHEN (("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) <= 0 THEN -3 ELSE LN(("_twmVC0"."count_target" / SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)) / (("_twmVC0"."count_total" - "_twmVC0"."count_target") / (SUM("_twmVC0"."count_total") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING) - SUM("_twmVC0"."count_target") OVER (ROWS BETWEEN UNBOUNDED PRECEDING AND UNBOUNDED FOLLOWING)))) END AS "woe"
FROM "risk"."mga_sax_on_merchseg_str1_stp15_amt_amt_s99" AS "_twmVC0"
);



--/********************  sax_on_merchseg_str1_stp17 - train_t1 ********************/

-----------------========================================-----------------
-----------------====woe kombinasyonunu yapıyor================-----------------
-----------------=============================-----------------
-----------------========================================-----------------

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp17";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp17"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
 mga_sax_on_merchseg_str1_stp12.cust_id AS cust_id
,mga_sax_on_merchseg_str1_stp12.card_no AS card_no
,mga_sax_on_merchseg_str1_stp12.target AS target

,s0_Freq.woe AS sax_code_clusterid_0_freq_n_woe
,s0_Freq.sax_code_clusterid_0_freq_n AS sax_code_clusterid_0_freq_n
,s0_amt.woe AS sax_code_clusterid_0_amt_n_woe
,s0_amt.sax_code_clusterid_0_amount_n AS sax_code_clusterid_0_amt_n

,s1_Freq.woe AS sax_code_clusterid_1_freq_n_woe
,s1_Freq.sax_code_clusterid_1_freq_n AS sax_code_clusterid_1_freq_n
,s1_amt.woe AS sax_code_clusterid_1_amt_n_woe
,s1_amt.sax_code_clusterid_1_amount_n AS sax_code_clusterid_1_amt_n


,s2_Freq.woe AS sax_code_clusterid_2_freq_n_woe
,s2_Freq.sax_code_clusterid_2_freq_n AS sax_code_clusterid_2_freq_n
,s2_amt.woe AS sax_code_clusterid_2_amt_n_woe
,s2_amt.sax_code_clusterid_2_amount_n AS sax_code_clusterid_2_amt_n


,s3_Freq.woe AS sax_code_clusterid_3_freq_n_woe
,s3_Freq.sax_code_clusterid_3_freq_n AS sax_code_clusterid_3_freq_n
,s3_amt.woe AS sax_code_clusterid_3_amt_n_woe
,s3_amt.sax_code_clusterid_3_amount_n AS sax_code_clusterid_3_amt_n


,s4_Freq.woe AS sax_code_clusterid_4_freq_n_woe
,s4_Freq.sax_code_clusterid_4_freq_n AS sax_code_clusterid_4_freq_n
,s4_amt.woe AS sax_code_clusterid_4_amt_n_woe
,s4_amt.sax_code_clusterid_4_amount_n AS sax_code_clusterid_4_amt_n


,s5_Freq.woe AS sax_code_clusterid_5_freq_n_woe
,s5_Freq.sax_code_clusterid_5_freq_n AS sax_code_clusterid_5_freq_n
,s5_amt.woe AS sax_code_clusterid_5_amt_n_woe
,s5_amt.sax_code_clusterid_5_amount_n AS sax_code_clusterid_5_amt_n


,s6_Freq.woe AS sax_code_clusterid_6_freq_n_woe
,s6_Freq.sax_code_clusterid_6_freq_n AS sax_code_clusterid_6_freq_n
,s6_amt.woe AS sax_code_clusterid_6_amt_n_woe
,s6_amt.sax_code_clusterid_6_amount_n AS sax_code_clusterid_6_amt_n


,s7_Freq.woe AS sax_code_clusterid_7_freq_n_woe
,s7_Freq.sax_code_clusterid_7_freq_n AS sax_code_clusterid_7_freq_n
,s7_amt.woe AS sax_code_clusterid_7_amt_n_woe
,s7_amt.sax_code_clusterid_7_amount_n AS sax_code_clusterid_7_amt_n


,s8_Freq.woe AS sax_code_clusterid_8_freq_n_woe
,s8_Freq.sax_code_clusterid_8_freq_n AS sax_code_clusterid_8_freq_n
,s8_amt.woe AS sax_code_clusterid_8_amt_n_woe
,s8_amt.sax_code_clusterid_8_amount_n AS sax_code_clusterid_8_amt_n


,s9_Freq.woe AS sax_code_clusterid_9_freq_n_woe
,s9_Freq.sax_code_clusterid_9_freq_n AS sax_code_clusterid_9_freq_n
,s9_amt.woe AS sax_code_clusterid_9_amt_n_woe
,s9_amt.sax_code_clusterid_9_amount_n AS sax_code_clusterid_9_amt_n


,s10_Freq.woe AS sax_code_clusterid_10_freq_n_woe
,s10_Freq.sax_code_clusterid_10_freq_n AS sax_code_clusterid_10_freq_n
,s10_amt.woe AS sax_code_clusterid_10_amt_n_woe
,s10_amt.sax_code_clusterid_10_amount_n AS sax_code_clusterid_10_amt_n



,s99_Freq.woe AS sax_code_clusterid_99_freq_n_woe
,s99_Freq.sax_code_clusterid_99_freq_n AS sax_code_clusterid_99_freq_n
,s99_amt.woe AS sax_code_clusterid_99_amt_n_woe
,s99_amt.sax_code_clusterid_99_amount_n AS sax_code_clusterid_99_amt_n

FROM
risk.mga_sax_on_merchseg_str1_stp12 

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s0 AS s0_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_0_freq_n = s0_Freq.sax_code_clusterid_0_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s0 AS s0_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_0_amount_n = s0_amt.sax_code_clusterid_0_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s1 AS s1_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_1_freq_n = s1_Freq.sax_code_clusterid_1_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s1 AS s1_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_1_amount_n = s1_amt.sax_code_clusterid_1_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s2 AS s2_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_2_freq_n = s2_Freq.sax_code_clusterid_2_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s2 AS s2_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_2_amount_n = s2_amt.sax_code_clusterid_2_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s3 AS s3_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_3_freq_n = s3_Freq.sax_code_clusterid_3_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s3 AS s3_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_3_amount_n = s3_amt.sax_code_clusterid_3_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s4 AS s4_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_4_freq_n = s4_Freq.sax_code_clusterid_4_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s4 AS s4_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_4_amount_n = s4_amt.sax_code_clusterid_4_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s5 AS s5_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_5_freq_n = s5_Freq.sax_code_clusterid_5_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s5 AS s5_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_5_amount_n = s5_amt.sax_code_clusterid_5_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s6 AS s6_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_6_freq_n = s6_Freq.sax_code_clusterid_6_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s6 AS s6_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_6_amount_n = s6_amt.sax_code_clusterid_6_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s7 AS s7_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_7_freq_n = s7_Freq.sax_code_clusterid_7_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s7 AS s7_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_7_amount_n = s7_amt.sax_code_clusterid_7_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s8 AS s8_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_8_freq_n = s8_Freq.sax_code_clusterid_8_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s8 AS s8_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_8_amount_n = s8_amt.sax_code_clusterid_8_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s9 AS s9_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_9_freq_n = s9_Freq.sax_code_clusterid_9_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s9 AS s9_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_9_amount_n = s9_amt.sax_code_clusterid_9_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s10 AS s10_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_10_freq_n = s10_Freq.sax_code_clusterid_10_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s10 AS s10_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_10_amount_n = s10_amt.sax_code_clusterid_10_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s99 AS s99_Freq
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_99_freq_n = s99_Freq.sax_code_clusterid_99_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s99 AS s99_amt
ON 
mga_sax_on_merchseg_str1_stp12.sax_code_clusterid_99_amount_n = s99_amt.sax_code_clusterid_99_amount_n
);


--/********************  sax_on_merchseg_str1_stp18 - train_t2 ********************/

-- ilk once join yapip sonra __ ile doldurmasi gerektigini fark etti o yuzden den simdi dolduruo ___ ile.
-- sonra tekrar join yapcak. biz yapcamız zmn once dolduralim sonra 1 kere join yapalim
--
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp18";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp18"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_freq_n", '____') AS "sax_code_clusterid_0_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_1_freq_n", '____') AS "sax_code_clusterid_1_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_2_freq_n", '____') AS "sax_code_clusterid_2_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_3_freq_n", '____') AS "sax_code_clusterid_3_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_4_freq_n", '____') AS "sax_code_clusterid_4_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_5_freq_n", '____') AS "sax_code_clusterid_5_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_6_freq_n", '____') AS "sax_code_clusterid_6_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_7_freq_n", '____') AS "sax_code_clusterid_7_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_8_freq_n", '____') AS "sax_code_clusterid_8_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_9_freq_n", '____') AS "sax_code_clusterid_9_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_10_freq_n", '____') AS "sax_code_clusterid_10_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_99_freq_n", '____') AS "sax_code_clusterid_99_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_amt_n", '____') AS "sax_code_clusterid_0_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_1_amt_n", '____') AS "sax_code_clusterid_1_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_2_amt_n", '____') AS "sax_code_clusterid_2_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_3_amt_n", '____') AS "sax_code_clusterid_3_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_4_amt_n", '____') AS "sax_code_clusterid_4_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_5_amt_n", '____') AS "sax_code_clusterid_5_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_6_amt_n", '____') AS "sax_code_clusterid_6_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_7_amt_n", '____') AS "sax_code_clusterid_7_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_8_amt_n", '____') AS "sax_code_clusterid_8_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_9_amt_n", '____') AS "sax_code_clusterid_9_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_10_amt_n", '____') AS "sax_code_clusterid_10_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_99_amt_n", '____') AS "sax_code_clusterid_99_amt_n"
FROM "risk"."mga_sax_on_merchseg_str1_stp17" AS "_twmVC0"
);


--/********************  sax_on_merchseg_str1_stp19 - train (Final table) ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp19";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp19"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
 mga_sax_on_merchseg_str1_stp18.cust_id AS cust_id
,mga_sax_on_merchseg_str1_stp18.card_no AS card_no
,mga_sax_on_merchseg_str1_stp18.target AS target
,s0_Freq.woe AS sax_code_clusterid_0_freq_n_woe
,s0_amt.woe AS sax_code_clusterid_0_amt_n_woe
,s1_Freq.woe AS sax_code_clusterid_1_freq_n_woe
,s1_amt.woe AS sax_code_clusterid_1_amt_n_woe
,s2_Freq.woe AS sax_code_clusterid_2_freq_n_woe
,s2_amt.woe AS sax_code_clusterid_2_amt_n_woe
,s3_Freq.woe AS sax_code_clusterid_3_freq_n_woe
,s3_amt.woe AS sax_code_clusterid_3_amt_n_woe
,s4_Freq.woe AS sax_code_clusterid_4_freq_n_woe
,s4_amt.woe AS sax_code_clusterid_4_amt_n_woe
,s5_Freq.woe AS sax_code_clusterid_5_freq_n_woe
,s5_amt.woe AS sax_code_clusterid_5_amt_n_woe
,s6_Freq.woe AS sax_code_clusterid_6_freq_n_woe
,s6_amt.woe AS sax_code_clusterid_6_amt_n_woe
,s7_Freq.woe AS sax_code_clusterid_7_freq_n_woe
,s7_amt.woe AS sax_code_clusterid_7_amt_n_woe
,s8_Freq.woe AS sax_code_clusterid_8_freq_n_woe
,s8_amt.woe AS sax_code_clusterid_8_amt_n_woe
,s9_Freq.woe AS sax_code_clusterid_9_freq_n_woe
,s9_amt.woe AS sax_code_clusterid_9_amt_n_woe
,s10_Freq.woe AS sax_code_clusterid_10_freq_n_woe
,s10_amt.woe AS sax_code_clusterid_10_amt_n_woe
,s99_Freq.woe AS sax_code_clusterid_99_freq_n_woe
,s99_amt.woe AS sax_code_clusterid_99_amt_n_woe

FROM
risk.mga_sax_on_merchseg_str1_stp18 

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s0 AS s0_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_0_freq_n = s0_Freq.sax_code_clusterid_0_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s0 AS s0_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_0_amt_n = s0_amt.sax_code_clusterid_0_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s1 AS s1_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_1_freq_n = s1_Freq.sax_code_clusterid_1_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s1 AS s1_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_1_amt_n = s1_amt.sax_code_clusterid_1_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s2 AS s2_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_2_freq_n = s2_Freq.sax_code_clusterid_2_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s2 AS s2_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_2_amt_n = s2_amt.sax_code_clusterid_2_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s3 AS s3_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_3_freq_n = s3_Freq.sax_code_clusterid_3_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s3 AS s3_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_3_amt_n = s3_amt.sax_code_clusterid_3_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s4 AS s4_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_4_freq_n = s4_Freq.sax_code_clusterid_4_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s4 AS s4_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_4_amt_n = s4_amt.sax_code_clusterid_4_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s5 AS s5_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_5_freq_n = s5_Freq.sax_code_clusterid_5_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s5 AS s5_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_5_amt_n = s5_amt.sax_code_clusterid_5_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s6 AS s6_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_6_freq_n = s6_Freq.sax_code_clusterid_6_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s6 AS s6_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_6_amt_n = s6_amt.sax_code_clusterid_6_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s7 AS s7_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_7_freq_n = s7_Freq.sax_code_clusterid_7_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s7 AS s7_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_7_amt_n = s7_amt.sax_code_clusterid_7_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s8 AS s8_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_8_freq_n = s8_Freq.sax_code_clusterid_8_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s8 AS s8_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_8_amt_n = s8_amt.sax_code_clusterid_8_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s9 AS s9_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_9_freq_n = s9_Freq.sax_code_clusterid_9_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s9 AS s9_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_9_amt_n = s9_amt.sax_code_clusterid_9_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s10 AS s10_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_10_freq_n = s10_Freq.sax_code_clusterid_10_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s10 AS s10_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_10_amt_n = s10_amt.sax_code_clusterid_10_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s99 AS s99_Freq
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_99_freq_n = s99_Freq.sax_code_clusterid_99_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s99 AS s99_amt
ON 
mga_sax_on_merchseg_str1_stp18.sax_code_clusterid_99_amt_n = s99_amt.sax_code_clusterid_99_amount_n

);

--/********************  sax_on_merchseg_str1_stp20 - test_t1 ********************/
--woe hesabını traindeki kelimelere göre yaptık. şimdi trainde oluşan lookup ı test için de kullanıyoruz.
--yukardaki lookup tablosunu gelecek için de kullanabiliyoruz.
DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp20";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp20"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (

SELECT 
 mga_sax_on_merchseg_str1_stp13.cust_id AS cust_id
,mga_sax_on_merchseg_str1_stp13.card_no AS card_no
,mga_sax_on_merchseg_str1_stp13.target AS target

,s0_Freq.woe AS sax_code_clusterid_0_freq_n_woe
,s0_Freq.sax_code_clusterid_0_freq_n AS sax_code_clusterid_0_freq_n
,s0_amt.woe AS sax_code_clusterid_0_amt_n_woe
,s0_amt.sax_code_clusterid_0_amount_n AS sax_code_clusterid_0_amt_n

,s1_Freq.woe AS sax_code_clusterid_1_freq_n_woe
,s1_Freq.sax_code_clusterid_1_freq_n AS sax_code_clusterid_1_freq_n
,s1_amt.woe AS sax_code_clusterid_1_amt_n_woe
,s1_amt.sax_code_clusterid_1_amount_n AS sax_code_clusterid_1_amt_n


,s2_Freq.woe AS sax_code_clusterid_2_freq_n_woe
,s2_Freq.sax_code_clusterid_2_freq_n AS sax_code_clusterid_2_freq_n
,s2_amt.woe AS sax_code_clusterid_2_amt_n_woe
,s2_amt.sax_code_clusterid_2_amount_n AS sax_code_clusterid_2_amt_n


,s3_Freq.woe AS sax_code_clusterid_3_freq_n_woe
,s3_Freq.sax_code_clusterid_3_freq_n AS sax_code_clusterid_3_freq_n
,s3_amt.woe AS sax_code_clusterid_3_amt_n_woe
,s3_amt.sax_code_clusterid_3_amount_n AS sax_code_clusterid_3_amt_n


,s4_Freq.woe AS sax_code_clusterid_4_freq_n_woe
,s4_Freq.sax_code_clusterid_4_freq_n AS sax_code_clusterid_4_freq_n
,s4_amt.woe AS sax_code_clusterid_4_amt_n_woe
,s4_amt.sax_code_clusterid_4_amount_n AS sax_code_clusterid_4_amt_n


,s5_Freq.woe AS sax_code_clusterid_5_freq_n_woe
,s5_Freq.sax_code_clusterid_5_freq_n AS sax_code_clusterid_5_freq_n
,s5_amt.woe AS sax_code_clusterid_5_amt_n_woe
,s5_amt.sax_code_clusterid_5_amount_n AS sax_code_clusterid_5_amt_n


,s6_Freq.woe AS sax_code_clusterid_6_freq_n_woe
,s6_Freq.sax_code_clusterid_6_freq_n AS sax_code_clusterid_6_freq_n
,s6_amt.woe AS sax_code_clusterid_6_amt_n_woe
,s6_amt.sax_code_clusterid_6_amount_n AS sax_code_clusterid_6_amt_n


,s7_Freq.woe AS sax_code_clusterid_7_freq_n_woe
,s7_Freq.sax_code_clusterid_7_freq_n AS sax_code_clusterid_7_freq_n
,s7_amt.woe AS sax_code_clusterid_7_amt_n_woe
,s7_amt.sax_code_clusterid_7_amount_n AS sax_code_clusterid_7_amt_n


,s8_Freq.woe AS sax_code_clusterid_8_freq_n_woe
,s8_Freq.sax_code_clusterid_8_freq_n AS sax_code_clusterid_8_freq_n
,s8_amt.woe AS sax_code_clusterid_8_amt_n_woe
,s8_amt.sax_code_clusterid_8_amount_n AS sax_code_clusterid_8_amt_n


,s9_Freq.woe AS sax_code_clusterid_9_freq_n_woe
,s9_Freq.sax_code_clusterid_9_freq_n AS sax_code_clusterid_9_freq_n
,s9_amt.woe AS sax_code_clusterid_9_amt_n_woe
,s9_amt.sax_code_clusterid_9_amount_n AS sax_code_clusterid_9_amt_n


,s10_Freq.woe AS sax_code_clusterid_10_freq_n_woe
,s10_Freq.sax_code_clusterid_10_freq_n AS sax_code_clusterid_10_freq_n
,s10_amt.woe AS sax_code_clusterid_10_amt_n_woe
,s10_amt.sax_code_clusterid_10_amount_n AS sax_code_clusterid_10_amt_n



,s99_Freq.woe AS sax_code_clusterid_99_freq_n_woe
,s99_Freq.sax_code_clusterid_99_freq_n AS sax_code_clusterid_99_freq_n
,s99_amt.woe AS sax_code_clusterid_99_amt_n_woe
,s99_amt.sax_code_clusterid_99_amount_n AS sax_code_clusterid_99_amt_n

FROM
risk.mga_sax_on_merchseg_str1_stp13 

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s0 AS s0_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_0_freq_n = s0_Freq.sax_code_clusterid_0_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s0 AS s0_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_0_amount_n = s0_amt.sax_code_clusterid_0_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s1 AS s1_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_1_freq_n = s1_Freq.sax_code_clusterid_1_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s1 AS s1_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_1_amount_n = s1_amt.sax_code_clusterid_1_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s2 AS s2_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_2_freq_n = s2_Freq.sax_code_clusterid_2_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s2 AS s2_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_2_amount_n = s2_amt.sax_code_clusterid_2_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s3 AS s3_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_3_freq_n = s3_Freq.sax_code_clusterid_3_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s3 AS s3_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_3_amount_n = s3_amt.sax_code_clusterid_3_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s4 AS s4_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_4_freq_n = s4_Freq.sax_code_clusterid_4_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s4 AS s4_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_4_amount_n = s4_amt.sax_code_clusterid_4_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s5 AS s5_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_5_freq_n = s5_Freq.sax_code_clusterid_5_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s5 AS s5_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_5_amount_n = s5_amt.sax_code_clusterid_5_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s6 AS s6_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_6_freq_n = s6_Freq.sax_code_clusterid_6_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s6 AS s6_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_6_amount_n = s6_amt.sax_code_clusterid_6_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s7 AS s7_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_7_freq_n = s7_Freq.sax_code_clusterid_7_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s7 AS s7_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_7_amount_n = s7_amt.sax_code_clusterid_7_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s8 AS s8_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_8_freq_n = s8_Freq.sax_code_clusterid_8_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s8 AS s8_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_8_amount_n = s8_amt.sax_code_clusterid_8_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s9 AS s9_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_9_freq_n = s9_Freq.sax_code_clusterid_9_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s9 AS s9_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_9_amount_n = s9_amt.sax_code_clusterid_9_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s10 AS s10_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_10_freq_n = s10_Freq.sax_code_clusterid_10_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s10 AS s10_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_10_amount_n = s10_amt.sax_code_clusterid_10_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s99 AS s99_Freq
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_99_freq_n = s99_Freq.sax_code_clusterid_99_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s99 AS s99_amt
ON 
mga_sax_on_merchseg_str1_stp13.sax_code_clusterid_99_amount_n = s99_amt.sax_code_clusterid_99_amount_n
);


--/********************  sax_on_merchseg_str1_stp21 - test_t2 ********************/

DROP TABLE IF EXISTS "risk"."mga_sax_on_merchseg_str1_stp21";
CREATE FACT TABLE "risk"."mga_sax_on_merchseg_str1_stp21"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (
SELECT 
	 "_twmVC0"."card_no" AS "card_no"
	,"_twmVC0"."cust_id" AS "cust_id"
	,"_twmVC0"."target" AS "target"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_freq_n", '____') AS "sax_code_clusterid_0_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_1_freq_n", '____') AS "sax_code_clusterid_1_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_2_freq_n", '____') AS "sax_code_clusterid_2_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_3_freq_n", '____') AS "sax_code_clusterid_3_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_4_freq_n", '____') AS "sax_code_clusterid_4_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_5_freq_n", '____') AS "sax_code_clusterid_5_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_6_freq_n", '____') AS "sax_code_clusterid_6_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_7_freq_n", '____') AS "sax_code_clusterid_7_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_8_freq_n", '____') AS "sax_code_clusterid_8_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_9_freq_n", '____') AS "sax_code_clusterid_9_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_10_freq_n", '____') AS "sax_code_clusterid_10_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_99_freq_n", '____') AS "sax_code_clusterid_99_freq_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_0_amt_n", '____') AS "sax_code_clusterid_0_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_1_amt_n", '____') AS "sax_code_clusterid_1_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_2_amt_n", '____') AS "sax_code_clusterid_2_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_3_amt_n", '____') AS "sax_code_clusterid_3_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_4_amt_n", '____') AS "sax_code_clusterid_4_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_5_amt_n", '____') AS "sax_code_clusterid_5_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_6_amt_n", '____') AS "sax_code_clusterid_6_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_7_amt_n", '____') AS "sax_code_clusterid_7_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_8_amt_n", '____') AS "sax_code_clusterid_8_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_9_amt_n", '____') AS "sax_code_clusterid_9_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_10_amt_n", '____') AS "sax_code_clusterid_10_amt_n"
	,COALESCE("_twmVC0"."sax_code_clusterid_99_amt_n", '____') AS "sax_code_clusterid_99_amt_n"
FROM "risk"."mga_sax_on_merchseg_str1_stp20" AS "_twmVC0"
);

--/********************  sax_on_merchseg_str1_stp22 - test (Final Table) ********************/

DROP TABLE IF EXISTS  "risk"."mga_sax_on_merchseg_str1_stp22";
CREATE FACT TABLE  "risk"."mga_sax_on_merchseg_str1_stp22"() DISTRIBUTE BY HASH("card_no") COMPRESS LOW AS (

SELECT 
 mga_sax_on_merchseg_str1_stp21.cust_id AS cust_id
,mga_sax_on_merchseg_str1_stp21.card_no AS card_no
,mga_sax_on_merchseg_str1_stp21.target AS target
,s0_Freq.woe AS sax_code_clusterid_0_freq_n_woe
,s0_amt.woe AS sax_code_clusterid_0_amt_n_woe
,s1_Freq.woe AS sax_code_clusterid_1_freq_n_woe
,s1_amt.woe AS sax_code_clusterid_1_amt_n_woe
,s2_Freq.woe AS sax_code_clusterid_2_freq_n_woe
,s2_amt.woe AS sax_code_clusterid_2_amt_n_woe
,s3_Freq.woe AS sax_code_clusterid_3_freq_n_woe
,s3_amt.woe AS sax_code_clusterid_3_amt_n_woe
,s4_Freq.woe AS sax_code_clusterid_4_freq_n_woe
,s4_amt.woe AS sax_code_clusterid_4_amt_n_woe
,s5_Freq.woe AS sax_code_clusterid_5_freq_n_woe
,s5_amt.woe AS sax_code_clusterid_5_amt_n_woe
,s6_Freq.woe AS sax_code_clusterid_6_freq_n_woe
,s6_amt.woe AS sax_code_clusterid_6_amt_n_woe
,s7_Freq.woe AS sax_code_clusterid_7_freq_n_woe
,s7_amt.woe AS sax_code_clusterid_7_amt_n_woe
,s8_Freq.woe AS sax_code_clusterid_8_freq_n_woe
,s8_amt.woe AS sax_code_clusterid_8_amt_n_woe
,s9_Freq.woe AS sax_code_clusterid_9_freq_n_woe
,s9_amt.woe AS sax_code_clusterid_9_amt_n_woe
,s10_Freq.woe AS sax_code_clusterid_10_freq_n_woe
,s10_amt.woe AS sax_code_clusterid_10_amt_n_woe
,s99_Freq.woe AS sax_code_clusterid_99_freq_n_woe
,s99_amt.woe AS sax_code_clusterid_99_amt_n_woe

FROM
risk.mga_sax_on_merchseg_str1_stp21 

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s0 AS s0_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_0_freq_n = s0_Freq.sax_code_clusterid_0_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s0 AS s0_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_0_amt_n = s0_amt.sax_code_clusterid_0_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s1 AS s1_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_1_freq_n = s1_Freq.sax_code_clusterid_1_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s1 AS s1_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_1_amt_n = s1_amt.sax_code_clusterid_1_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s2 AS s2_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_2_freq_n = s2_Freq.sax_code_clusterid_2_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s2 AS s2_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_2_amt_n = s2_amt.sax_code_clusterid_2_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s3 AS s3_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_3_freq_n = s3_Freq.sax_code_clusterid_3_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s3 AS s3_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_3_amt_n = s3_amt.sax_code_clusterid_3_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s4 AS s4_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_4_freq_n = s4_Freq.sax_code_clusterid_4_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s4 AS s4_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_4_amt_n = s4_amt.sax_code_clusterid_4_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s5 AS s5_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_5_freq_n = s5_Freq.sax_code_clusterid_5_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s5 AS s5_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_5_amt_n = s5_amt.sax_code_clusterid_5_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s6 AS s6_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_6_freq_n = s6_Freq.sax_code_clusterid_6_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s6 AS s6_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_6_amt_n = s6_amt.sax_code_clusterid_6_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s7 AS s7_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_7_freq_n = s7_Freq.sax_code_clusterid_7_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s7 AS s7_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_7_amt_n = s7_amt.sax_code_clusterid_7_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s8 AS s8_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_8_freq_n = s8_Freq.sax_code_clusterid_8_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s8 AS s8_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_8_amt_n = s8_amt.sax_code_clusterid_8_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s9 AS s9_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_9_freq_n = s9_Freq.sax_code_clusterid_9_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s9 AS s9_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_9_amt_n = s9_amt.sax_code_clusterid_9_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s10 AS s10_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_10_freq_n = s10_Freq.sax_code_clusterid_10_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s10 AS s10_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_10_amt_n = s10_amt.sax_code_clusterid_10_amount_n

--00000000000000000000000000000000000000000000000000000000000000000000000000000--

LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_s99 AS s99_Freq
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_99_freq_n = s99_Freq.sax_code_clusterid_99_freq_n
LEFT OUTER JOIN 
risk.mga_sax_on_merchseg_str1_stp16_amt_s99 AS s99_amt
ON 
mga_sax_on_merchseg_str1_stp21.sax_code_clusterid_99_amt_n = s99_amt.sax_code_clusterid_99_amount_n
);


GRANT ALL on risk.mga_sax_on_merchseg_str1_stp19 to public;
analyze risk.mga_sax_on_merchseg_str1_stp19;

GRANT ALL on risk.mga_sax_on_merchseg_str1_stp22 to public;
analyze risk.mga_sax_on_merchseg_str1_stp22;

GRANT ALL on risk.mga_sax_on_merchseg_str1_stp10 to public;
analyze risk.mga_sax_on_merchseg_str1_stp10;
